// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { TouchableOpacity, ViewPropTypes, Text } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'

const styles = StyleSheet.create({
  disabled: {
    opacity: 0.5
  }
})

Button.propTypes = {
  children: PropTypes.node.isRequired,
  disabled: PropTypes.bool,
  style: ViewPropTypes.style,
  onPress: PropTypes.func,
  textStyle: Text.propTypes.style
}

export default function Button ({
  children,
  disabled,
  style,
  onPress,
  textStyle
}) {
  const childComponent =
    typeof children === 'string' ? (
      <Text style={textStyle}>{children}</Text>
    ) : (
      children
    )
  const disabledStyle = disabled ? styles.disabled : {}
  return (
    <TouchableOpacity
      style={[style, disabledStyle]}
      onPress={!disabled ? onPress : () => {}}
    >
      {childComponent}
    </TouchableOpacity>
  )
}
