// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { View, Text, ViewPropTypes } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import Icon from 'components/Icon'
import Button from './Button'
import COLORS from '../../colors'
import font from 'utils/font'

const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    alignItems: 'center'
  },
  primary: {
    color: '$Primary'
  },
  secondary: {
    color: '$Secondary'
  },
  text: {
    ...font({ weight: 'bold' }),
    textAlign: 'center'
  }
})

OpacityButton.propTypes = {
  buttonStyle: ViewPropTypes.style,
  children: PropTypes.string.isRequired,
  disabled: PropTypes.bool,
  iconStyle: ViewPropTypes.style,
  leftIcon: PropTypes.string,
  onPress: PropTypes.func,
  rightIcon: PropTypes.string,
  secondary: PropTypes.bool,
  style: ViewPropTypes.style
}

export default function OpacityButton ({
  buttonStyle,
  children,
  disabled,
  iconStyle,
  leftIcon,
  onPress,
  rightIcon,
  secondary,
  style,
  textStyle
}) {
  const textColor = secondary ? styles.secondary : styles.primary
  const iconColor = secondary ? COLORS.Secondary : COLORS.Primary
  return (
    <Button onPress={onPress} style={buttonStyle} disabled={disabled}>
      <View style={[styles.container, style]}>
        {leftIcon && (
          <Icon name={leftIcon} color={iconColor} size={18} style={iconStyle} />
        )}
        <Text style={[styles.text, textColor, textStyle]}>{children}</Text>
        {rightIcon && (
          <Icon
            name={rightIcon}
            color={iconColor}
            size={18}
            style={iconStyle}
          />
        )}
      </View>
    </Button>
  )
}
