// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { View, Text, ViewPropTypes } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import Icon from 'components/Icon'
import Button from './Button'
import COLORS from '../../colors'
import font from 'utils/font'

const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    alignItems: 'center'
  },
  primary: {
    backgroundColor: '$Primary'
  },
  secondary: {
    backgroundColor: '$Secondary'
  },
  text: {
    ...font({ weight: 'bold' }),
    flex: 1,
    textAlign: 'center',
    color: '$White'
  }
})

SolidButton.propTypes = {
  children: PropTypes.string.isRequired,
  disabled: PropTypes.bool,
  leftIcon: PropTypes.string,
  onPress: PropTypes.func,
  rightIcon: PropTypes.string,
  secondary: PropTypes.bool,
  style: ViewPropTypes.style
}

export default function SolidButton ({
  children,
  disabled,
  leftIcon,
  onPress,
  rightIcon,
  secondary,
  style
}) {
  const viewStyle = secondary ? styles.secondary : styles.primary
  return (
    <Button onPress={onPress} disabled={disabled}>
      <View style={[styles.container, viewStyle, style]}>
        {leftIcon && <Icon name={leftIcon} color={COLORS.White} size={18} />}
        <Text style={styles.text}>{children}</Text>
        {rightIcon && <Icon name={rightIcon} color={COLORS.White} size={18} />}
      </View>
    </Button>
  )
}
