// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { View } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import GroupBadge, { BADGE_SPACING } from 'components/GroupBadge'

const styles = StyleSheet.create({
  container: {
    flexDirection: 'row'
  },
  unread: {
    position: 'absolute',
    borderWidth: 2,
    borderColor: '#ffffff',
    backgroundColor: '#77dd77'
  }
})

ConversationBadge.propTypes = {
  names: PropTypes.arrayOf(PropTypes.string).isRequired,
  size: PropTypes.number.isRequired,
  unread: PropTypes.bool
}

export default function ConversationBadge ({ names, size, unread }) {
  const containerStyle = {
    width: size + (names.length > 2 ? BADGE_SPACING : 0),
    height: size + (names.length > 2 ? BADGE_SPACING : 0)
  }
  const dotSize = Math.max(size / 3, 10)
  const dotStyle = {
    bottom: -dotSize / 10,
    right: 0 + dotSize / 8,
    width: dotSize,
    height: dotSize,
    borderRadius: dotSize / 2
  }
  return (
    <View style={[styles.container, containerStyle]}>
      <GroupBadge names={names} size={size} />
      {unread && <View style={[styles.unread, dotStyle]} />}
    </View>
  )
}
