import React from 'react'
import ConversationBadge from '../ConversationBadge'
import { shallow } from 'enzyme'
import GroupBadge from 'components/GroupBadge'
import { View } from 'react-native'

function renderHelper (props = {}) {
  return shallow(
    <ConversationBadge
      names={['foo', 'bar', 'baz']}
      size={24}
      unread
      {...props}
    />
  )
}

describe('ConversationBadge Component', () => {
  it('does not change by accident', () => {
    expect(renderHelper()).toMatchSnapshot()
  })

  it('does not render the unread icon if not needed', () => {
    const node = renderHelper({ unread: true })
    expect(node.find(View)).toHaveLength(2)
    const nodeRead = renderHelper({ unread: false })
    expect(nodeRead.find(View)).toHaveLength(1)
  })

  it('renders a group badge and an unread view', () => {
    const node = renderHelper()
    expect(node.find(View)).toHaveLength(2)
    expect(node.find(GroupBadge)).toHaveLength(1)
  })

  it('passes down names and sizes to GrabBadge', () => {
    const names = ['parappa', 'the', 'rappa']
    const node = renderHelper({ names, size: 44 })
    const groupBadge = node.find(GroupBadge)
    expect(groupBadge.props().names).toEqual(names)
    expect(groupBadge.props().size).toEqual(44)
  })
})
