import React from 'react'
import EmptyResource from '../EmptyResource'
import { shallow } from 'enzyme'
import Icon from 'components/Icon'
import { SolidButton } from 'components/Button'
import { Text } from 'react-native'

function renderHelper (props = {}) {
  return shallow(
    <EmptyResource
      label='Some label'
      icon='Some icon'
      onCreate={() => {}}
      {...props}
    />
  )
}

describe('EmptyResource Component', () => {
  it('does not change by accident', () => {
    expect(renderHelper()).toMatchSnapshot()
  })
  it('renders the icon passed', () => {
    const node = renderHelper({ icon: 'boop' })
    const icon = node.find(Icon)
    expect(icon).toHaveLength(1)
    expect(icon.prop('name')).toBe('boop')
  })

  it('renders the label passed', () => {
    const node = renderHelper({ label: 'my label' })
    expect(node.find(Text)).toHaveLength(1)
    expect(
      node
        .find(Text)
        .children()
        .text()
    ).toBe('my label')
  })

  it('renders the button with button label if passed and onPress', () => {
    const onCreate = jest.fn()
    const node = renderHelper({ buttonLabel: 'button label', onCreate })
    const button = node.find(SolidButton)
    expect(button).toHaveLength(1)
    expect(button.prop('onPress')).toBe(onCreate)
  })
})
