// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { View, Text, Switch } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import fontMaker from 'utils/font'

const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    marginTop: 10
  },
  label: {
    fontSize: 16,
    flex: 1,
    marginBottom: 5,
    ...fontMaker({ weight: 'bold' })
  },
  input: {
    borderWidth: 1,
    borderColor: '$DarkText',
    borderRadius: 16
  }
})

FormTextInput.propTypes = {
  label: PropTypes.string.isRequired,
  containerStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object]),
  style: PropTypes.oneOfType([PropTypes.number, PropTypes.object])
}

export default function FormTextInput ({
  label,
  containerStyle,
  style,
  ...props
}) {
  return (
    <View style={[styles.container, style]}>
      <Text style={styles.label}>{label}</Text>
      <Switch
        underlineColorAndroid='rgba(0,0,0,0)'
        style={styles.input}
        {...props}
      />
    </View>
  )
}
