// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { View, Text, TextInput } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import fontMaker from 'utils/font'

const styles = StyleSheet.create({
  container: {
    flexDirection: 'column',
    marginTop: 10
  },
  label: {
    fontSize: 16,
    marginBottom: 5,
    ...fontMaker({ weight: 'bold' })
  },
  inputWrapper: {
    borderWidth: 1,
    borderColor: '$Primary',
    borderRadius: 3,
    minHeight: 30,
    paddingLeft: 5,
    paddingRight: 5,
    paddingTop: 8,
    paddingBottom: 8
  },
  input: {
    width: '100%',
    flex: 1,
    padding: 0,
    margin: 0,
    borderWidth: 0,
    fontSize: 15,
    color: '$Primary'
  }
})

FormTextInput.propTypes = {
  label: PropTypes.string.isRequired,
  containerStyle: PropTypes.oneOfType([PropTypes.number, PropTypes.object]),
  style: PropTypes.oneOfType([PropTypes.number, PropTypes.object]),
  multiline: PropTypes.bool
}

export default function FormTextInput ({
  label,
  containerStyle,
  style,
  multiline,
  ...props
}) {
  const inputStyle = {
    justifyContent: multiline ? 'flex-start' : 'center'
  }
  return (
    <View style={[styles.container, style]}>
      <Text style={styles.label}>{label}</Text>
      <View style={[styles.inputWrapper, inputStyle, containerStyle]}>
        <TextInput
          underlineColorAndroid='rgba(0,0,0,0)'
          multiline={multiline}
          style={styles.input}
          {...props}
        />
      </View>
    </View>
  )
}
