// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { View } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import UserBadge from 'components/UserBadge'

export const BADGE_SPACING = 1

const styles = StyleSheet.create({
  row: {
    flexDirection: 'row'
  },
  column: {
    flexDirection: 'column'
  },
  leftHalf: {
    borderTopRightRadius: 0,
    borderBottomRightRadius: 0
  },
  rightHalf: {
    borderTopLeftRadius: 0,
    borderBottomLeftRadius: 0,
    marginLeft: BADGE_SPACING
  },
  topThird: {
    borderTopLeftRadius: 0,
    borderBottomLeftRadius: 0,
    borderBottomRightRadius: 0,
    marginLeft: BADGE_SPACING
  },
  bottomThird: {
    borderTopLeftRadius: 0,
    borderBottomLeftRadius: 0,
    borderTopRightRadius: 0,
    marginLeft: BADGE_SPACING,
    marginTop: BADGE_SPACING
  },
  textLeftHalf: {
    marginLeft: BADGE_SPACING
  },
  textRightHalf: {
    marginLeft: -BADGE_SPACING / 2
  },
  textBottomThird: {
    marginTop: -4,
    marginLeft: -4
  },
  textTopThird: {
    marginTop: 4,
    marginLeft: -4
  }
})

GroupBadge.propTypes = {
  names: PropTypes.arrayOf(PropTypes.string).isRequired,
  size: PropTypes.number.isRequired
}

export default function GroupBadge ({ names, size }) {
  const halfWidth = {
    width: size / 2
  }
  const halfHeight = {
    height: size / 2
  }
  if (names.length === 1) {
    return <UserBadge name={names[0]} size={size} />
  }
  if (names.length === 2) {
    return (
      <View style={styles.row}>
        <UserBadge
          name={names[0]}
          size={size}
          style={[styles.leftHalf, halfWidth]}
          textSizeRatio={3.5}
          textStyle={styles.textLeftHalf}
        />
        <UserBadge
          name={names[1]}
          size={size}
          style={[styles.rightHalf, halfWidth]}
          textSizeRatio={3.5}
          textStyle={styles.textRightHalf}
        />
      </View>
    )
  }
  return (
    <View style={styles.row}>
      <UserBadge
        name={names[0]}
        size={size + BADGE_SPACING}
        style={[styles.leftHalf, halfWidth]}
        textSizeRatio={3.5}
        textStyle={styles.textLeftHalf}
      />
      <View style={styles.column}>
        <UserBadge
          name={names[1]}
          size={size}
          style={[styles.topThird, halfWidth, halfHeight]}
          textSizeRatio={4.5}
          textStyle={styles.textTopThird}
        />
        <UserBadge
          name={names[2]}
          size={size}
          style={[styles.bottomThird, halfWidth, halfHeight]}
          textSizeRatio={4.5}
          textStyle={styles.textBottomThird}
        />
      </View>
    </View>
  )
}
