// @flow
import React, { Component } from 'react'
import PropTypes from 'prop-types'
import { View, ViewPropTypes } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import Button from 'components/Button'
import Icon from 'components/Icon'
import { ExpandingTextInput } from 'components/FormControls'
import COLORS from '../../colors'

const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    width: '100%',
    minHeight: 45,
    alignItems: 'center'
  },
  button: {
    marginLeft: 10
  },
  microphone: {
    marginTop: 2
  },
  greyButton: {
    backgroundColor: COLORS.DarkBackground,
    marginRight: 5,
    justifyContent: 'center',
    alignItems: 'center',
    width: 30,
    height: 30,
    borderRadius: 15
  },
  textWrapper: {
    flexDirection: 'row',
    justifyContent: 'center',
    backgroundColor: '$LightBackground',
    borderRadius: 20,
    borderWidth: 1,
    marginRight: 10,
    marginLeft: 10,
    borderColor: '$LightDivider',
    flex: 1,
    height: 40
  },
  textInput: {
    flex: 1,
    marginLeft: 10,
    fontSize: 15
  },
  sendButton: {
    marginRight: 7,
    marginTop: 1,
    backgroundColor: 'transparent'
  }
})

export default class MessageInput extends Component {
  static propTypes = {
    style: ViewPropTypes.style,
    text: PropTypes.string,
    setText: PropTypes.func.isRequired,
    onOptions: PropTypes.func,
    onSend: PropTypes.func.isRequired
  }

  constructor (props) {
    super(props)
    this.state = {
      height: 45
    }
  }
  componentWillReceiveProps (nextProps) {
    if (this.props.text && !nextProps.text) {
      this._textInput.clear()
    }
  }

  render () {
    const { style, text, setText, onOptions, onSend, onAudio } = this.props
    const { height } = this.state
    const sizeStyle = { height: height + 15 }
    const inputStyle = { height: height + 10 }
    return (
      <View style={[styles.container, style, sizeStyle]}>
        {onOptions && (
          <Button style={styles.button} onPress={onOptions}>
            <Icon size={35} name='ios-add-circle' color={COLORS.Secondary} />
          </Button>
        )}
        <View style={[styles.textWrapper, inputStyle]}>
          <ExpandingTextInput
            placeholder='Message...'
            onChangeText={setText}
            ref={ref => (this._textInput = ref)}
            placeholderTextColor='#8d8d8d'
            style={styles.textInput}
            setHeight={height => this.setState({ height })}
          />
          {onAudio && (!text || (text && !text.length)) ? (
            <Button style={[styles.sendButton]} onPress={onAudio}>
              <Icon
                size={30}
                name='ios-microphone'
                style={styles.microphone}
                color={COLORS.Secondary}
              />
            </Button>
          ) : null}
          {!onAudio || (text && text.length) ? (
            <Button style={styles.sendButton} onPress={onSend}>
              <Icon size={40} name='ios-send' color={COLORS.Secondary} />
            </Button>
          ) : null}
        </View>
      </View>
    )
  }
}
