// @flow
import React from 'react'
import { View, Text, TextInput } from 'react-native'
import Modal from 'react-native-modal'
import PropTypes from 'prop-types'
import Button from 'components/Button'
import StyleSheet from 'react-native-extended-stylesheet'

const styles = StyleSheet.create({
  container: {
    backgroundColor: '$White',
    borderRadius: 5
  },
  row: {
    marginTop: 15,
    height: 40,
    flexDirection: 'row',
    width: '100%'
  },
  button: {
    flex: 1,
    height: 40,
    justifyContent: 'center',
    alignItems: 'center',
    borderColor: '$Primary',
    borderTopWidth: 1
  },
  buttonOK: {
    backgroundColor: '$Primary'
  },
  buttonOKText: {
    color: '$White'
  },
  text: {
    fontSize: 13,
    color: '$Primary',
    marginTop: 20,
    width: '80%',
    paddingLeft: 20,
    paddingRight: 20
  },
  inputContainer: {
    borderColor: '$Primary',
    borderRadius: 5,
    borderWidth: 1,
    justifyContent: 'center',
    alignItems: 'center',
    marginTop: 10,
    height: 40,
    width: '90%',
    marginLeft: '5%',
    paddingLeft: 10,
    paddingRight: 10
  },
  textInput: {
    height: 40,
    width: '100%',
    flex: 1,
    fontSize: 16,
    color: '$Primary'
  }
})

NailitModal.propTypes = {
  isVisible: PropTypes.bool.isRequired,
  text: PropTypes.string.isRequired,
  setMessage: PropTypes.func.isRequired,
  cancelFn: PropTypes.func.isRequired,
  saveFn: PropTypes.func.isRequired,
  message: PropTypes.string.isRequired
}

export default function NailitModal ({
  isVisible,
  text,
  message,
  setMessage,
  saveFn,
  cancelFn
}) {
  return (
    <View>
      <Modal isVisible={isVisible}>
        <View style={styles.container}>
          <Text style={styles.text}>{text}</Text>
          <View style={styles.inputContainer}>
            <TextInput
              style={styles.textInput}
              autoCorrect={false}
              value={message}
              onChangeText={setMessage}
              underlineColorAndroid='transparent'
            />
          </View>
          <View style={styles.row}>
            <Button onPress={cancelFn} style={styles.button}>
              Cancel
            </Button>
            <Button
              secondary
              onPress={saveFn}
              textStyle={styles.buttonOKText}
              style={[styles.button, styles.buttonOK]}
            >
              OK
            </Button>
          </View>
        </View>
      </Modal>
    </View>
  )
}
