// @flow
import { Alert } from 'react-native'
import { Record } from 'immutable'
import createReducer from 'utils/createreducer'
import createConstants from 'utils/createconstants'
import createViewSelector from 'utils/createviewselector'

export const CONSTANTS = createConstants('MODAL', {
  RESET: null,
  SET_TEXT: null,
  SET_MESSAGE: null,
  SET_CANCEL: null,
  SET_SAVE: null,
  SET_VISIBLE: null
})

export const actions = {
  reset () {
    return {
      type: CONSTANTS.RESET
    }
  },
  confirm (text, textLimit = 0, textLimitString = 'Field is too short') {
    return (dispatch, getState) => {
      dispatch(actions.reset())
      dispatch(actions.setVisible(true))
      dispatch(actions.setText(text))
      return new Promise((resolve, reject) => {
        dispatch(
          actions.setSave(() => {
            const message = selectors.message(getState())
            if (message < textLimit) {
              Alert.alert('Nailit', textLimitString)
              return
            }
            dispatch(actions.setVisible(false))
            resolve(message)
          })
        )
        dispatch(
          actions.setCancel(() => {
            dispatch(actions.setVisible(false))
            reject(new Error('cancellation'))
          })
        )
      })
    }
  },
  setSave (saveFn) {
    return {
      type: CONSTANTS.SET_SAVE,
      payload: saveFn
    }
  },
  setCancel (cancelFn) {
    return {
      type: CONSTANTS.SET_CANCEL,
      payload: cancelFn
    }
  },
  setText (text) {
    return {
      type: CONSTANTS.SET_TEXT,
      payload: text
    }
  },
  setMessage (message) {
    return {
      type: CONSTANTS.SET_MESSAGE,
      payload: message
    }
  },
  setVisible (isVisible) {
    return {
      type: CONSTANTS.SET_VISIBLE,
      payload: isVisible
    }
  }
}

export const ModalState = Record({
  text: 'Sample Text',
  message: '',
  isVisible: false,
  saveFn: () => {},
  cancelFn: () => {}
})

export const reducer = createReducer(new ModalState(), {
  [CONSTANTS.RESET]: () => new ModalState(),
  [CONSTANTS.SET_SAVE]: (state, { payload }) => state.set('saveFn', payload),
  [CONSTANTS.SET_CANCEL]: (state, { payload }) =>
    state.set('cancelFn', payload),
  [CONSTANTS.SET_MESSAGE]: (state, { payload }) =>
    state.set('message', payload),
  [CONSTANTS.SET_TEXT]: (state, { payload }) => state.set('text', payload),
  [CONSTANTS.SET_VISIBLE]: (state, { payload }) =>
    state.set('isVisible', payload)
})

export const viewState = state => state.modal
export const viewSelector = createViewSelector(viewState)

export const selectors = {
  text: viewSelector('text', ''),
  cancelFn: viewSelector('cancelFn'),
  saveFn: viewSelector('saveFn'),
  message: viewSelector('message'),
  isVisible: viewSelector('isVisible')
}
