import React from 'react'
import { shallow } from 'enzyme'
import NavbarButton from '../NavbarButton'
import Icon from 'components/Icon'
import Button from 'components/Button'

const renderHelper = (props = {}) =>
  shallow(
    <NavbarButton
      name='foo'
      size={20}
      color='#3344ff'
      style={{ padding: 34 }}
      onPress={() => {}}
      {...props}
    />
  )

describe('NavbarButton', () => {
  it('should not change by accident', () => {
    expect(renderHelper()).toMatchSnapshot()
  })
  it('renders an icon if no children', () => {
    const node = renderHelper()
    expect(node.find(Icon)).toHaveLength(1)
  })
  it('renders children if passed', () => {
    const node = renderHelper({
      children: 'foo'
    })
    expect(node.find(Icon)).toHaveLength(0)
    expect(node.children().text()).toBe('foo')
  })
  it('renders a button passing onPress and style thru', () => {
    const style = { something: 'foo' }
    const onPress = jest.fn()
    const node = renderHelper({ onPress, style })
    expect(
      node
        .find(Button)
        .prop('style')
        .includes(style)
    ).toBe(true)
    node.find(Button).prop('onPress')()
    expect(onPress).toHaveBeenCalledTimes(1)
  })
})
