// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { Map, List } from 'immutable'
import StyleSheet from 'react-native-extended-stylesheet'
import EmptyResource from 'components/EmptyResource'
import { SwipeableFlatList } from 'react-native-swipeable-flat-list'
import ResourceRow from './ResourceRow'
import ResourceDelete from './ResourceDelete'
import COLORS from '../../colors'

const styles = StyleSheet.create({
  container: {
    backgroundColor: '$White',
    flex: 1
  }
})

ResourceList.propTypes = {
  resource: PropTypes.instanceOf(Map).isRequired,
  resourceList: PropTypes.instanceOf(List).isRequired,
  canDelete: PropTypes.bool,
  onDelete: PropTypes.func,
  field: PropTypes.string.isRequired,
  emptyIcon: PropTypes.string.isRequired,
  onPress: PropTypes.func,
  emptyLabel: PropTypes.string.isRequired
}

export default function ResourceList ({
  resource,
  resourceList,
  canDelete,
  onDelete,
  field,
  onPress,
  emptyIcon,
  emptyLabel
}) {
  const flattenedList = resourceList.toJS().map(id => ({ id }))
  if (!flattenedList.length) {
    return <EmptyResource icon={emptyIcon} label={emptyLabel} />
  }
  const rowRenderer = ({ item }) => (
    <ResourceRow
      key={item.id}
      style={{ height: 75 }}
      {...item}
      field={field}
      onPress={onPress}
      resource={resource}
    />
  )
  const rowRightRenderer = ({ item }) => (
    <ResourceDelete
      key={item.id}
      {...item}
      style={{ height: 75, width: 75 }}
      onDelete={onDelete}
      field={field}
    />
  )
  return (
    <SwipeableFlatList
      data={flattenedList}
      style={styles.container}
      renderItem={rowRenderer}
      keyExtractor={(item, index) => item.id.toString()}
      renderRight={canDelete ? rowRightRenderer : undefined}
      backgroundColor={COLORS.White}
    />
  )
}
