// @flow
import React, { Component } from 'react'
import PropTypes from 'prop-types'
import { Image, TouchableOpacity, Text } from 'react-native'
import { Map } from 'immutable'
import StyleSheet from 'react-native-extended-stylesheet'
import Lightbox from 'components/Lightbox'

const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    height: 75,
    paddingLeft: 15,
    paddingRight: 15,
    borderColor: '$LightDivider',
    borderBottomWidth: 1,
    alignItems: 'center',
    justifyContent: 'space-between',
    overflow: 'hidden'
  },
  name: {
    color: '$Primary',
    textAlign: 'left',
    fontSize: 14,
    flex: 1
  },
  image: {
    width: 0,
    height: 0,
    resizeMode: 'cover'
  },
  imageActive: {
    flex: 1,
    resizeMode: 'contain'
  }
})

export default class ResourceRow extends Component {
  static propTypes = {
    resource: PropTypes.instanceOf(Map).isRequired,
    id: PropTypes.string.isRequired
  }

  onPress = () => {
    const { id, onPress } = this.props
    if (onPress) {
      onPress({ id })
      return
    }
    this.lightbox.open()
  }

  render () {
    const { id, resource, field } = this.props
    const resourceItem = resource.get(id)
    const uri = resourceItem.get('url')
    return (
      <TouchableOpacity style={styles.container} onPress={this.onPress}>
        <Text numberOfLines={1} ellipsizeMode='middle' style={styles.name}>
          {resourceItem.get(field)}
        </Text>
        {uri && (
          <Lightbox
            ref={ref => (this.lightbox = ref)}
            activeProps={{ style: styles.imageActive }}
          >
            <Image style={styles.image} source={{ uri }} />
          </Lightbox>
        )}
      </TouchableOpacity>
    )
  }
}
