// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { View, TextInput, Keyboard } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import COLORS from '../../colors'

const styles = StyleSheet.create({
  container: {
    justifyContent: 'center',
    alignItems: 'center',
    marginTop: 40,
    height: 40,
    width: '80%',
    paddingLeft: 20,
    paddingRight: 20
  },
  background: {
    position: 'absolute',
    top: 0,
    right: 0,
    left: 0,
    bottom: 0,
    backgroundColor: '$White',
    borderRadius: 25,
    opacity: 0.3
  },
  text: {
    height: 40,
    width: '100%',
    flex: 1,
    fontSize: 16,
    color: '$White'
  }
})

RoundTextInput.propTypes = {
  value: PropTypes.string.isRequired,
  onChangeText: PropTypes.func.isRequired,
  placeHolder: PropTypes.string.isRequired
}

export default function RoundTextInput ({ value, onChangeText, placeHolder }) {
  return (
    <View style={styles.container}>
      <View style={styles.background} />
      <TextInput
        style={styles.text}
        autoCorrect={false}
        keyboardType='phone-pad'
        placeholder={placeHolder}
        selectionColor={COLORS.Secondary}
        placeholderTextColor={COLORS.LightPrimary}
        onSubmitEditing={Keyboard.dismiss}
        value={value}
        onChange={event => onChangeText(event.nativeEvent.text)}
        underlineColorAndroid='transparent'
      />
    </View>
  )
}
