import React from 'react'
import { shallow } from 'enzyme'
import { TextInput, Keyboard } from 'react-native'
import RoundTextInput from '../RoundTextInput'

function renderHelper (props = {}) {
  return shallow(
    <RoundTextInput
      value='foo'
      onChangeText={() => {}}
      placeHolder='foo'
      {...props}
    />
  )
}

describe('RoundTextInput', () => {
  it('should not change by accient', () => {
    expect(renderHelper()).toMatchSnapshot()
  })
  it('should map the value to the input', () => {
    const node = renderHelper({ value: 'eleven' })
    expect(node.find(TextInput).prop('value')).toBe('eleven')
  })
  it('should map the onChange event', () => {
    const onChangeText = jest.fn()
    const node = renderHelper({ value: 'eleven', onChangeText })
    node.find(TextInput).prop('onChange')({ nativeEvent: { text: 'mike' } })
    expect(onChangeText).toHaveBeenCalledWith('mike')
  })
  it('should have the expected props', () => {
    const node = renderHelper()
    expect(node.find(TextInput).prop('autoCorrect')).toBe(false)
    expect(node.find(TextInput).prop('keyboardType')).toBe('phone-pad')
    expect(node.find(TextInput).prop('onSubmitEditing')).toBe(Keyboard.dismiss)
  })
})
