// @flow
import React from 'react'
import { Text } from 'react-native'
import PropTypes from 'prop-types'
import moment from 'moment'
import numeral from 'numeral'

export const TIME_FORMATTERS = {
  AGO: dateString => moment(dateString).fromNow(),
  FORMATTED_TIME: dateString => moment(dateString).format('hh:mm A'),
  FORMATTED_MINUTES: seconds => numeral(seconds).format('00:00'),
  FORMATTED_DAY: date => moment(date).format('dddd MMM Do, YYYY'),
  FORMATTED_COMPLETE: date => moment(date).format('MM/DD/YYYY'),
  FORMATTED_COMPLETE_TIME: date => moment(date).format('MM/DD/YYYY hh:mm A')
}

TimeFormatter.propTypes = {
  date: PropTypes.oneOfType([PropTypes.instanceOf(Date), PropTypes.string])
    .isRequired,
  format: PropTypes.func.isRequired
}

TimeFormatter.defaultProps = {
  format: TIME_FORMATTERS.AGO
}

export default function TimeFormatter ({ date, format, ...props }) {
  const formattedTime = format(date)
  return <Text {...props}>{formattedTime}</Text>
}
