// @flow
import React, { Component } from 'react'
import PropTypes from 'prop-types'
import { View, Text, TouchableOpacity, TextInput } from 'react-native'
import Autocomplete from 'components/Autocomplete'
import StyleSheet from 'react-native-extended-stylesheet'
import UserBadge from '../../components/UserBadge'
import Token from '../../components/Token'

const styles = StyleSheet.create({
  autocompleteContainer: {
    flex: 1,
    left: 40,
    position: 'absolute',
    right: 0,
    top: 0,
    zIndex: 1
  },
  entry: {
    flexDirection: 'row',
    height: 32,
    paddingLeft: 3,
    alignItems: 'center'
  },
  entryText: {
    fontSize: 13,
    flex: 1
  },
  entryTextWrapper: {
    flex: 1,
    marginLeft: 5,
    height: 30,
    alignItems: 'center',
    flexDirection: 'row',
    marginRight: 5
  },
  wrapper: {
    position: 'relative',
    overflow: 'visible',
    flexDirection: 'row',
    alignItems: 'center',
    zIndex: 99,
    width: '100%',
    height: 80
  },
  innerWrapper: {
    marginLeft: 2
  },
  inputWrapper: {
    flexDirection: 'row',
    flex: 1,
    paddingTop: 1,
    paddingRight: 4,
    paddingBottom: 1,
    paddingLeft: 4,
    overflow: 'hidden',
    flexWrap: 'wrap',
    minHeight: 26,
    alignItems: 'center'
  },
  input: {
    flex: 1,
    height: 25,
    padding: 0,
    margin: 0,
    borderWidth: 0,
    minWidth: 50,
    fontSize: 14
  },
  textTo: {
    marginLeft: 10,
    color: '#a8a8a8'
  }
})

export default class TokenAutocomplete extends Component {
  static propTypes = {
    addToken: PropTypes.func.isRequired,
    options: PropTypes.arrayOf(PropTypes.string).isRequired,
    removeToken: PropTypes.func.isRequired,
    values: PropTypes.arrayOf(PropTypes.string).isRequired
  }

  constructor (props) {
    super(props)
    this.state = {
      search: 'd'
    }
    this.renderAutocompleteEntry = this.renderAutocompleteEntry.bind(this)
    this.focus = this.focus.bind(this)
    this.renderTextInput = this.renderTextInput.bind(this)
  }
  componentDidMount () {
    setTimeout(() => {
      this.setState({ search: '' })
    }, 100)
  }

  addToken (name) {
    this.textInput.blur()
    this.props.addToken(name)
    this.setState({ search: '' })
  }

  focus () {
    this.textInput.focus()
  }

  renderAutocompleteEntry (item) {
    const { name, isLast } = item
    const borderStyle = {
      borderBottomWidth: 1,
      borderColor: '#c8c8c8'
    }
    return (
      <TouchableOpacity
        style={styles.entry}
        onPress={() => this.addToken(name)}
      >
        <UserBadge size={22} name={name} />
        <View style={[styles.entryTextWrapper, !isLast && borderStyle]}>
          <Text style={styles.entryText}>{name}</Text>
        </View>
      </TouchableOpacity>
    )
  }

  renderTextInput (props) {
    const { values, removeToken } = this.props
    return (
      <View style={[styles.wrapper, styles.innerWrapper]}>
        <TouchableOpacity style={styles.inputWrapper} onPress={this.focus}>
          {values.map((value, index) => (
            <Token
              key={index}
              index={index}
              value={value}
              remove={removeToken}
            />
          ))}
          <TextInput
            ref={ref => (this.textInput = ref)}
            value={this.state.search}
            onKeyPress={this.keyPress}
            onChangeText={search => this.setState({ search })}
            style={styles.input}
            underlineColorAndroid='rgba(0,0,0,0)'
          />
        </TouchableOpacity>
      </View>
    )
  }

  render () {
    const { options } = this.props
    const { search } = this.state
    const filteredOptions = options
      .filter(
        option => option.toLowerCase().indexOf(search.toLowerCase()) !== -1
      )
      .map(option => ({ name: option, isLast: false }))
    if (!filteredOptions.length) {
      filteredOptions.unshift({ name: search, isLast: false })
    }
    filteredOptions[filteredOptions.length - 1].isLast = true
    return (
      <View
        style={{
          height: 80,
          padding: 0,
          margin: 0,
          flexDirection: 'row',
          alignItems: 'center'
        }}
      >
        <Text style={styles.textTo}>To:</Text>
        <View style={styles.autocompleteContainer}>
          <Autocomplete
            renderTextInput={this.renderTextInput}
            data={search.length && filteredOptions}
            renderItem={this.renderAutocompleteEntry}
          />
        </View>
      </View>
    )
  }
}
