// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { Text, View, ViewPropTypes } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import randomColor from 'utils/randomcolor'
import initials from 'utils/initials'

const styles = StyleSheet.create({
  container: {
    justifyContent: 'center',
    alignItems: 'center'
  },
  text: {
    color: '#ffffff'
  }
})

UserBadge.defaultProps = {
  size: 30,
  textSizeRatio: 3
}

UserBadge.propTypes = {
  name: PropTypes.string.isRequired,
  size: PropTypes.number.isRequired,
  style: ViewPropTypes.style,
  textSizeRatio: PropTypes.number.isRequired,
  textStyle: ViewPropTypes.style
}

export default function UserBadge ({
  name,
  size,
  style,
  textSizeRatio,
  textStyle
}) {
  const containerStyle = {
    borderRadius: size / 2,
    width: size,
    height: size,
    backgroundColor: randomColor(name)
  }
  const textSizeStyle = {
    fontSize: Math.floor(size / textSizeRatio)
  }
  const nameInitials = initials(name)
  return (
    <View style={[styles.container, containerStyle, style]}>
      <Text style={[styles.text, textSizeStyle, textStyle]}>
        {nameInitials}
      </Text>
    </View>
  )
}
