// @flow
import CONSTANTS from './constants'
import { getContacts } from './utils'
import { Platform, PermissionsAndroid } from 'react-native'

function requestContactPermissions () {
  return PermissionsAndroid.request(
    PermissionsAndroid.PERMISSIONS.READ_CONTACTS,
    {
      title: 'Nailit Contacts Permission',
      message: 'Nailint needs access to your contacts.'
    }
  )
}

export function fetchList () {
  return async dispatch => {
    try {
      if (Platform.OS === 'android') {
        await requestContactPermissions()
      }
      const contacts = await getContacts()
      dispatch({
        type: CONSTANTS.FETCH_LIST,
        payload: contacts
          .map(contact => ({ ...contact, id: contact.recordID }))
          .filter(
            contact => contact.phoneNumbers && contact.phoneNumbers.length
          )
          .filter(
            ({ givenName, middleName, familyName }) =>
              [givenName, middleName, familyName].filter(v => v).join(' ')
                .length
          )
      })
    } catch (e) {
      dispatch({
        type: CONSTANTS.FETCH_LIST,
        payload: []
      })
    }
  }
}

export function releaseList () {
  return {
    type: CONSTANTS.RELEASE_LIST
  }
}
