// @flow
import { fromJS, List, Map } from 'immutable'
import AddressBookSchema from './schema'
import {
  createEntitiesToMap,
  createPatchedEntitiesToMap
} from 'resources/utils'
import CONSTANTS from './constants'
import { normalize } from 'normalizr'
import schema from 'resources/schema'

export function entityToRecord ({
  deleted,
  recordID,
  emailAddresses,
  phoneNumbers,
  familyName,
  givenName,
  middleName,
  ...contact
}) {
  return new AddressBookSchema({
    id: recordID,
    email: (emailAddresses.find(({ email }) => email) || {}).email,
    cell: phoneNumbers
      .find(({ number }) => number)
      .number.replace('(', '')
      .replace(')', ''),
    name: [givenName, middleName, familyName].filter(v => v).join(' '),
    ...contact
  })
}

export const entitiesToMap = createEntitiesToMap('addressbook', entityToRecord)
export const partialEntitiesToMap = createPatchedEntitiesToMap(
  'addressbook',
  entityToRecord
)

export default {
  [CONSTANTS.RELEASE_LIST]: state =>
    state.set('addressbook', new Map()).set(
      '_addressbook',
      new Map({
        list: List(),
        hasLoaded: false
      })
    ),
  [CONSTANTS.FETCH_LIST]: (state, { payload }) => {
    const { result, entities } = normalize(payload, [schema.addressbook])
    const addressbook = entitiesToMap(entities, result)
    const _addressbook = state
      .get('_addressbook')
      .set('_list', fromJS(result))
      .set('hasLoaded', true)
    return state.merge({
      addressbook,
      _addressbook
    })
  }
}
