// @flow
import humps from 'humps'
import { UserSelectors } from 'resources/user'
import CONSTANTS from './constants'
import * as ContactApi from './api'

export function fetchRecentList () {
  return async (dispatch, getState) => {
    const userId = UserSelectors.currentUserId(getState())
    try {
      const response = await ContactApi.fetchRecentList({ userId })
      const contacts = Object.keys(response.data).map(name => ({
        name,
        ...humps.camelizeKeys(response.data[name])
      }))
      dispatch({
        type: CONSTANTS.FETCH_RECENT_LIST,
        payload: contacts
      })
    } catch (e) {
      console.error('Contacts recent list error', e)
    }
  }
}

export function addContact ({ name, phone, email, projectId }) {
  return async (dispatch, getState) => {
    const userId = UserSelectors.currentUserId(getState())
    try {
      const response = await ContactApi.addContact({
        name,
        phone,
        email,
        projectId,
        userId
      })
      return response.data
    } catch (e) {
      console.error('addContact error', e)
    }
  }
}
