// @flow
import { createAction } from 'redux-actions'
import CONSTANTS from './constants'
import { normalizeUsers } from 'utils/normalizeusers'
import { normalizeProject } from 'utils/normalizeproject'
import generateUUID from 'utils/generateuuid'
import { UserSelectors } from 'resources/user'
import * as InboxApi from './api'

export const setListLoading = createAction(CONSTANTS.SET_LIST_LOADING)

export function fetchList ({ projectId = 0 }) {
  return async (dispatch, getState) => {
    const userId = UserSelectors.currentUserId(getState())
    try {
      dispatch(setListLoading(true))
      const response = await InboxApi.fetchInbox({ projectId, userId })
      const cleanedResponse = {
        ...response,
        data: response.data
          .filter(inbox => inbox.conversationId) // this is because api returns { userTwoName: "USER DELETED" }
          .map(inbox => ({
            ...inbox,
            id: generateUUID(),
            conversation: inbox.conversationId.toString(),
            partecipants: normalizeUsers(inbox),
            project: normalizeProject(inbox)
          }))
      }
      dispatch({
        type: CONSTANTS.FETCH_LIST,
        payload: cleanedResponse
      })
    } catch (e) {
      console.error('Inbox error', e)
    } finally {
      dispatch(setListLoading(false))
    }
  }
}

export function markRead ({ conversationId }) {
  return {
    type: CONSTANTS.MARK_READ,
    payload: conversationId
  }
}
