// @flow
import { fromJS } from 'immutable'
import { normalize } from 'normalizr'
import CONSTANTS from './constants'
import schema from 'resources/schema'
import InboxSchema from './schema'
import {
  createEntitiesToMap,
  createPatchedEntitiesToMap
} from 'resources/utils'
import { ProjectReducers } from 'resources/project'
import { UserReducers } from 'resources/user'

export function entityToRecord (entity) {
  const {
    partecipants,
    trades,
    unread,
    latestMessage,
    roomId,
    ...inbox
  } = entity
  return new InboxSchema({
    ...inbox,
    latestMessage: (latestMessage || '').trim(),
    unread: Boolean(unread),
    partecipants: fromJS(partecipants),
    trades: fromJS(trades),
    room: roomId
  })
}

export const entitiesToMap = createEntitiesToMap('inbox', entityToRecord)
export const partialEntitiesToMap = createPatchedEntitiesToMap(
  'inbox',
  entityToRecord
)

export default {
  [CONSTANTS.SET_LIST_LOADING] (state, { payload }) {
    return state.setIn(['_inbox', 'isListLoading'], payload)
  },
  [CONSTANTS.FETCH_LIST] (state, { payload }) {
    const { nextPage, previousPage, count, data } = payload
    const { result, entities } = normalize(data, [schema.inbox])
    const inbox = entitiesToMap(entities, result)
    const _inbox = state
      .get('_inbox')
      .set('_list', fromJS(result))
      .set('nextPage', nextPage)
      .set('previousPage', previousPage)
      .set('count', count)
    // related resources
    const projects = state.projects.mergeDeep(
      ProjectReducers.partialEntitiesToMap(state.projects, entities)
    )
    const users = state.users.mergeDeep(
      UserReducers.partialEntitiesToMap(state.users, entities)
    )
    return state
      .set('inbox', fromJS(inbox))
      .set('_inbox', _inbox)
      .merge({
        projects,
        users
      })
  },

  [CONSTANTS.MARK_READ] (state, { payload }) {
    const inboxIdx = state
      .get('inbox')
      .findKey(inbox => inbox.get('conversation') === payload)
    return state.setIn(['inbox', inboxIdx, 'unread'], false)
  }
}
