// @flow
import CONSTANTS from './constants'
import { UserSelectors } from 'resources/user'
import * as ProjectApi from './api'

export function fetchList () {
  return async (dispatch, getState) => {
    try {
      const userId = UserSelectors.currentUserId(getState())
      const response = await ProjectApi.fetchList({ userId })
      const { data } = response
      dispatch({
        type: CONSTANTS.FETCH_LIST,
        payload: data.projects
      })
    } catch (e) {
      // TODO: Send this to sentry
      console.error('Project error', e)
    }
  }
}

export function fetchInfo ({ projectId }) {
  return async (dispatch, getState) => {
    try {
      const userId = UserSelectors.currentUserId(getState())
      const response = await ProjectApi.fetchInfo({ projectId, userId })
      const { data } = response
      dispatch({
        type: CONSTANTS.FETCH_INFO,
        payload: {
          isSub: data.isSub,
          canPay: data.canPay,
          ...data.project
        }
      })
    } catch (e) {
      // TODO: Send this to sentry
      console.log('Project error', e)
    }
  }
}

export function createProject ({ name, lat, long, address }) {
  return async (dispatch, getState) => {
    try {
      const state = getState()
      const userId = UserSelectors.currentUserId(state)
      const currentUser = UserSelectors.users(state).get(userId)
      await ProjectApi.createProject({
        name,
        userId,
        lat,
        long,
        email: currentUser.get('email'),
        phoneNumber: currentUser.get('cell'),
        location: address
      })
    } catch (e) {
      // TODO: Send this to sentry
      console.log('Project error', e)
    }
  }
}

export function editProject ({
  name,
  lat,
  long,
  email,
  phoneNumber,
  address,
  contacts,
  projectId
}) {
  return async (dispatch, getState) => {
    try {
      const state = getState()
      const userId = UserSelectors.currentUserId(state)
      await ProjectApi.createProject({
        name,
        userId,
        lat,
        long,
        projectId,
        contacts: contacts,
        email,
        phoneNumber,
        location: address
      })
    } catch (e) {
      // TODO: Send this to sentry
      console.log('Project error', e)
    }
  }
}

export function broadcastMessage ({ projectId, message }) {
  return (dispatch, getState) => {
    const state = getState()
    const userId = UserSelectors.currentUserId(state)
    return ProjectApi.broadcastMessage({ userId, projectId, message })
  }
}
