// @flow
import CONSTANTS from './constants' // eslint-disable-line no-undef
import ProjectSchema from './schema'
import { fromJS } from 'immutable'
import { normalize } from 'normalizr'
import { ContactReducers } from 'resources/contact'
import schema from 'resources/schema'
import {
  createEntitiesToMap,
  createPatchedEntitiesToMap
} from 'resources/utils'

export function entityToRecord (entity) {
  const { id, userId, contacts, lat, long, name, ...project } = entity
  const safeContacts = contacts
    ? Array.isArray(contacts) ? contacts : [contacts]
    : []
  return new ProjectSchema({
    id: id.toString(),
    name: name || 'No name',
    contacts: fromJS(safeContacts),
    lat: parseFloat(lat, 10),
    long: parseFloat(long, 10),
    owner: userId,
    ...project
  })
}

export const entitiesToMap = createEntitiesToMap('projects', entityToRecord)
export const partialEntitiesToMap = createPatchedEntitiesToMap(
  'projects',
  entityToRecord
)

export default {
  [CONSTANTS.FETCH_LIST] (state, { payload }) {
    const { entities, result } = normalize(payload, [schema.project])
    const projects = entitiesToMap(entities, result)
    const _projects = state._projects.merge({
      _list: fromJS(result),
      hasListLoaded: true
    })
    return state.mergeDeep({
      projects,
      _projects
    })
  },
  [CONSTANTS.FETCH_INFO] (state, { payload }) {
    const { entities, result } = normalize(payload, schema.project)
    const projects = entitiesToMap(entities)
    const contacts = ContactReducers.entitiesToMap(entities)
    const _projects = state._projects.merge({
      hasLoaded: fromJS({ [result]: true })
    })
    return state.mergeDeep({
      projects,
      contacts,
      _projects
    })
  }
}
