// @flow
import CONSTANTS from './constants'
import { UserSelectors } from 'resources/user'
import * as ProjectAudioApi from './api'

export function fetchList ({ projectId }) {
  return async (dispatch, getState) => {
    const userId = UserSelectors.currentUserId(getState())
    try {
      const response = await ProjectAudioApi.fetchAudio({ projectId, userId })
      dispatch({
        type: CONSTANTS.FETCH_LIST,
        payload: {
          audio: response.data.audio || [],
          projectId
        }
      })
    } catch (e) {
      console.error('Project Audio error', e)
    }
  }
}

export function uploadAudio ({ projectId, filename, filepath }) {
  return async dispatch => {
    try {
      await ProjectAudioApi.uploadAudio({
        projectId,
        filename,
        filepath
      })
    } catch (e) {
      console.error('Project Audio error', e)
    }
  }
}

export function destroyAudio ({ imageId, projectId }) {
  return async dispatch => {
    try {
      dispatch({
        type: CONSTANTS.DESTROY_AUDIO,
        payload: {
          id: imageId,
          projectId
        }
      })
      const images = [{ id: imageId }]
      await ProjectAudioApi.destroyAudio({ images })
    } catch (e) {
      console.error('Project Audio error', e)
    }
  }
}
