// @flow
import { fromJS } from 'immutable'
import { normalize } from 'normalizr'
import CONSTANTS from './constants'
import schema from 'resources/schema'
import ProjectAudioSchema from './schema'
import {
  createEntitiesToMap,
  createPatchedEntitiesToMap
} from 'resources/utils'

export function entityToRecord ({ deleted, ...entity }) {
  return new ProjectAudioSchema({
    deleted: Boolean(deleted),
    ...entity
  })
}

export const entitiesToMap = createEntitiesToMap('audio', entityToRecord)
export const partialEntitiesToMap = createPatchedEntitiesToMap(
  'audio',
  entityToRecord
)

export default {
  [CONSTANTS.FETCH_LIST] (state, { payload }) {
    const { entities, result } = normalize(payload.audio, [schema.projectaudio])
    const newAudio = entitiesToMap(entities)
    const projectaudio = state.projectaudio.merge(newAudio)
    const _projectaudio = state._projectaudio
      .setIn(['hasLoaded', payload.projectId], true)
      .setIn(['project', payload.projectId], fromJS(result))
    return state.merge({
      _projectaudio,
      projectaudio
    })
  },
  [CONSTANTS.DESTROY_AUDIO] (state, { payload }) {
    const { id, projectId } = payload
    const projectaudio = state.projectaudio.remove(id)
    const filteredList = state._projectaudio
      .getIn(['project', projectId])
      .filter(fileId => fileId !== id)
    const _projectaudio = state._projectaudio.setIn(
      ['project', projectId],
      filteredList
    )
    return state.merge({
      _projectaudio,
      projectaudio
    })
  }
}
