// @flow
import CONSTANTS from './constants'
import { UserSelectors } from 'resources/user'
import * as ProjectFileApi from './api'

export function fetchList ({ projectId }) {
  return async (dispatch, getState) => {
    const userId = UserSelectors.currentUserId(getState())
    try {
      const response = await ProjectFileApi.fetchFiles({ projectId, userId })
      dispatch({
        type: CONSTANTS.FETCH_LIST,
        payload: {
          files: response.data.files || [],
          projectId
        }
      })
    } catch (e) {
      console.error('Project File error', e)
    }
  }
}

export function uploadFile ({ projectId, filename, filepath }) {
  return async dispatch => {
    try {
      return ProjectFileApi.uploadFile({
        projectId,
        filename,
        filepath
      })
    } catch (e) {
      console.error('Project File error', e)
    }
  }
}

export function destroyFile ({ imageId, projectId }) {
  return async dispatch => {
    try {
      dispatch({
        type: CONSTANTS.DESTROY_IMAGE,
        payload: {
          id: imageId,
          projectId
        }
      })
      const images = [{ id: imageId }]
      await ProjectFileApi.destroyFiles({ images })
    } catch (e) {
      console.error('Project File error', e)
    }
  }
}
