// @flow
import { fromJS } from 'immutable'
import { normalize } from 'normalizr'
import CONSTANTS from './constants'
import schema from 'resources/schema'
import ProjectFileSchema from './schema'
import {
  createEntitiesToMap,
  createPatchedEntitiesToMap
} from 'resources/utils'

export function entityToRecord ({ deleted, ...entity }) {
  return new ProjectFileSchema({
    deleted: Boolean(deleted),
    ...entity
  })
}

export const entitiesToMap = createEntitiesToMap('files', entityToRecord)
export const partialEntitiesToMap = createPatchedEntitiesToMap(
  'files',
  entityToRecord
)

export default {
  [CONSTANTS.FETCH_LIST] (state, { payload }) {
    const { entities, result } = normalize(payload.files, [schema.projectfiles])
    const newImages = entitiesToMap(entities)
    const projectfile = state.projectfile.merge(newImages)
    const _projectfile = state._projectfile
      .setIn(['hasLoaded', payload.projectId], true)
      .setIn(['project', payload.projectId], fromJS(result))
    return state.merge({
      _projectfile,
      projectfile
    })
  },
  [CONSTANTS.DESTROY_IMAGE] (state, { payload }) {
    const { id, projectId } = payload
    const projectfile = state.projectfile.remove(id)
    const filteredList = state._projectfile
      .getIn(['project', projectId])
      .filter(imageId => imageId !== id)
    const _projectfile = state._projectfile.setIn(
      ['project', projectId],
      filteredList
    )
    return state.merge({
      _projectfile,
      projectfile
    })
  }
}
