// @flow
import CONSTANTS from './constants'
import { UserSelectors } from 'resources/user'
import * as ProjectImageApi from './api'

export function fetchList ({ projectId }) {
  return async (dispatch, getState) => {
    const userId = UserSelectors.currentUserId(getState())
    try {
      const response = await ProjectImageApi.fetchImages({ projectId, userId })
      dispatch({
        type: CONSTANTS.FETCH_LIST,
        payload: {
          images: response.data.images || [],
          projectId
        }
      })
    } catch (e) {
      console.error('Project Image error', e)
    }
  }
}

export function uploadImage ({ projectId, filename, filepath }) {
  return async dispatch => {
    return ProjectImageApi.uploadImage({
      projectId,
      filename,
      filepath
    })
  }
}

export function destroyImage ({ imageId, projectId }) {
  return async dispatch => {
    try {
      dispatch({
        type: CONSTANTS.DESTROY_IMAGE,
        payload: {
          id: imageId,
          projectId
        }
      })
      const images = [{ id: imageId }]
      await ProjectImageApi.destroyImages({ images })
    } catch (e) {
      console.error('Project Image error', e)
    }
  }
}
