// @flow
import { fromJS } from 'immutable'
import { normalize } from 'normalizr'
import CONSTANTS from './constants'
import schema from 'resources/schema'
import ProjectImageSchema from './schema'
import {
  createEntitiesToMap,
  createPatchedEntitiesToMap
} from 'resources/utils'

export function entityToRecord ({ deleted, ...entity }) {
  return new ProjectImageSchema({
    deleted: Boolean(deleted),
    ...entity
  })
}

export const entitiesToMap = createEntitiesToMap('images', entityToRecord)
export const partialEntitiesToMap = createPatchedEntitiesToMap(
  'images',
  entityToRecord
)

export default {
  [CONSTANTS.FETCH_LIST] (state, { payload }) {
    const { entities, result } = normalize(payload.images, [
      schema.projectimage
    ])
    const newImages = entitiesToMap(entities)
    const projectimage = state.projectimage.merge(newImages)
    const _projectimage = state._projectimage
      .setIn(['hasLoaded', payload.projectId], true)
      .setIn(['project', payload.projectId], fromJS(result))
    return state.merge({
      _projectimage,
      projectimage
    })
  },
  [CONSTANTS.DESTROY_IMAGE] (state, { payload }) {
    const { id, projectId } = payload
    const projectimage = state.projectimage.remove(id)
    const filteredList = state._projectimage
      .getIn(['project', projectId])
      .filter(imageId => imageId !== id)
    const _projectimage = state._projectimage.setIn(
      ['project', projectId],
      filteredList
    )
    return state.merge({
      _projectimage,
      projectimage
    })
  }
}
