// @flow
import { UserSelectors, UserActions } from 'resources/user'
import CONSTANTS from './constants'
import * as TradeApi from './api'

export function reset () {
  return {
    type: CONSTANTS.RESET
  }
}

export function fetchForProject ({ projectId }) {
  return async (dispatch, getState) => {
    try {
      const currentUserId = UserSelectors.currentUserId(getState())
      const response = await TradeApi.fetchForProject({ projectId })
      const { data } = response
      const tasks = data.tasks || []
      await Promise.all(
        tasks.map(async task => {
          const responseTask = await TradeApi.fetchInfoForProject({
            projectId,
            projectTaskId: task.projectTaskId,
            userId: currentUserId
          })
          const { data } = responseTask
          task.taskSub = (data.subs || []).filter(value => value)
          await Promise.all(
            task.taskSub.map(({ id }) => dispatch(UserActions.fetchInfo(id)))
          )
        })
      )
      dispatch({
        type: CONSTANTS.FETCH_LIST_FOR_PROJECT,
        payload: {
          projectId,
          tasks
        }
      })
    } catch (e) {
      // TODO: Send this to sentry
      console.error('Task error', e)
    }
  }
}

export function fetchList () {
  return async dispatch => {
    try {
      const response = await TradeApi.fetchList()
      const { data } = response
      dispatch({
        type: CONSTANTS.FETCH_LIST,
        payload: {
          tasks: data.tasks || []
        }
      })
    } catch (e) {
      // TODO: Send this to sentry
      console.error('Task list error', e)
    }
  }
}

export function addPeopleToTrade ({ projectId, taskId, subs }) {
  return async (dispatch, getState) => {
    try {
      const response = await TradeApi.addPeopleToTrade({
        projectId,
        taskId,
        subs
      })
      dispatch(fetchForProject({ projectId }))
      return response
    } catch (e) {
      // TODO: Send this to sentry
      console.error('addPeopleToTrade error', e)
    }
  }
}

export function removePeopleFromTrade ({ projectId, taskId, subs }) {
  return async (dispatch, getState) => {
    try {
      await TradeApi.removePeopleFromTrade({
        projectId,
        taskId,
        subs
      })
      await dispatch(fetchForProject({ projectId }))
    } catch (e) {
      // TODO: Send this to sentry
      console.error('addPeopleToTrade error', e)
    }
  }
}
