// @flow
import CONSTANTS from './constants' // eslint-disable-line no-undef
import TaskSchema from './schema'
import { List, fromJS } from 'immutable'
import { normalize } from 'normalizr'
import { BidReducers } from 'resources/bid'
import { SubReducers } from 'resources/sub'
import schema from 'resources/schema'
import {
  createEntitiesToMap,
  createPatchedEntitiesToMap
} from 'resources/utils'

export function entityToRecord (entity) {
  const {
    id,
    projectTaskId,
    taskName,
    name,
    categories,
    bids,
    subs,
    url,
    taskSub,
    ...task
  } = entity
  return new TaskSchema({
    id: id.toString(),
    projectTask: projectTaskId,
    name: taskName || name,
    bids: fromJS(bids),
    subs: fromJS(subs),
    taskSub: fromJS(taskSub || []),
    url: url || '',
    categories: fromJS(categories) || List(),
    ...task
  })
}

export const entitiesToMap = createEntitiesToMap('tasks', entityToRecord)
export const partialEntitiesToMap = createPatchedEntitiesToMap(
  'tasks',
  entityToRecord
)

export default {
  [CONSTANTS.RESET] (state) {
    return state.set('tasks', new Map()).set(
      '_tasks',
      fromJS({
        _project: {},
        hasProjectLoaded: {}
      })
    )
  },
  [CONSTANTS.FETCH_LIST_FOR_PROJECT] (state, { payload }) {
    const { projectId } = payload
    const { entities, result } = normalize(payload.tasks, [schema.task])
    const tasks = entitiesToMap(entities, result)
    const bids = BidReducers.entitiesToMap(entities)
    const subs = SubReducers.entitiesToMap(entities)
    const _tasks = state._tasks.mergeDeep({
      _project: {
        [projectId]: fromJS(result)
      },
      hasProjectLoaded: {
        [projectId]: true
      }
    })
    return state.mergeDeep({
      bids,
      subs,
      tasks,
      _tasks
    })
  },
  [CONSTANTS.FETCH_LIST] (state, { payload }) {
    const { entities, result } = normalize(payload.tasks, [schema.task])
    const tasks = entitiesToMap(entities, result)
    const bids = BidReducers.entitiesToMap(entities)
    const subs = SubReducers.entitiesToMap(entities)
    const _tasks = state._tasks.mergeDeep({
      _tasks: fromJS(result),
      hasListLoaded: true
    })
    return state.mergeDeep({
      bids,
      subs,
      tasks,
      _tasks
    })
  }
}
