// @flow
import CONSTANTS from './constants'
import * as UserApi from './api'
import { DEVELOPMENT_ENV } from '../../config'
import { post } from 'utils/http'

export function setCurrentUser (userId) {
  return {
    type: CONSTANTS.SET_CURRENT_ID,
    payload: userId
  }
}

export function fetchInfo (userId) {
  return async dispatch => {
    try {
      const response = await UserApi.fetchInfo({ userId })
      const { user } = response.data
      const safeUser = user || { id: userId }
      dispatch({
        type: CONSTANTS.FETCH_INFO,
        payload: {
          id: safeUser.id.toString(),
          ...safeUser
        }
      })
    } catch (error) {
      // TODO: Add toast errors and sentry
      if (DEVELOPMENT_ENV) {
        console.log(error)
        console.error(`error fetching user ${userId}`, error)
      }
    }
  }
}

export function registerToken ({ deviceToken, userId, deviceType }) {
  return async dispatch => {
    await post('/add/device_token', {
      deviceToken,
      deviceType,
      userId
    })
  }
}

export function unregisterToken ({ deviceToken, userId }) {
  return async dispatch => {}
}
