// @flow
import { createSelector } from 'reselect'
import { resources } from './selectors'

export function createResourceSelector (name) {
  return createSelector(
    [resources],
    resources =>
      Array.isArray(name) ? resources.getIn(name) : resources.get(name)
  )
}

export function listToMap (resources, entityToRecord, list) {
  return list.reduce((map, id) => {
    map[id] = entityToRecord(resources[id])
    return map
  }, {})
}

export function createEntitiesToMap (entityName, entityToRecord) {
  return function entitiesToMap (entities, list) {
    const resources = entityName in entities ? entities[entityName] : {}
    return listToMap(resources, entityToRecord, list || Object.keys(resources))
  }
}

export function createPatchedEntitiesToMap (entityName, entityToRecord) {
  return function patchedEntitiesToMap (records, entities, list) {
    const resources = entityName in entities ? entities[entityName] : {}
    return listToMap(
      resources,
      entity => entityToPatchedRecord(records, entity, entityToRecord),
      list || Object.keys(resources)
    )
  }
}

export function entityToPatchedRecord (records, partialEntity, entityToRecord) {
  const record = records.get(partialEntity.id)
  return record
    ? entityToRecord(
      record
        .toMap()
        .merge(partialEntity)
        .toJS()
    )
    : entityToRecord(partialEntity)
}

export function idToString (ids) {
  if (Array.isArray(ids)) {
    return ids.map(id => id.toString())
  }
  throw new Error('idtostring: not array')
}
