// @flow
import { StackNavigator, DrawerNavigator } from 'react-navigation'
import Splashscreen from 'screens/Splashscreen'
import Login from 'screens/Login'
import Inbox from 'screens/Inbox'
import Sidemenu from 'screens/Sidemenu'
import Verifypin from 'screens/Verifypin'
import ProjectList from 'screens/ProjectList'
import ProjectInfo from 'screens/ProjectInfo'
import {
  ProfileInfo,
  ProfilePassword,
  ProfileNotification
} from 'screens/Profile'
import Account from 'screens/Account'
import Conversation from 'screens/Conversation'
import CreateConversation from 'screens/CreateConversation'
import ReferFriend from 'screens/ReferFriend'
import Support from 'screens/Support'
import SelectTrade from 'screens/SelectTrade'
import SelectProject from 'screens/SelectProject'
import AddToConversation from 'screens/AddToConversation'
import ProjectImage from 'screens/ProjectImage'
import ProjectAudio from 'screens/ProjectAudio'
import ProjectFile from 'screens/ProjectFile'
import ProjectCreate from 'screens/ProjectCreate'
import ProjectEdit from 'screens/ProjectEdit'
import AddAddressBookContact from 'screens/AddAddressBookContact'
import AddManualContact from 'screens/AddManualContact'
import AddContact from 'screens/AddContact'
import SCREENS from './screens'
import COLORS from '../colors'
export { default as SCREENS } from './screens'

const defaultNavigationOptions = {
  headerStyle: {
    backgroundColor: COLORS.Primary
  },
  headerTitleStyle: {
    fontSize: 18,
    alignSelf: 'center',
    zIndex: 1
  },
  headerTintColor: COLORS.PrimaryContrast,
  headerBackTitle: 'Back'
}

export const SignedOutNavigator = StackNavigator(
  {
    [SCREENS.LOGIN]: {
      screen: Login,
      name: 'Login'
    },
    [SCREENS.VERIFY_PIN]: {
      screen: Verifypin,
      name: 'Verifypin'
    }
  },
  {
    mode: 'modal',
    initialRouteName: SCREENS.LOGIN,
    headerMode: 'screen',
    navigationOptions: defaultNavigationOptions
  }
)

const createScreen = (screen, name) => ({ screen, name })

export const SignedInNavigator = StackNavigator(
  {
    [SCREENS.ACCOUNT]: createScreen(Account, 'account'),
    [SCREENS.INBOX]: createScreen(Inbox, 'inbox'),
    [SCREENS.CREATE_CONVERSATION]: createScreen(
      CreateConversation,
      'createconversation'
    ),
    [SCREENS.CONVERSATION]: createScreen(Conversation, 'conversation'),
    [SCREENS.PROFILE_INFO]: createScreen(ProfileInfo, 'profileinfo'),
    [SCREENS.PROFILE_PASSWORD]: createScreen(
      ProfilePassword,
      'profilepassword'
    ),
    [SCREENS.PROFILE_NOTIFICATION]: createScreen(
      ProfileNotification,
      'profilenotification'
    ),
    [SCREENS.PROJECT_INFO]: createScreen(ProjectInfo, 'projectinfo'),
    [SCREENS.PROJECT_LIST]: createScreen(ProjectList, 'projectlist'),
    [SCREENS.REFER_FRIEND]: createScreen(ReferFriend, 'referfriend'),
    [SCREENS.SUPPORT]: createScreen(Support, 'support'),
    [SCREENS.SELECT_TRADE]: createScreen(SelectTrade, 'selectrade'),
    [SCREENS.SELECT_PROJECT]: createScreen(SelectProject, 'selectproject'),
    [SCREENS.PROJECT_IMAGE]: createScreen(ProjectImage, 'projectimage'),
    [SCREENS.PROJECT_AUDIO]: createScreen(ProjectAudio, 'projectaudio'),
    [SCREENS.PROJECT_FILE]: createScreen(ProjectFile, 'projectfile'),
    [SCREENS.PROJECT_CREATE]: createScreen(ProjectCreate, 'projectcreate'),
    [SCREENS.PROJECT_EDIT]: createScreen(ProjectEdit, 'projectedit'),
    [SCREENS.ADD_CONTACT]: createScreen(AddContact, 'addcontact'),
    [SCREENS.ADD_MANUAL_CONTACT]: createScreen(
      AddManualContact,
      'addmanualcontact'
    ),
    [SCREENS.ADD_ADDRESSBOOK_CONTACT]: createScreen(
      AddAddressBookContact,
      'addaddressbookcontact'
    ),
    [SCREENS.ADD_TO_CONVERSATION]: createScreen(
      AddToConversation,
      'addtoconversation'
    )
  },
  {
    initialRouteName: SCREENS.PROJECT_LIST,
    headerMode: 'screen',
    navigationOptions: defaultNavigationOptions
  }
)

export default StackNavigator(
  {
    [SCREENS.SPLASHSCREEN]: {
      screen: Splashscreen
    },
    SignedIn: {
      screen: DrawerNavigator(
        {
          Drawer: {
            name: 'Drawer',
            screen: SignedInNavigator
          }
        },
        {
          initialRouteName: 'Drawer',
          drawerWidth: 250,
          drawerPosition: 'left',
          contentComponent: Sidemenu,
          drawerOpenRoute: 'DrawerOpen',
          drawerCloseRoute: 'DrawerClose',
          drawerToggleRoute: 'DrawerToggle'
        }
      )
    },
    SignedOut: {
      screen: SignedOutNavigator
    }
  },
  {
    headerMode: 'none',
    header: { visible: false },
    mode: 'modal',
    navigationOptions: {
      gesturesEnabled: false
    }
  }
)
