// @flow
import React, { Component } from 'react'
import PropTypes from 'prop-types'
import { TouchableOpacity, View, Text } from 'react-native'
import { Map, List } from 'immutable'
import AtoZList from 'react-native-atoz-list'
import { LoaderScreen } from 'components/Loader'
import StyleSheet from 'react-native-extended-stylesheet'
import font from 'utils/font'

const styles = StyleSheet.create({
  wrapper: {
    flex: 1,
    backgroundColor: '$White'
  },
  header: {
    height: 25,
    justifyContent: 'center',
    backgroundColor: '$LightBackground',
    paddingLeft: 10
  },
  headerText: {
    fontSize: 13,
    ...font({ weight: 'bold' })
  },
  cell: {
    height: 40,
    borderBottomColor: '$LightDivider',
    borderBottomWidth: 1,
    backgroundColor: '$White',
    flexDirection: 'row',
    alignItems: 'center'
  },
  name: {
    fontSize: 15,
    marginLeft: 10
  }
})

export default class AddAddressBookContact extends Component {
  static navigationOptions = {
    title: 'From Address Book'
  }

  static propTypes = {
    addressBookList: PropTypes.instanceOf(List).isRequired,
    addressBook: PropTypes.instanceOf(Map).isRequired,
    hasLoaded: PropTypes.bool.isRequired
  }

  constructor (props) {
    super(props)
    this._renderCellComponent = this._renderCellComponent.bind(this)
  }

  componentWillUnmount () {
    this.props.releaseList()
  }

  _renderCellComponent (data) {
    return (
      <TouchableOpacity onPress={() => this.props.addContact(data)}>
        <View style={styles.cell}>
          <Text style={styles.name}>{data.get('name')}</Text>
        </View>
      </TouchableOpacity>
    )
  }

  _renderSectionComponent (data) {
    return (
      <View style={styles.header}>
        <Text style={styles.headerText}>{data.sectionId}</Text>
      </View>
    )
  }

  render () {
    const { hasLoaded, addressBook, addressBookList } = this.props
    if (!hasLoaded) {
      return <LoaderScreen />
    }
    const data = addressBookList
      .sort((idA, idB) => {
        const contactA = addressBook.get(idA)
        const contactB = addressBook.get(idB)
        return contactA.get('name').localeCompare(contactB.get('name'))
      })
      .reduce((contacts, contactId) => {
        const contact = addressBook.get(contactId)
        const initial = contact.get('name')[0]
        if (!contacts[initial]) {
          contacts[initial] = []
        }
        contacts[initial].push(contact)
        return contacts
      }, {})
    return (
      <View style={styles.wrapper}>
        <AtoZList
          sectionHeaderHeight={25}
          cellHeight={40}
          data={data}
          renderCell={this._renderCellComponent}
          renderSection={this._renderSectionComponent}
        />
      </View>
    )
  }
}
