// @flow
import { Record } from 'immutable'
import { Alert } from 'react-native'
import createReducer from 'utils/createreducer'
import createConstants from 'utils/createconstants'
import createViewSelector from 'utils/createviewselector'
import { AddressBookActions, AddressBookSelectors } from 'resources/addressbook'
import { RouteActions } from 'routes'

export const CONSTANTS = createConstants('SCREEN_ADDADDRESSBOOKCONTACT', {
  RESET: null,
  SET_PROJECT: null,
  SET_SAVE: null
})

export const actions = {
  reset () {
    return {
      type: CONSTANTS.RESET
    }
  },
  initialize ({ onSave, projectId }) {
    return dispatch => {
      dispatch(actions.reset())
      dispatch(actions.setProject(projectId))
      dispatch(actions.setSave(onSave))
      dispatch(AddressBookActions.fetchList())
    }
  },
  releaseList () {
    return AddressBookActions.releaseList()
  },
  setSave (onSave) {
    return {
      type: CONSTANTS.SET_SAVE,
      payload: onSave
    }
  },
  setProject (projectId) {
    return {
      type: CONSTANTS.SET_PROJECT,
      payload: projectId
    }
  },
  addContact (contact) {
    return async (dispatch, getState) => {
      const onSave = selectors.onSave(getState())
      // const projectId = selectors.projectId(getState())
      try {
        // TODO: add person to project
        dispatch(
          onSave({
            name: contact.get('name'),
            cell: contact.get('cell'),
            email: contact.get('email')
          })
        )
        dispatch(RouteActions.back())
      } catch (error) {
        console.log(error)
        Alert.alert('Nailit', "There's been a error adding the team member")
      }
    }
  }
}

export const AddAddressBookContactState = Record({
  onSave: null,
  projectId: ''
})

export const reducer = createReducer(new AddAddressBookContactState(), {
  [CONSTANTS.RESET]: () => new AddAddressBookContactState(),
  [CONSTANTS.SET_PROJECT]: (state, { payload }) =>
    state.set('projectId', payload),
  [CONSTANTS.SET_SAVE]: (state, { payload }) => state.set('onSave', payload)
})

export const viewState = state => state.screens.addaddressbookcontact
export const viewSelector = createViewSelector(viewState)
export const projectId = viewSelector('projectId', '')
export const onSave = viewSelector('onSave')

export const selectors = {
  projectId,
  onSave,
  hasLoaded: AddressBookSelectors.hasLoaded,
  addressBookList: AddressBookSelectors.addressBookList,
  addressBook: AddressBookSelectors.addressbook
}
