// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { View, Text } from 'react-native'
import { Map, List } from 'immutable'
import Loader from 'components/Loader'
import ResourceList from 'components/ResourceList'
import { SolidButton } from 'components/Button'
import StyleSheet from 'react-native-extended-stylesheet'
import { SCREEN_WIDTH } from 'utils/device'

const styles = StyleSheet.create({
  wrapper: {
    flex: 1,
    backgroundColor: '$White'
  },
  row: {
    flexDirection: 'row',
    marginTop: 10,
    marginLeft: 10,
    marginRight: 10
  },
  firstRow: {
    height: 35
  },
  secondRow: {
    alignItems: 'center'
  },
  leftButton: {
    marginRight: 10,
    flex: 1,
    borderRadius: 5,
    paddingTop: 10,
    paddingBottom: 10,
    width: SCREEN_WIDTH / 2 - 15
  },
  rightButton: {
    flex: 1,
    borderRadius: 5,
    paddingTop: 10,
    paddingBottom: 10,
    width: SCREEN_WIDTH / 2 - 15
  },
  recent: {
    fontSize: 14,
    marginLeft: 20,
    marginTop: 5
  },
  line: {
    height: 1,
    marginRight: 20,
    marginLeft: 5,
    marginTop: 8,
    flex: 1,
    backgroundColor: '$Primary'
  }
})

AddContact.navigationOptions = {
  title: 'Add Contact'
}

AddContact.propTypes = {
  contacts: PropTypes.instanceOf(Map),
  contactsList: PropTypes.instanceOf(List)
}

export default function AddContact ({
  contacts,
  contactsList,
  toManualContact,
  toAddressBookContact,
  hasLoaded,
  isLoading,
  addContact
}) {
  return (
    <View style={styles.wrapper}>
      <View style={[styles.row, styles.firstRow]}>
        <SolidButton style={styles.leftButton} onPress={toAddressBookContact}>
          ADDRESS BOOK
        </SolidButton>
        <SolidButton style={styles.rightButton} onPress={toManualContact}>
          MANUAL CONTACT
        </SolidButton>
      </View>
      <View style={[styles.row, styles.secondRow]}>
        <Text style={styles.recent}>Recent Contacts</Text>
        <View style={styles.line} />
      </View>
      {!hasLoaded || isLoading ? (
        <Loader size={20} />
      ) : (
        <ResourceList
          resource={contacts}
          resourceList={contactsList}
          field='name'
          emptyIcon='ios-people-outline'
          emptyLabel='No recent contacts'
          onPress={addContact}
        />
      )}
    </View>
  )
}
