// @flow
import { Record } from 'immutable'
import createReducer from 'utils/createreducer'
import createConstants from 'utils/createconstants'
import createViewSelector from 'utils/createviewselector'
import { RouteActions } from 'routes'
import { ContactActions, ContactSelectors } from 'resources/contact'
import { TaskActions } from 'resources/task'
import createFilter from 'utils/createfilter'
import SCREENS from 'routes/screens'
import { createSelector } from 'reselect'

export const CONSTANTS = createConstants('SCREEN_ADDCONTACT', {
  RESET: null,
  SET_LOADING: null,
  SET_SEARCH: null,
  SET_SAVE: null,
  SET_PROJECT: null
})

export const actions = {
  reset () {
    return {
      type: CONSTANTS.RESET
    }
  },
  setLoading (loading) {
    return {
      type: CONSTANTS.SET_LOADING,
      payload: loading
    }
  },
  initialize ({ onSave, projectId }) {
    return (dispatch, getState) => {
      dispatch(actions.reset())
      dispatch(ContactActions.fetchRecentList())
      dispatch(actions.setSave(onSave))
      dispatch(actions.setProject(projectId))
    }
  },
  toManualContact () {
    return (dispatch, getState) => {
      const projectId = selectors.projectId(getState())
      dispatch(
        RouteActions.navigate(SCREENS.ADD_MANUAL_CONTACT, {
          projectId,
          onSave: actions.addManualContact
        })
      )
    }
  },
  toAddressBookContact () {
    return (dispatch, getState) => {
      const projectId = selectors.projectId(getState())
      dispatch(
        RouteActions.navigate(SCREENS.ADD_ADDRESSBOOK_CONTACT, {
          projectId,
          onSave: actions.addAddressBookContact
        })
      )
    }
  },
  setSearch (search) {
    return {
      type: CONSTANTS.SET_SEARCH,
      payload: search
    }
  },
  setSave (onSave) {
    return {
      type: CONSTANTS.SET_SAVE,
      payload: onSave
    }
  },
  setProject (projectId) {
    return {
      type: CONSTANTS.SET_PROJECT,
      payload: projectId
    }
  },
  addContact ({ id }) {
    return async (dispatch, getState) => {
      const contacts = selectors.contacts(getState())
      const contact = contacts.get(id)
      return dispatch(
        actions.addAddressBookContact({
          name: contact.get('name'),
          cell: contact.get('phone'),
          email: contact.get('email')
        })
      )
    }
  },
  addManualContact ({ name, cell, email }) {
    return actions.addAddressBookContact({ name, cell, email })
  },
  addAddressBookContact ({ name, cell, email }) {
    return async (dispatch, getState) => {
      const onSave = selectors.onSave(getState())
      const projectId = selectors.projectId(getState())
      dispatch(actions.setLoading(true))
      // add to trade
      await dispatch(
        TaskActions.addPeopleToTrade({
          taskId: 0,
          subs: [
            {
              name,
              cell
            }
          ],
          projectId: projectId
        })
      )
      dispatch(actions.setLoading(false))
      dispatch(
        onSave({
          name,
          cell,
          email
        })
      )
      dispatch(RouteActions.back())
    }
  }
}

export const AddContactState = Record({
  search: '',
  onSave: null,
  projectId: '',
  isLoading: false
})

export const reducer = createReducer(new AddContactState(), {
  [CONSTANTS.RESET]: () => new AddContactState(),
  [CONSTANTS.SET_SEARCH]: (state, { payload }) => {
    return state.set('search', payload)
  },
  [CONSTANTS.SET_LOADING]: (state, { payload }) => {
    return state.set('isLoading', payload)
  },
  [CONSTANTS.SET_PROJECT]: (state, { payload }) => {
    return state.set('projectId', payload)
  },
  [CONSTANTS.SET_SAVE]: (state, { payload }) => {
    return state.set('onSave', payload)
  }
})

export const viewState = state => state.screens.addcontact
export const viewSelector = createViewSelector(viewState)
export const search = viewSelector('search', '')
export const onSave = viewSelector('onSave')
export const projectId = viewSelector('projectId')
export const isLoading = viewSelector('isLoading', false)

export const filteredContactsList = createFilter(
  search,
  ContactSelectors.contacts,
  ContactSelectors.recentContactsList,
  ['name']
)

export const contactsList = createSelector(
  [filteredContactsList, ContactSelectors.contacts],
  (filteredContactsList, contacts) =>
    filteredContactsList.filter(
      contactId => contacts.getIn([contactId, 'phone'], '').length > 0
    )
)

export const selectors = {
  search,
  contacts: ContactSelectors.contacts,
  contactsList,
  onSave,
  projectId,
  isLoading,
  hasLoaded: ContactSelectors.hasRecentContactsListLoaded
}
