// @flow
import { Record } from 'immutable'
import { Alert } from 'react-native'
import createReducer from 'utils/createreducer'
import createConstants from 'utils/createconstants'
import createViewSelector from 'utils/createviewselector'
import isValidContact from 'utils/validcontact'
import * as RouteActions from 'routes/actions'

export const CONSTANTS = createConstants('SCREEN_ADDMANUALCONTACT', {
  RESET: null,
  SET_PROJECT: null,
  SET_SAVE: null,
  SET_NAME: null,
  SET_EMAIL: null,
  SET_PHONE: null
})

export const actions = {
  reset () {
    return {
      type: CONSTANTS.RESET
    }
  },
  initialize ({ onSave, projectId }) {
    return dispatch => {
      dispatch(actions.reset())
      dispatch(actions.setProject(projectId))
      dispatch(actions.setSave(onSave))
      dispatch(
        RouteActions.setParams({
          addContact: () => dispatch(actions.addContact())
        })
      )
    }
  },
  setSave (onSave) {
    return {
      type: CONSTANTS.SET_SAVE,
      payload: onSave
    }
  },
  setProject (projectId) {
    return {
      type: CONSTANTS.SET_PROJECT,
      payload: projectId
    }
  },
  setName (name) {
    return {
      type: CONSTANTS.SET_NAME,
      payload: name
    }
  },
  setEmail (email) {
    return {
      type: CONSTANTS.SET_EMAIL,
      payload: email
    }
  },
  setPhone (phone) {
    return {
      type: CONSTANTS.SET_PHONE,
      payload: phone
    }
  },
  addContact () {
    return async (dispatch, getState) => {
      const state = getState()
      const onSave = selectors.onSave(state)
      const name = selectors.name(state)
      // const email = selectors.email(state)
      const phone = selectors.phone(state)
      if (!isValidContact({ name, phone })) {
        alert('Incomplete contact')
        return
      }
      try {
        dispatch(
          onSave({
            name,
            cell: phone,
            email: ''
          })
        )
        dispatch(RouteActions.back())
      } catch (error) {
        console.log(error)
        Alert.alert('Nailit', "There's been a error adding the team member")
      }
    }
  }
}

export const AddManualContactState = Record({
  onSave: null,
  projectId: '',
  name: '',
  email: '',
  phone: ''
})

export const reducer = createReducer(new AddManualContactState(), {
  [CONSTANTS.RESET]: () => new AddManualContactState(),
  [CONSTANTS.SET_PROJECT]: (state, { payload }) =>
    state.set('projectId', payload),
  [CONSTANTS.SET_SAVE]: (state, { payload }) => state.set('onSave', payload),
  [CONSTANTS.SET_NAME]: (state, { payload }) => state.set('name', payload),
  [CONSTANTS.SET_EMAIL]: (state, { payload }) => state.set('email', payload),
  [CONSTANTS.SET_PHONE]: (state, { payload }) => state.set('phone', payload)
})

export const viewState = state => state.screens.addmanualcontact
export const viewSelector = createViewSelector(viewState)
export const projectId = viewSelector('projectId', '')
export const onSave = viewSelector('onSave')
export const name = viewSelector('name')
export const phone = viewSelector('phone')
export const email = viewSelector('email')

export const selectors = {
  name,
  phone,
  email,
  onSave,
  projectId
}
