// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { Map, List } from 'immutable'
import StyleSheet from 'react-native-extended-stylesheet'
import { View } from 'react-native'
import SearchBar from 'components/Search'
import COLORS from '../../colors'
import NavbarButton from 'components/NavbarButton'
import AddOptions from './components/AddOptions'
import RecentContactList from './components/RecentContactList'

const styles = StyleSheet.create({
  wrapper: {
    backgroundColor: '$White',
    flex: 1
  },
  container: {
    flex: 1,
    backgroundColor: '$White'
  },
  searchBar: {
    backgroundColor: '$LightBackground'
  },
  seachBox: {
    borderBottomColor: '$LightDivider'
  }
})

AddToConversation.navigationOptions = ({ navigation }) => ({
  title: 'Add to Conversation',
  headerRight: (
    <NavbarButton
      onPress={() => navigation.state.params.add()}
      name='md-create'
      size={25}
    >
      ADD
    </NavbarButton>
  )
})

AddToConversation.propTypes = {
  contacts: PropTypes.instanceOf(Map).isRequired,
  contactsList: PropTypes.instanceOf(List).isRequired,
  search: PropTypes.string.isRequired,
  setSearch: PropTypes.func.isRequired
}

export default function AddToConversation ({ setSearch, search, ...props }) {
  return (
    <View style={styles.wrapper}>
      <View style={styles.searchBar}>
        <SearchBar
          placeholder='Search'
          onChangeText={setSearch}
          useClearButton={false}
          onCancel={() => setSearch('')}
          style={styles.seachBox}
          textFieldBackgroundColor={COLORS.DarkBackground}
        />
        <AddOptions {...props} />
      </View>

      <RecentContactList {...props} />
    </View>
  )
}
