// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { FlatList } from 'react-native'
import { List, Map } from 'immutable'
import StyleSheet from 'react-native-extended-stylesheet'
import RecentContactListRow from './RecentContactListRow'

const styles = StyleSheet.create({
  container: {
    flex: 1
  }
})

RecentContactList.propTypes = {
  contacts: PropTypes.instanceOf(Map).isRequired,
  contactsList: PropTypes.instanceOf(List).isRequired,
  selection: PropTypes.instanceOf(List).isRequired,
  toggleContact: PropTypes.func.isRequired
}

export default function RecentContactList ({
  contacts,
  contactsList,
  toggleContact,
  selection
}) {
  const flattenedList = contactsList.toJS().map(id => ({ id }))
  const rowRenderer = ({ item }) => (
    <RecentContactListRow
      {...item}
      contacts={contacts}
      toggleContact={toggleContact}
      selection={selection}
    />
  )

  return (
    <FlatList
      data={flattenedList}
      keyExtractor={(_, index) => index.toString()}
      renderItem={rowRenderer}
      style={styles.container}
    />
  )
}
