// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { List, Map } from 'immutable'
import { TouchableOpacity, View, Text } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import COLORS from '../../../colors'
import Icon from 'components/Icon'

const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    alignItems: 'center',
    height: 40,
    paddingLeft: 5,
    paddingRight: 5,
    borderBottomWidth: 1,
    borderBottomColor: '$DarkDivider'
  },
  textContainer: {
    flex: 1,
    marginLeft: 15,
    marginRight: 15,
    justifyContent: 'center',
    flexDirection: 'column'
  },
  selection: {
    borderRadius: 15,
    borderWidth: 1,
    borderColor: '$Secondary',
    width: 17,
    height: 17,
    justifyContent: 'center',
    alignItems: 'center'
  }
})

RecentContactListRow.propTypes = {
  contacts: PropTypes.instanceOf(Map).isRequired,
  toggleContact: PropTypes.func.isRequired,
  selection: PropTypes.instanceOf(List).isRequired,
  id: PropTypes.string.isRequired
}

export default function RecentContactListRow ({
  contacts,
  toggleContact,
  selection,
  id
}) {
  const contact = contacts.get(id)
  const selected = selection.includes(id)
  return (
    <TouchableOpacity onPress={() => toggleContact(id)}>
      <View style={styles.container}>
        <View style={styles.textContainer}>
          <Text>{contact.get('name')}</Text>
        </View>
        <View style={styles.selection}>
          {selected && (
            <Icon name='ios-checkmark-circle' size={15} color={COLORS.Orange} />
          )}
        </View>
      </View>
    </TouchableOpacity>
  )
}
