// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { Map, Record } from 'immutable'
import { KeyboardAvoidingView } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import MessageInput from 'components/MessageInput'
import EmptyResources from 'components/EmptyResource'
import createLoader from 'utils/createloader'
import MessageContainer from './components/MessageContainer'
import ProjectButtons from './components/ProjectButtons'
import SideEffects from './components/SideEffects'
import RecordModal from './components/Record'
import { KEYBOARD_BEHAVIOUR } from 'utils/device'

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '$White'
  },
  input: {
    marginBottom: 5
  }
})

Conversation.propTypes = {
  isGroupConversation: PropTypes.bool.isRequired,
  currentUserId: PropTypes.string.isRequired,
  setText: PropTypes.func.isRequired,
  users: PropTypes.instanceOf(Map).isRequired,
  conversation: PropTypes.instanceOf(Record).isRequired,
  sendMessage: PropTypes.func.isRequired,
  showMessageOptions: PropTypes.func.isRequired
}

Conversation.navigationOptions = ({ navigation }) => ({
  title: navigation.state.params.title || 'Loading ...'
})

export function Conversation (props) {
  const {
    setText,
    currentUserId,
    conversation,
    users,
    sendMessage,
    showMessageOptions,
    openRecordAudio,
    showRecordModal,
    sendRecord,
    cancelRecord,
    text
  } = props
  const messages = conversation.get('messages')
  const partecipants = conversation.get('partecipants')
  return (
    <KeyboardAvoidingView
      behavior={KEYBOARD_BEHAVIOUR}
      style={styles.container}
      enabled
      keyboardVerticalOffset={74}
    >
      <ProjectButtons {...props} />
      {!messages.size ? (
        <EmptyResources
          icon='ios-chatbubbles-outline'
          label='This conversation has no messages yet'
        />
      ) : (
        <MessageContainer
          messages={messages}
          users={users}
          partecipants={partecipants}
          currentUserId={currentUserId}
        />
      )}
      <MessageInput
        style={styles.input}
        setText={setText}
        onSend={sendMessage}
        onOptions={showMessageOptions}
        onAudio={openRecordAudio}
        text={text}
      />
      <RecordModal
        isVisible={showRecordModal}
        saveFn={sendRecord}
        cancelFn={cancelRecord}
        {...props}
      />
      <SideEffects {...props} />
    </KeyboardAvoidingView>
  )
}

export default createLoader(Conversation)
