// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { Map } from 'immutable'
import { View } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import { isSameDay, isSameUser } from '../utils'
import MessageText from './MessageText'
import MessageImage from './MessageImage'
import MessageSending from './MessageSending'
import Time from './Time'
import COLORS from '../../../colors'

const styles = {
  sendingText: {},
  left: StyleSheet.create({
    container: {
      flex: 1,
      alignItems: 'flex-start'
    },
    wrapper: {
      borderRadius: 15,
      backgroundColor: '#f0f0f0',
      marginRight: 60,
      minHeight: 20,
      justifyContent: 'flex-end'
    },
    containerToNext: {
      borderBottomLeftRadius: 3
    },
    containerToPrevious: {
      borderTopLeftRadius: 3
    }
  }),
  right: StyleSheet.create({
    container: {
      flex: 1,
      alignItems: 'flex-end'
    },
    wrapper: {
      borderRadius: 15,
      backgroundColor: '#0084ff',
      marginLeft: 60,
      minHeight: 20,
      justifyContent: 'flex-end'
    },
    containerToNext: {
      borderBottomRightRadius: 3
    },
    containerToPrevious: {
      borderTopRightRadius: 3
    }
  }),
  tick: {
    fontSize: 10,
    backgroundColor: 'transparent',
    color: 'white'
  },
  tickView: {
    flexDirection: 'row',
    marginRight: 10
  }
}

Bubble.propTypes = {
  currentMessage: PropTypes.instanceOf(Map).isRequired,
  previousMessage: PropTypes.instanceOf(Map),
  nextMessage: PropTypes.instanceOf(Map),
  position: PropTypes.string.isRequired
}

export default function Bubble ({
  currentMessage,
  nextMessage,
  previousMessage,
  position
}) {
  const bubbleNextStyle =
    isSameUser(currentMessage, nextMessage) &&
    isSameDay(currentMessage, nextMessage)
      ? styles[position].containerToNext
      : null

  const bubblePreviousStyle =
    isSameUser(currentMessage, previousMessage) &&
    isSameDay(currentMessage, previousMessage)
      ? styles[position].containerToPrevious
      : null

  const textColor = position === 'right' ? COLORS.White : COLORS.Black
  const hasImage = !!(
    currentMessage.get('mediaThumbnail') || currentMessage.get('mediaUrl')
  )
  return (
    <View style={styles[position].container}>
      <View
        style={[styles[position].wrapper, bubbleNextStyle, bubblePreviousStyle]}
      >
        <MessageImage currentMessage={currentMessage} />
        <MessageText
          hasImage={hasImage}
          message={currentMessage.get('message')}
          color={textColor}
        />
        <Time date={currentMessage.get('createdAt')} color={textColor} />
      </View>
      <MessageSending currentMessage={currentMessage} />
    </View>
  )
}
