// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { View } from 'react-native'
import { Map } from 'immutable'
import StyleSheet from 'react-native-extended-stylesheet'
import TimeFormatter, { TIME_FORMATTERS } from 'components/TimeFormatter'
import { isSameDay } from '../utils'

const styles = StyleSheet.create({
  container: {
    alignItems: 'center',
    justifyContent: 'center',
    marginTop: 5,
    marginBottom: 10
  },
  text: {
    backgroundColor: 'transparent',
    color: '$DarkText',
    fontSize: 14,
    fontWeight: '600'
  }
})

Day.propTypes = {
  currentMessage: PropTypes.instanceOf(Map).isRequired,
  previousMessage: PropTypes.instanceOf(Map)
}

export default function Day ({ currentMessage, previousMessage }) {
  if (isSameDay(currentMessage, previousMessage)) {
    return null
  }
  return (
    <View style={styles.container}>
      <TimeFormatter
        date={currentMessage.get('createdAt')}
        format={TIME_FORMATTERS.FORMATTED_DAY}
        style={styles.text}
      />
    </View>
  )
}
