// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { Map } from 'immutable'
import { View } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import { isSameUser } from '../utils'
import Day from './Day'
import Bubble from './Bubble'
import Avatar from './Avatar'

const styles = {
  left: StyleSheet.create({
    container: {
      flexDirection: 'row',
      alignItems: 'flex-end',
      justifyContent: 'flex-start',
      marginLeft: 8,
      marginRight: 0
    }
  }),
  right: StyleSheet.create({
    container: {
      flexDirection: 'row',
      alignItems: 'flex-end',
      justifyContent: 'flex-end',
      marginLeft: 0,
      marginRight: 8
    }
  })
}

Message.propTypes = {
  currentMessage: PropTypes.instanceOf(Map).isRequired,
  nextMessage: PropTypes.instanceOf(Map),
  previousMessage: PropTypes.instanceOf(Map),
  position: PropTypes.string.isRequired,
  isLast: PropTypes.bool.isRequired
}

export default function Message (props) {
  const {
    currentMessage,
    nextMessage,
    previousMessage,
    position,
    isLast
  } = props
  const containerStyle = {
    marginBottom: isSameUser(currentMessage, nextMessage) ? 2 : 10
  }
  const messageStyle = {
    marginTop: isLast ? 10 : 0
  }

  return (
    <View style={messageStyle}>
      <Day currentMessage={currentMessage} previousMessage={previousMessage} />
      <View style={[styles[position].container, containerStyle]}>
        {position === 'left' ? <Avatar {...props} /> : null}
        <Bubble {...props} />
      </View>
    </View>
  )
}
