// @flow
import PropTypes from 'prop-types'
import React, { Component } from 'react'
import { Map } from 'immutable'
import { View } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import Icon from 'components/Icon'
import { IconButton } from 'components/Button'
import Time from './Time'
import COLORS from '../../../colors'
import Sound from 'react-native-sound'

const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    borderRadius: 5,
    padding: 4,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: '$LightBackground',
    marginLeft: 20,
    marginRight: 20,
    marginTop: 10,
    marginBottom: 10
  },
  text: {
    marginLeft: 8,
    fontSize: 15,
    textAlign: 'right',
    color: '$DarkText'
  },
  time: {
    marginBottom: 0,
    marginLeft: 10,
    fontSize: 13
  },
  button: {
    marginLeft: 15,
    marginRight: 5
  }
})

export default class MessageAudio extends Component {
  static propTypes = {
    currentMessage: PropTypes.instanceOf(Map).isRequired
  }
  constructor (props) {
    super(props)
    const audioFile = props.currentMessage.get('mediaUrl')
    const sound = new Sound(audioFile, '', error => {
      if (error) {
        console.log('failed to load the sound', error)
      }
    })
    this.state = {
      isPlaying: false,
      sound
    }
    this.play = this.play.bind(this)
    this.pause = this.pause.bind(this)
  }

  pause () {
    this.state.sound.pause()
    this.setState({ isPlaying: false })
  }

  play () {
    this.state.sound.play(success => {
      if (!success) {
        this.state.sound.reset()
      }
    })
    this.setState({ isPlaying: true })
  }

  render () {
    const { currentMessage } = this.props
    const { isPlaying } = this.state
    return (
      <View style={styles.container}>
        <Icon name='ios-microphone' color={COLORS.Secondary} />
        {isPlaying ? (
          <IconButton
            onPress={this.pause}
            name='ios-pause'
            style={styles.button}
            color={COLORS.Primary}
          />
        ) : (
          <IconButton
            onPress={this.play}
            name='ios-play'
            style={styles.button}
            color={COLORS.Primary}
          />
        )}
        <Time date={currentMessage.get('createdAt')} style={styles.time} />
      </View>
    )
  }
}
