// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { FlatList, TouchableWithoutFeedback, Keyboard } from 'react-native'
import { Map, List } from 'immutable'
import StyleSheet from 'react-native-extended-stylesheet'
import Message from './Message'
import PhoneCall from './PhoneCall'
import MessageAudio from './MessageAudio'
import { MESSAGE_TYPE } from 'resources/conversation/constants'
import { invertMessages } from '../utils'
import uuid from 'utils/generateuuid'

const styles = StyleSheet.create({
  container: {
    flex: 1,
    paddingBottom: 10
  }
})

MessageContainer.propTypes = {
  currentUserId: PropTypes.string.isRequired,
  users: PropTypes.instanceOf(Map),
  messages: PropTypes.instanceOf(List)
}

export default function MessageContainer ({ currentUserId, users, messages }) {
  const flattenedList = invertMessages(
    messages.toJS().map((_, index) => ({ index }))
  )
  const rowRenderer = ({ item }) => {
    const currentMessage = messages.get(item.index)
    const previousMessage =
      item.index > 1 ? messages.get(item.index - 1) : undefined
    const nextMessage =
      item.index < flattenedList.length
        ? messages.get(item.index + 1)
        : undefined
    const position =
      currentMessage.get('user') === currentUserId ? 'right' : 'left'
    if (currentMessage.get('type') === MESSAGE_TYPE.PHONE_CALL) {
      return (
        <PhoneCall
          isLast={item.index === flattenedList.length - 1}
          currentMessage={currentMessage}
        />
      )
    }
    if (currentMessage.get('type') === MESSAGE_TYPE.AUDIO) {
      return <MessageAudio currentMessage={currentMessage} />
    }
    return (
      <Message
        isLast={item.index === flattenedList.length - 1}
        currentMessage={currentMessage}
        nextMessage={nextMessage}
        previousMessage={previousMessage}
        position={position}
        users={users}
      />
    )
  }

  return (
    <TouchableWithoutFeedback onPress={Keyboard.dismiss}>
      <FlatList
        data={flattenedList}
        keyExtractor={item => {
          const message = messages.get(item.index)
          return message.get('id') || uuid()
        }}
        renderItem={rowRenderer}
        style={styles.container}
        inverted
      />
    </TouchableWithoutFeedback>
  )
}
