// @flow
import PropTypes from 'prop-types'
import React from 'react'
import { View } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import { OpacityButton } from 'components/Button'

const styles = StyleSheet.create({
  container: {
    width: '100%',
    height: 40,
    backgroundColor: '$LightBackground',
    borderBottomWidth: 1,
    borderBottomColor: '$LightText',
    zIndex: 2,
    shadowOffset: { width: 0, height: 3 },
    shadowColor: '$DarkText',
    shadowOpacity: 0.1,
    flexDirection: 'row'
  },
  separator: {
    width: 1,
    paddingTop: 5,
    paddingBottom: 5,
    marginLeft: 5,
    marginRight: 5,
    backgroundColor: '$LightDivider'
  },
  button: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center'
  },
  buttonTextStyle: {
    fontSize: 16
  }
})

ProjectButtons.propTypes = {
  isGroupConversation: PropTypes.bool.isRequired,
  toProjectInbox: PropTypes.func.isRequired,
  toProjectDetails: PropTypes.func.isRequired
}

export default function ProjectButtons ({
  isGroupConversation,
  toProjectInbox,
  toProjectDetails
}) {
  if (!isGroupConversation) {
    return null
  }
  return (
    <View style={styles.container}>
      <OpacityButton
        buttonStyle={styles.button}
        textStyle={styles.buttonTextStyle}
        onPress={toProjectInbox}
      >
        PROJECT INBOX
      </OpacityButton>
      <View style={styles.separator} />
      <OpacityButton
        buttonStyle={styles.button}
        textStyle={styles.buttonTextStyle}
        onPress={toProjectDetails}
      >
        PROJECT DETAILS
      </OpacityButton>
    </View>
  )
}
