// @flow
import React from 'react'
import { View, Text, Platform } from 'react-native'
import Modal from 'react-native-modal'
import PropTypes from 'prop-types'
import Button from 'components/Button'
import Icon from 'components/Icon'
import Loader from 'components/Loader'
import StyleSheet from 'react-native-extended-stylesheet'
import COLORS from '../../../colors'

const styles = StyleSheet.create({
  container: {
    backgroundColor: '$White',
    borderRadius: 5
  },
  row: {
    marginTop: 15,
    height: 40,
    flexDirection: 'row',
    width: '100%'
  },
  button: {
    flex: 1,
    height: 40,
    justifyContent: 'center',
    alignItems: 'center',
    borderColor: '$Primary',
    borderTopWidth: 1
  },
  audioButton: {
    height: 40,
    marginLeft: 10,
    marginRight: 10,
    justifyContent: 'center',
    alignItems: 'center',
    width: 40,
    borderRadius: 20,
    borderWidth: 1,
    borderColor: COLORS.Secondary
  },
  buttonOK: {
    backgroundColor: '$Primary'
  },
  buttonOKText: {
    color: '$White'
  },
  audioDetailButton: {
    marginTop: Platform.OS === 'ios' ? 5 : 0,
    marginLeft: Platform.OS === 'ios' ? 2 : 0
  },
  record: {
    width: 20,
    height: 20,
    borderRadius: 15,
    backgroundColor: COLORS.Red
  },
  stop: {
    width: 16,
    height: 16,
    backgroundColor: COLORS.DarkText
  },
  text: {
    fontSize: 13,
    color: '$Primary',
    marginTop: 20,
    width: '80%',
    paddingLeft: 20,
    paddingRight: 20
  },
  inputContainer: {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
    marginTop: 10,
    height: 40,
    width: '90%',
    marginLeft: '5%',
    paddingLeft: 10,
    paddingRight: 10
  },
  textInput: {
    height: 40,
    width: '100%',
    flex: 1,
    fontSize: 16,
    color: '$Primary'
  },
  volumeBars: {
    flexDirection: 'row',
    alignItems: 'flex-end'
  },
  volumeBar: {
    height: 10,
    width: 20,
    marginLeft: 5,
    backgroundColor: COLORS.Secondary
  }
})

RecordModal.propTypes = {
  isVisible: PropTypes.bool.isRequired,
  cancelFn: PropTypes.func.isRequired,
  saveFn: PropTypes.func.isRequired
}

export default function RecordModal ({
  isVisible,
  saveFn,
  recordClip,
  hasAudioClip,
  playClip,
  pauseClip,
  stopClip,
  isRecording,
  isPlaying,
  volumeWidth,
  isAudioLoading,
  cancelFn
}) {
  const volumeBar1 = { height: volumeWidth * 0.4 * 0.3 }
  const volumeBar2 = { height: volumeWidth * 0.4 * 0.7 }
  const volumeBar3 = { height: volumeWidth * 0.4 * 1.0 }
  const volumeBar4 = { height: volumeWidth * 0.4 * 0.5 }
  const volumeBar5 = { height: volumeWidth * 0.4 * 0.2 }
  return (
    <View>
      <Modal isVisible={isVisible}>
        {isAudioLoading ? (
          <View style={styles.container}>
            <Loader
              style={{ marginTop: 10, marginBottom: 10, alignSelf: 'center' }}
            />
          </View>
        ) : (
          <View style={styles.container}>
            <Text style={styles.text}>Record your message</Text>
            <View style={styles.inputContainer}>
              {!isRecording &&
                !isPlaying && (
                  <Button style={styles.audioButton} onPress={recordClip}>
                    <View style={styles.record} />
                  </Button>
                )}
              {!isRecording &&
                hasAudioClip &&
                !isPlaying && (
                  <Button style={styles.audioButton} onPress={playClip}>
                    <Icon
                      style={styles.audioDetailButton}
                      name='ios-play'
                      width={20}
                      color={COLORS.DarkText}
                    />
                  </Button>
                )}
              {(isRecording || (hasAudioClip && isPlaying)) && (
                <Button style={styles.audioButton} onPress={stopClip}>
                  <View style={styles.stop} />
                </Button>
              )}
              {isRecording && (
                <View style={styles.volumeBars}>
                  <View style={[styles.volumeBar, volumeBar1]} />
                  <View style={[styles.volumeBar, volumeBar2]} />
                  <View style={[styles.volumeBar, volumeBar3]} />
                  <View style={[styles.volumeBar, volumeBar4]} />
                  <View style={[styles.volumeBar, volumeBar5]} />
                </View>
              )}
            </View>
            <View style={styles.row}>
              <Button onPress={cancelFn} style={styles.button}>
                Cancel
              </Button>
              <Button
                secondary
                onPress={saveFn}
                textStyle={styles.buttonOKText}
                style={[styles.button, styles.buttonOK]}
              >
                Send
              </Button>
            </View>
          </View>
        )}
      </Modal>
    </View>
  )
}
