// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { List } from 'immutable'
import { View } from 'react-native'
import TokenAutocomplete from 'components/TokenAutocomplete'
import StyleSheet from 'react-native-extended-stylesheet'
import MessageInput from 'components/MessageInput'
import ProjectList from './components/ProjectList'
import ProjectLoader from './components/ProjectLoader'
import Modal from 'components/Modal'

const styles = StyleSheet.create({
  container: {
    flex: 1
  }
})

CreateConversation.propTypes = {
  addRecipient: PropTypes.func.isRequired,
  contacts: PropTypes.instanceOf(List).isRequired,
  removeRecipient: PropTypes.func.isRequired,
  recipients: PropTypes.instanceOf(List).isRequired
}

CreateConversation.navigationOptions = {
  title: 'New Conversation'
}

export default function CreateConversation ({
  addRecipient,
  contacts,
  removeRecipient,
  recipients,
  hasLoaded,
  message,
  createConversation,
  setMessage,
  ...props
}) {
  return (
    <View style={styles.container}>
      <TokenAutocomplete
        addToken={addRecipient}
        options={contacts.toJS()}
        removeToken={removeRecipient}
        values={recipients.toJS()}
      />
      {!hasLoaded ? <ProjectLoader /> : <ProjectList {...props} />}
      <MessageInput
        setText={setMessage}
        onSend={createConversation}
        value={message}
      />
      <Modal {...props} />
    </View>
  )
}
