// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { Map } from 'immutable'
import { TouchableOpacity, View, Text } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import sanitizeLocation from 'utils/sanitizelocation'
import font from 'utils/font'
import { SCREEN_WIDTH } from 'utils/device'
import COLORS from '../../../colors'
import Icon from 'components/Icon'

const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    height: 75,
    paddingLeft: 15,
    paddingRight: 15,
    borderColor: '$LightDivider',
    borderBottomWidth: 1,
    alignItems: 'center',
    justifyContent: 'space-between'
  },
  name: {
    ...font({ weight: 'bold' }),
    color: '$Primary',
    textAlign: 'left',
    fontSize: 15,
    width: SCREEN_WIDTH - 45
  },
  address: {
    color: '$DarkText',
    fontSize: 13,
    marginTop: 5,
    paddingRight: 10,
    textAlign: 'left'
  },
  icon: {
    position: 'absolute',
    right: 7,
    top: 30,
    width: 20,
    height: 20,
    borderWidth: 1,
    borderRadius: 10,
    borderColor: '$Secondary',
    justifyContent: 'center',
    alignItems: 'center'
  },
  selectedIcon: {
    marginTop: 2
  }
})

ProjectRow.propTypes = {
  projects: PropTypes.instanceOf(Map).isRequired,
  toggleProject: PropTypes.func.isRequired,
  id: PropTypes.string.isRequired
}

export default function ProjectRow ({ toggleProject, projects, id, selected }) {
  const project = projects.get(id)
  const onPress = () => toggleProject(id)
  return (
    <TouchableOpacity onPress={onPress}>
      <View style={styles.container}>
        <View style={styles.inputText}>
          <Text style={styles.name} numberOfLines={1}>
            {project.get('name')}
          </Text>
          <Text style={styles.address} numberOfLines={1}>
            {sanitizeLocation(project.get('location')) || 'No address set yet'}
          </Text>
        </View>
        <View style={styles.icon} color={COLORS.Primary}>
          {selected && (
            <Icon
              name='ios-checkmark-circle'
              size={20}
              style={styles.selectedIcon}
              color={COLORS.Secondary}
            />
          )}
        </View>
      </View>
    </TouchableOpacity>
  )
}
