// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { View } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import createLoader from 'utils/createloader'
import SearchBar from 'components/Search'
import { SolidButton } from 'components/Button'
import COLORS from '../../colors'
import NavbarButton from 'components/NavbarButton'
import EmptyView from './components/EmptyView'
import Loader from './components/Loader'
import FilterBar from './components/FilterBar'
import ConversationList from './components/ConversationList'

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '$White'
  },
  searchBar: {
    backgroundColor: '$LightBackground',
    borderBottomWidth: 1,
    borderBottomColor: '$LightText'
  },
  seachBox: {
    borderBottomColor: '$LightDivider'
  },
  projectDetailsButton: {
    height: 40
  }
})

Inbox.propTypes = {
  displayProjectFilter: PropTypes.bool.isRequired,
  canViewDetails: PropTypes.bool.isRequired,
  isEmpty: PropTypes.bool.isRequired,
  toProjectInfo: PropTypes.func.isRequired,
  setSearch: PropTypes.func.isRequired
}

Inbox.navigationOptions = ({ navigation }) => ({
  title: 'Inbox',
  headerLeft: !navigation.state.params.displayBack && (
    <NavbarButton onPress={() => navigation.navigate('DrawerOpen')} />
  ),
  headerRight: (
    <NavbarButton
      onPress={() => navigation.state.params.createConversation()}
      name='ios-create-outline'
      size={25}
    />
  )
})

export function Inbox ({
  canViewDetails,
  displayProjectFilter,
  toProjectInfo,
  isEmpty,
  setSearch,
  ...props
}) {
  return (
    <View style={styles.container}>
      <View style={styles.searchBar}>
        <SearchBar
          placeholder='Search'
          onChangeText={setSearch}
          useClearButton={false}
          onCancel={() => setSearch('')}
          style={styles.seachBox}
          textFieldBackgroundColor={COLORS.DarkBackground}
        />
        {displayProjectFilter && <FilterBar {...props} />}
      </View>
      {!isEmpty ? <ConversationList {...props} /> : <EmptyView />}
      {canViewDetails &&
        displayProjectFilter && (
          <SolidButton
            style={styles.projectDetailsButton}
            onPress={toProjectInfo}
          >
            Project Details
          </SolidButton>
        )}
    </View>
  )
}

export default createLoader(Inbox, Loader)
