import React from 'react'
import { shallow } from 'enzyme'
import { Inbox } from '../Inbox'
import { ProjectSchema } from 'resources/project'
import SearchBar from 'components/Search'
import { SolidButton } from 'components/Button'
import FilterBar from '../components/FilterBar'
import EmptyView from '../components/EmptyView'
import ConversationList from '../components/ConversationList'
import { fromJS, Map, List } from 'immutable'

function renderHelper (props) {
  const setSearch = jest.fn()
  const changeProjectFilter = jest.fn()
  const toConversation = jest.fn()
  const toProjectInfo = jest.fn()
  const projects = fromJS({
    '3': new ProjectSchema({})
  })
  return shallow(
    <Inbox
      changeProjectFilter={changeProjectFilter}
      canViewDetails
      displayProjectFilter
      projectId='3'
      projects={projects}
      inbox={new Map()}
      inboxList={new List()}
      isEmpty={false}
      setSearch={setSearch}
      toConversation={toConversation}
      users={new Map()}
      toProjectInfo={toProjectInfo}
      {...props}
    />
  )
}

describe('Inbox', () => {
  it('renders a searchbar', () => {
    const setSearch = jest.fn()
    const node = renderHelper({ setSearch })
    expect(node.find(SearchBar).exists()).toBeTruthy()
    expect(node.find(SearchBar).prop('onChangeText')).toBe(setSearch)
    node.find(SearchBar).prop('onCancel')()
    expect(setSearch).toHaveBeenCalledWith('')
  })
  it('renders a FilterBar', () => {
    const changeProjectFilter = jest.fn()
    const projects = new Map()
    const projectId = '34'
    const node = renderHelper({ changeProjectFilter, projects, projectId })
    expect(node.find(FilterBar).exists()).toBeTruthy()
    expect(node.find(FilterBar).prop('projects')).toBe(projects)
    expect(node.find(FilterBar).prop('projectId')).toBe(projectId)
  })
  it('renders a conversation list', () => {
    const inbox = new Map()
    const inboxList = new List()
    const projects = new Map()
    const toConversation = jest.fn()
    const users = new Map()

    const nodeFull = renderHelper({
      isEmpty: false,
      inbox,
      inboxList,
      projects,
      toConversation,
      users
    })
    const nodeEmpty = renderHelper({ isEmpty: true })

    expect(nodeEmpty.find(ConversationList).exists()).toBeFalsy()
    expect(nodeEmpty.find(EmptyView).exists()).toBeTruthy()

    expect(nodeFull.find(ConversationList).exists()).toBeTruthy()
    expect(nodeFull.find(EmptyView).exists()).toBeFalsy()
    expect(nodeFull.find(ConversationList).prop('inbox')).toBe(inbox)
    expect(nodeFull.find(ConversationList).prop('inboxList')).toBe(inboxList)
    expect(nodeFull.find(ConversationList).prop('projects')).toBe(projects)
    expect(nodeFull.find(ConversationList).prop('toConversation')).toBe(
      toConversation
    )
    expect(nodeFull.find(ConversationList).prop('users')).toBe(users)
  })

  it('can view details', () => {
    const nodeEmpty = renderHelper({ canViewDetails: false })
    const nodeFull = renderHelper({ canViewDetails: true })

    expect(
      nodeFull
        .find(SolidButton)
        .map(button => button.prop('children'))
        .includes('Project Details')
    ).toBeTruthy()

    expect(
      nodeEmpty
        .find(SolidButton)
        .map(button => button.prop('children'))
        .includes('Project Details')
    ).toBeFalsy()
  })
})
