// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { FlatList } from 'react-native'
import { List, Map } from 'immutable'
import StyleSheet from 'react-native-extended-stylesheet'
import ConversationRow from './ConversationRow'

const styles = StyleSheet.create({
  container: {
    flex: 1
  }
})

ConversationList.propTypes = {
  inbox: PropTypes.instanceOf(Map).isRequired,
  inboxList: PropTypes.instanceOf(List).isRequired,
  projects: PropTypes.instanceOf(Map).isRequired,
  toConversation: PropTypes.func.isRequired,
  users: PropTypes.instanceOf(Map).isRequired
}

export default function ConversationList ({
  inbox,
  inboxList,
  projects,
  toConversation,
  users
}) {
  const flattenedList = inboxList.toJS().map(id => ({ id }))
  const rowRenderer = ({ item }) => (
    <ConversationRow
      {...item}
      toConversation={toConversation}
      inbox={inbox}
      projects={projects}
      users={users}
    />
  )

  return (
    <FlatList
      data={flattenedList}
      keyExtractor={(_, index) => index.toString()}
      renderItem={rowRenderer}
      style={styles.container}
    />
  )
}
