// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { Map } from 'immutable'
import { TouchableOpacity, View, Text } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import ConversationBadge from 'components/ConversationBadge'
import TimeFormatter, { TIME_FORMATTERS } from 'components/TimeFormatter'
import { latestMessagSanitize } from '../utils'

const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    height: 75,
    paddingLeft: 10,
    paddingTop: 8
  },
  textContainer: {
    flex: 1,
    marginLeft: 15,
    marginRight: 15,
    paddingTop: 5,
    justifyContent: 'center',
    flexDirection: 'column'
  },
  firstRow: {
    flexDirection: 'row'
  },
  partecipants: {
    flex: 1,
    paddingRight: 10,
    fontSize: 15,
    color: '$Primary'
  },
  time: {
    flex: 0,
    fontSize: 12,
    color: '$DarkText'
  },
  unread: {
    fontWeight: 'bold',
    color: '$Primary'
  },
  message: {
    fontSize: 13,
    marginTop: 3,
    color: '$DarkText'
  },
  project: {
    flex: 0,
    fontSize: 12,
    color: '$Primary'
  },
  lastRow: {
    flexDirection: 'row',
    marginTop: 4,
    alignItems: 'center'
  },
  divider: {
    height: 1,
    flex: 1,
    marginLeft: 10,
    marginRight: 15,
    backgroundColor: '$LightDivider'
  }
})

ConversationRow.propTypes = {
  inbox: PropTypes.instanceOf(Map).isRequired,
  projects: PropTypes.instanceOf(Map).isRequired,
  toConversation: PropTypes.func.isRequired,
  users: PropTypes.instanceOf(Map).isRequired,
  id: PropTypes.string.isRequired
}

export default function ConversationRow ({
  inbox,
  toConversation,
  projects,
  users,
  id
}) {
  const message = inbox.get(id)
  const partecipants = message.partecipants.map(userId =>
    users.getIn([userId, 'name'])
  )
  const unread = message.get('unread')
  const project = projects.get(message.get('project'))
  const onPress = () =>
    toConversation({
      conversationId: message.get('conversation'),
      roomId: message.get('room')
    })
  return (
    <TouchableOpacity onPress={onPress}>
      <View style={styles.container}>
        <ConversationBadge
          size={47}
          unread={!!unread}
          names={partecipants.toJS()}
        />
        <View style={styles.textContainer}>
          <View style={styles.firstRow}>
            <Text
              numberOfLines={1}
              style={[styles.partecipants, unread && styles.unread]}
            >
              {partecipants.join(', ')}
            </Text>
            <TimeFormatter
              date={message.get('createdAt')}
              format={TIME_FORMATTERS.AGO}
              style={styles.time}
            />
          </View>
          <Text
            style={[styles.message, unread && styles.unread]}
            numberOfLines={1}
          >
            {latestMessagSanitize(message.get('latestMessage'))}
          </Text>
          <View style={styles.lastRow}>
            <View style={styles.divider} />
            <Text style={styles.project} numberOfLines={1}>
              {project.get('name')}
            </Text>
          </View>
        </View>
      </View>
    </TouchableOpacity>
  )
}
