// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { Map } from 'immutable'
import { TouchableOpacity, View, Text } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import Icon from 'components/Icon'
import COLORS from '../../../colors'

const styles = StyleSheet.create({
  container: {
    height: 35,
    alignItems: 'center',
    backgroundColor: '$LightBackground',
    borderBottomWidth: 1,
    borderBottomColor: '$LightDivider',
    flexDirection: 'row'
  },
  text: {
    flex: 1,
    marginLeft: 10,
    marginRight: 20,
    color: '$Primary',
    fontSize: 15
  },
  filterIcon: {
    marginLeft: 10
  },
  chevronIcon: {
    marginRight: 10
  }
})

FilterBar.propTypes = {
  changeProjectFilter: PropTypes.func.isRequired,
  projectId: PropTypes.string.isRequired,
  projects: PropTypes.instanceOf(Map).isRequired
}

export default function FilterBar ({
  projectId,
  changeProjectFilter,
  projects
}) {
  const projectName =
    projectId === '0' ? 'All Projects' : projects.getIn([projectId, 'name'])
  return (
    <TouchableOpacity onPress={changeProjectFilter}>
      <View style={styles.container}>
        <Icon
          name='ios-options-outline'
          color={COLORS.Primary}
          size={25}
          style={styles.filterIcon}
        />
        <Text style={styles.text} numberOfLines={1}>
          {projectName}
        </Text>
        <Icon
          name='ios-arrow-forward'
          color={COLORS.Primary}
          size={20}
          style={styles.chevronIcon}
        />
      </View>
    </TouchableOpacity>
  )
}
