// @flow
import React from 'react'
import { View, ScrollView } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import { range } from 'lodash'
import { Circle, Rect } from 'react-native-svg'
import SearchBar from 'components/Search'
import ContentLoader from 'vendor/react-native-content-loader'
import { SCREEN_WIDTH } from 'utils/device'

const styles = StyleSheet.create({
  mainContainer: {
    flex: 1
  },
  container: {
    flex: 1,
    padding: 10
  },
  box: {
    marginTop: 5,
    height: 70
  },
  searchBar: {
    height: 70,
    backgroundColor: '$LightBackground',
    borderBottomWidth: 1,
    borderBottomColor: '$LightText'
  },
  seachBox: {
    borderBottomColor: '$LightDivider'
  }
})

const LARGE_INDICATOR = SCREEN_WIDTH - 150
const MEDIUM_INDICATOR = LARGE_INDICATOR - 30
const SMALL_INDICATOR = LARGE_INDICATOR / 2

export function LoadingIndicator () {
  return (
    <View style={styles.box}>
      <ContentLoader height={65} duration={1000}>
        <Circle cx='30' cy='30' r='30' />
        <Rect x='75' y='7' rx='4' ry='4' width={LARGE_INDICATOR} height='13' />
        <Rect x='75' y='31' rx='4' ry='4' width={MEDIUM_INDICATOR} height='8' />
        <Rect x='75' y='50' rx='4' ry='4' width={SMALL_INDICATOR} height='8' />
      </ContentLoader>
    </View>
  )
}

export default function Loader () {
  return (
    <View style={styles.mainContainer}>
      <View style={styles.searchBar}>
        <SearchBar
          placeholder='Search'
          editable={false}
          style={styles.seachBox}
        />
        <ContentLoader height={65} duration={1000}>
          <Rect
            x='10'
            y='7'
            rx='4'
            ry='4'
            width={LARGE_INDICATOR}
            height='13'
          />
        </ContentLoader>
      </View>
      <ScrollView style={styles.container}>
        {range(10).map((_, i) => <LoadingIndicator key={i} />)}
      </ScrollView>
    </View>
  )
}
