// @flow
import React from 'react'
import PropTypes from 'prop-types'
import StyleSheet from 'react-native-extended-stylesheet'
import {
  KeyboardAvoidingView,
  TouchableWithoutFeedback,
  Keyboard
} from 'react-native'
import LinearGradient from 'react-native-linear-gradient'
import Logo from 'components/Logo'
import { SolidButton } from 'components/Button'
import ErrorMessage from 'components/ErrorMessage'
import PlayButton from './components/PlayButton'
import { LoaderView } from 'components/Loader'
import Instructions from './components/Instructions'
import MoreInstructions from './components/MoreInstructions'
import RoundTextInput from 'components/RoundTextInput'
import COLORS from '../../colors'
import { KEYBOARD_BEHAVIOUR } from 'utils/device'

const styles = StyleSheet.create({
  wrapper: {
    flex: 1
  },
  container: {
    flex: 1,
    backgroundColor: '$Primary',
    justifyContent: 'center',
    alignItems: 'center'
  },
  loginButton: {
    marginTop: 20,
    width: '80%',
    height: 40,
    borderRadius: 20,
    paddingLeft: 20,
    paddingRight: 20
  },
  error: {
    marginTop: 20
  },
  loading: {
    marginTop: 30,
    backgroundColor: 'transparent'
  }
})

Login.navigationOptions = {
  title: 'Login',
  header: () => null
}

Login.propTypes = {
  errorMessage: PropTypes.string,
  isSubmitting: PropTypes.bool.isRequired,
  phoneNumber: PropTypes.string.isRequired,
  sendPin: PropTypes.func.isRequired,
  setPhoneNumber: PropTypes.func.isRequired
}

export default function Login ({
  errorMessage,
  isSubmitting,
  phoneNumber,
  sendPin,
  setPhoneNumber,
  ...props
}) {
  return (
    <KeyboardAvoidingView behavior={KEYBOARD_BEHAVIOUR} style={styles.wrapper}>
      <TouchableWithoutFeedback
        style={styles.wrapper}
        onPress={Keyboard.dismiss}
      >
        <LinearGradient
          colors={[COLORS.LightPrimary, COLORS.Primary]}
          start={{ x: 0.5, y: 0.3 }}
          end={{ x: 0.8, y: 0.7 }}
          style={styles.container}
        >
          <Logo width={200} />
          <Instructions />
          <LoaderView isLoading={isSubmitting} style={styles.loading}>
            <ErrorMessage style={styles.error} message={errorMessage} />
            <RoundTextInput
              value={phoneNumber}
              onChangeText={setPhoneNumber}
              placeHolder='Your cell number'
            />
            <SolidButton style={styles.loginButton} secondary onPress={sendPin}>
              SEND PIN
            </SolidButton>
          </LoaderView>
          <PlayButton {...props} />
          <MoreInstructions />
        </LinearGradient>
      </TouchableWithoutFeedback>
    </KeyboardAvoidingView>
  )
}
