import React from 'react'
import { shallow } from 'enzyme'
import Login from '../Login'
import RoundTextInput from 'components/RoundTextInput'
import ErrorMessage from 'components/ErrorMessage'
import PlayButton from '../components/PlayButton'
import { LoaderView } from 'components/Loader'
import Instructions from '../components/Instructions'
import MoreInstructions from '../components/MoreInstructions'
import Container from '../Container'
import { SolidButton } from 'components/Button'
import { actions } from '../module'

function renderHelper (props = {}) {
  return shallow(
    <Login
      errorMessage=''
      isSubmitting={false}
      isPlaying={false}
      phoneNumber=''
      sendPin={() => {}}
      setPhoneNumber={() => {}}
      setVideoState={() => {}}
      {...props}
    />
  )
}
describe('Login Screen', () => {
  describe('container', () => {
    it('should include in  navigateActions initialize', () => {
      expect(Container.navigateActions.includes(actions.initialize)).toBe(true)
    })
  })

  describe('view', () => {
    it('should render an input for phone number', () => {
      const setPhoneNumber = jest.fn()
      const node = renderHelper({ phoneNumber: '1234', setPhoneNumber })
      expect(node.find(RoundTextInput)).toHaveLength(1)
      expect(node.find(RoundTextInput).prop('value')).toBe('1234')
      expect(node.find(RoundTextInput).prop('onChangeText')).toBe(
        setPhoneNumber
      )
      node.find(RoundTextInput).prop('onChangeText')('2233')
      expect(setPhoneNumber).toHaveBeenCalledWith('2233')
    })
    it('should render a button to submit', () => {
      const sendPin = jest.fn()
      const node = renderHelper({ sendPin })
      expect(node.find(SolidButton)).toHaveLength(1)
      expect(
        node
          .find(SolidButton)
          .children()
          .text()
      ).toBe('SEND PIN')
      node.find(SolidButton).prop('onPress')('foo')
      expect(sendPin).toHaveBeenCalledWith('foo')
    })
    it('should display error string', () => {
      const node = renderHelper({ errorMessage: 'some error' })
      expect(node.find(ErrorMessage)).toHaveLength(1)
      expect(node.find(ErrorMessage).prop('message')).toBe('some error')
    })
    it('should display some helpful labels', () => {
      const node = renderHelper()
      expect(node.find(Instructions)).toHaveLength(1)
      expect(node.find(MoreInstructions)).toHaveLength(1)
    })
    it('should render a play button', () => {
      const node = renderHelper()
      expect(node.find(PlayButton)).toHaveLength(1)
    })
    it('should trigger a loaderView while is submitting', () => {
      const loadingNode = renderHelper({ isSubmitting: true })
      expect(loadingNode.find(LoaderView)).toHaveLength(1)
      expect(loadingNode.find(LoaderView).prop('isLoading')).toBe(true)
      const node = renderHelper()
      expect(node.find(LoaderView)).toHaveLength(1)
      expect(node.find(LoaderView).prop('isLoading')).toBe(false)
    })
  })
})
