import React from 'react'
import { shallow } from 'enzyme'
import PlayButton from '../components/PlayButton'
import { IconButton } from 'components/Button'
import YouTube from 'react-native-youtube'
import { VIDEO_STATES } from '../module'

function renderHelper (props = {}) {
  return shallow(
    <PlayButton isPlaying={false} setVideoState={() => {}} {...props} />
  )
}

describe('PlayButton', () => {
  describe('should not change by accient', () => {
    it('is playing', () => {
      expect(renderHelper({ isPlaying: false })).toMatchSnapshot()
    })
    it('is not playing', () => {
      expect(renderHelper({ isPlaying: true })).toMatchSnapshot()
    })
  })

  it('should render a play button if not playing', () => {
    const node = renderHelper({ isPlaying: false })
    expect(node.find(YouTube)).toHaveLength(0)
    expect(node.find(IconButton)).toHaveLength(1)
  })
  it('should render the youtube video if playing', () => {
    const node = renderHelper({ isPlaying: true })
    expect(node.find(YouTube)).toHaveLength(1)
  })
  it('should set the correct prop callbacks', () => {
    const setVideoState = jest.fn()
    const node = renderHelper({ isPlaying: true, setVideoState })
    node.find(YouTube).prop('onChangeState')({ state: VIDEO_STATES.PAUSED })
    expect(setVideoState).toHaveBeenLastCalledWith(VIDEO_STATES.PAUSED)
    setVideoState.mockClear()
    node.find(IconButton).prop('onPress')()
    expect(setVideoState).toHaveBeenLastCalledWith(VIDEO_STATES.PLAYING)
  })
})
