// @flow
import React from 'react'
import { View } from 'react-native'
import { IconButton } from 'components/Button'
import PropTypes from 'prop-types'
import StyleSheet from 'react-native-extended-stylesheet'
import YouTube from 'react-native-youtube'
import COLORS from '../../../colors'
import { SCREEN_WIDTH } from 'utils/device'
import { VIDEO_STATES } from '../module'
import { YOUTUBE_KEY } from '../../../config'

const styles = StyleSheet.create({
  container: {
    justifyContent: 'center',
    alignItems: 'center',
    marginTop: 40
  },
  button: {
    borderColor: '$Secondary',
    borderWidth: 2,
    justifyContent: 'center',
    alignItems: 'center',
    paddingLeft: 7,
    paddingTop: 2,
    height: 50,
    width: 50,
    borderRadius: 50
  },
  video: {
    alignSelf: 'stretch',
    height: 100,
    width: SCREEN_WIDTH,
    marginVertical: 10
  }
})

PlayButton.propTypes = {
  isPlaying: PropTypes.bool.isRequired,
  setVideoState: PropTypes.func.isRequired
}

export default function PlayButton ({ isPlaying, setVideoState }) {
  const video = !isPlaying ? null : (
    <YouTube
      apiKey={YOUTUBE_KEY}
      videoId='6fTQb5MURJA'
      play
      playsInline={false}
      modestbranding={false}
      showinfo={false}
      fullscreen
      onChangeState={({ state }) => setVideoState(state)}
      style={styles.video}
    />
  )
  return (
    <View style={styles.container}>
      <IconButton
        style={styles.button}
        name='ios-play-outline'
        size={40}
        color={COLORS.Secondary}
        onPress={() => setVideoState(VIDEO_STATES.PLAYING)}
      />
      {video}
    </View>
  )
}
