// @flow
import { Record } from 'immutable'
import { AsyncStorage, Keyboard } from 'react-native'
import createReducer from 'utils/createreducer'
import createConstants from 'utils/createconstants'
import createViewSelector from 'utils/createviewselector'
import { DEVELOPMENT_ENV, USERPHONE_KEY } from '../../config'
import * as API from 'utils/api'
import SCREENS from 'routes/screens'
import * as RouteActions from 'routes/actions'

export const CONSTANTS = createConstants('SCREEN_LOGIN', {
  RESET: null,
  SET_PHONE: null,
  SET_SUBMITTING: null,
  SET_VIDEOPLAYING: null,
  SET_ERRORMESSAGE: null
})

export const VIDEO_STATES = {
  PAUSED: 'paused',
  ENDED: 'ended',
  PLAYING: 'playing',
  BUFFERING: 'buffering',
  SEEKING: 'seeking'
}

export const actions = {
  initialize () {
    return async dispatch => {
      try {
        const phoneNumber = await AsyncStorage.getItem(USERPHONE_KEY)
        dispatch(actions.resetState())
        if (phoneNumber) {
          dispatch(actions.setPhoneNumber(phoneNumber))
        }
      } catch (error) {
        console.log('login initialize failed', error)
      }
    }
  },
  setPhoneNumber (phone) {
    return dispatch => {
      dispatch(actions.setErrorMessage(null))
      dispatch({
        type: CONSTANTS.SET_PHONE,
        payload: phone
      })
    }
  },
  resetState () {
    return {
      type: CONSTANTS.RESET
    }
  },
  setSubmitting (isSubmitting) {
    return {
      type: CONSTANTS.SET_SUBMITTING,
      payload: isSubmitting
    }
  },
  setPlaying (isPlaying) {
    return {
      type: CONSTANTS.SET_VIDEOPLAYING,
      payload: isPlaying
    }
  },
  setVideoState (videoState) {
    if (
      videoState === VIDEO_STATES.PAUSED ||
      videoState === VIDEO_STATES.ENDED
    ) {
      return actions.setPlaying(false)
    }
    return actions.setPlaying(true)
  },
  setErrorMessage (errorMessage) {
    return {
      type: CONSTANTS.SET_ERRORMESSAGE,
      payload: errorMessage
    }
  },
  sendPin () {
    return async (dispatch, getState) => {
      dispatch(actions.setVideoState(VIDEO_STATES.ENDED))
      Keyboard.dismiss()
      const phoneNumber = selectors.phoneNumber(getState())
      if (phoneNumber.length < 10) {
        dispatch(actions.setErrorMessage('Invalid phone number'))
        return
      }
      try {
        dispatch(actions.setSubmitting(true))
        const { responseCode } = await API.sendAuthCode({ phoneNumber })
        if (responseCode !== 200) {
          throw new Error('HTTP Error')
        }
        dispatch(RouteActions.navigate(SCREENS.VERIFY_PIN, { phoneNumber }))
      } catch (error) {
        if (DEVELOPMENT_ENV) {
          console.log('sendPin failed', error)
        }
        dispatch(
          actions.setErrorMessage("There's been an error requesting the PIN")
        )
      } finally {
        dispatch(actions.setSubmitting(false))
        dispatch(actions.setVideoState(VIDEO_STATES.ENDED))
      }
    }
  }
}

export const LoginState = Record({
  phoneNumber: '',
  isSubmitting: false,
  isPlaying: false,
  errorMessage: null
})

export const reducer = createReducer(new LoginState(), {
  [CONSTANTS.RESET]: () => new LoginState(),
  [CONSTANTS.SET_PHONE]: (state, { payload }) =>
    state.set('phoneNumber', payload),
  [CONSTANTS.SET_VIDEOPLAYING]: (state, { payload }) =>
    state.set('isPlaying', payload),
  [CONSTANTS.SET_SUBMITTING]: (state, { payload }) =>
    state.set('isSubmitting', payload),
  [CONSTANTS.SET_ERRORMESSAGE]: (state, { payload }) =>
    state.set('errorMessage', payload)
})

export const viewState = state => state.screens.login
export const viewSelector = createViewSelector(viewState)

export const selectors = {
  phoneNumber: viewSelector('phoneNumber', ''),
  isSubmitting: viewSelector('isSubmitting'),
  isPlaying: viewSelector('isPlaying'),
  errorMessage: viewSelector('errorMessage')
}
