// @flow
import { Alert } from 'react-native'
import { Record } from 'immutable'
import createReducer from 'utils/createreducer'
import createConstants from 'utils/createconstants'
import createViewSelector from 'utils/createviewselector'
import { get, post } from 'utils/http'
import { UserActions, UserSelectors } from 'resources/user'
import { stringIntToBool, boolToStringInt } from 'utils/stringbool'

const CONSTANTS = createConstants('SCREENS_PROFILE', {
  SET_USER: null,
  SET_NAME: null,
  SET_CELL: null,
  SET_COMM_DEVICE: null,
  SET_COMM_EMAIL: null,
  SET_COMM_MOBILE: null,
  SET_LOCATION: null,
  SET_LOADING: null,
  SET_CURRENT_PASSWORD: null,
  SET_NEW_PASSWORD: null,
  SET_NEW_PASSWORD2: null
})

export const actions = {
  initialize () {
    return async (dispatch, getState) => {
      const userId = UserSelectors.currentUserId(getState())
      try {
        dispatch(actions.setLoading(true))
        const userResponse = await get(`/user/${userId}`)
        const { data: { user } } = userResponse
        dispatch({
          type: CONSTANTS.SET_USER,
          payload: {
            cell: user.cell,
            name: user.name,
            email: user.email,
            commDevice: stringIntToBool(user.commDevice),
            commEmail: stringIntToBool(user.commEmail),
            commMobile: stringIntToBool(user.commMobile),
            id: user.id,
            location: user.location,
            tasks: ''
          }
        })
        dispatch(actions.setLoading(false))
      } catch (error) {
        console.log('profile', error)
      }
    }
  },
  save () {
    return async (dispatch, getState) => {
      const state = getState()
      const userId = UserSelectors.currentUserId(state)
      const cell = selectors.cell(state)
      const email = selectors.email(state)
      const commDevice = selectors.commDevice(state)
      const commEmail = selectors.commEmail(state)
      const commMobile = selectors.commMobile(state)
      const id = selectors.id(state)
      const location = selectors.location(state)
      const tasks = selectors.tasks(state)
      const name = selectors.name(state)
      const data = {
        id,
        cell,
        name,
        email,
        commDevice: boolToStringInt(commDevice),
        commMobile: boolToStringInt(commMobile),
        commEmail: boolToStringInt(commEmail),
        location,
        tasks
      }
      try {
        await post(`/user/${userId}`, data)
        dispatch(actions.setLoading(true))
        dispatch(UserActions.fetchInfo(userId))
        Alert.alert('Nailit!', 'Changes saved')
      } catch (error) {
        console.log(error)
        Alert.alert('Nailit!', 'There was a problem saving the user')
      } finally {
        dispatch(actions.setLoading(false))
      }
    }
  },
  savePassword () {
    return async (dispatch, getState) => {
      const state = getState()
      const userId = UserSelectors.currentUserId(state)
      const currentPassword = selectors.currentPassword(state)
      const newPassword = selectors.newPassword(state)
      const newPassword2 = selectors.newPassword2(state)
      const data = {
        userId,
        password: currentPassword,
        newPassword,
        newPasswordConfirm: newPassword2
      }
      try {
        await post(`/hange/password/${userId}`, data)
        dispatch(actions.setLoading(true))
        dispatch(UserActions.fetchInfo(userId))
        Alert.alert('Nailit!', 'Changes saved')
      } catch (error) {
        console.log(error)
        Alert.alert('Nailit!', 'There was a problem saving the user')
      } finally {
        dispatch(actions.setLoading(false))
      }
    }
  },
  setEmail (payload) {
    return { type: CONSTANTS.SET_EMAIL, payload }
  },
  setName (payload) {
    return { type: CONSTANTS.SET_NAME, payload }
  },
  setCell (payload) {
    return { type: CONSTANTS.SET_CELL, payload }
  },
  setCommDevice (payload) {
    return { type: CONSTANTS.SET_COMM_DEVICE, payload }
  },
  setCommEmail (payload) {
    return { type: CONSTANTS.SET_COMM_EMAIL, payload }
  },
  setCommMobile (payload) {
    return { type: CONSTANTS.SET_COMM_MOBILE, payload }
  },
  setLocation (payload) {
    return { type: CONSTANTS.SET_LOCATION, payload }
  },
  setLoading (payload) {
    return { type: CONSTANTS.SET_LOADING, payload }
  },
  setCurrentPassword (payload) {
    return { type: CONSTANTS.SET_CURRENT_PASSWORD, payload }
  },
  setNewPassword (payload) {
    return { type: CONSTANTS.SET_NEW_PASSWORD, payload }
  },
  setNewPassword2 (payload) {
    return { type: CONSTANTS.SET_NEW_PASSWORD2, payload }
  }
}

export const ProfileState = Record({
  id: null,
  cell: '',
  name: '',
  email: '',
  commDevice: false,
  commMobile: false,
  commEmail: false,
  location: '',
  tasks: '',
  isLoading: false,
  currentPassword: '',
  newPassword: '',
  newPassword2: ''
})

export const reducer = createReducer(new ProfileState(), {
  [CONSTANTS.SET_USER]: (state, { payload }) => {
    const {
      cell,
      name,
      commDevice,
      commEmail,
      commMobile,
      id,
      location,
      tasks,
      email
    } = payload
    return state
      .set('id', id)
      .set('cell', cell)
      .set('name', name)
      .set('email', email)
      .set('commDevice', commDevice)
      .set('commMobile', commMobile)
      .set('commEmail', commEmail)
      .set('location', location)
      .set('tasks', tasks)
      .set('currentPassword', '')
      .set('newPassword', '')
      .set('newPassword2', '')
  },
  [CONSTANTS.SET_NAME]: (state, { payload }) => state.set('name', payload),
  [CONSTANTS.SET_CELL]: (state, { payload }) => state.set('cell', payload),
  [CONSTANTS.SET_EMAIL]: (state, { payload }) => state.set('email', payload),
  [CONSTANTS.SET_COMM_DEVICE]: (state, { payload }) =>
    state.set('commDevice', payload),
  [CONSTANTS.SET_COMM_EMAIL]: (state, { payload }) =>
    state.set('commEmail', payload),
  [CONSTANTS.SET_COMM_MOBILE]: (state, { payload }) =>
    state.set('commMobile', payload),
  [CONSTANTS.SET_LOCATION]: (state, { payload }) =>
    state.set('location', payload),
  [CONSTANTS.SET_CURRENT_PASSWORD]: (state, { payload }) =>
    state.set('currentPassword', payload),
  [CONSTANTS.SET_NEW_PASSWORD]: (state, { payload }) =>
    state.set('newPassword', payload),
  [CONSTANTS.SET_NEW_PASSWORD2]: (state, { payload }) =>
    state.set('newPassword2', payload)
})

export const viewState = state => state.screens.profile
export const viewSelector = createViewSelector(viewState)

export const id = viewSelector('id', null)
export const cell = viewSelector('cell', '')
export const name = viewSelector('name', '')
export const email = viewSelector('email', '')
export const commDevice = viewSelector('commDevice', false)
export const commMobile = viewSelector('commMobile', false)
export const commEmail = viewSelector('commEmail', false)
export const location = viewSelector('location', '')
export const tasks = viewSelector('tasks', '')
export const currentPassword = viewSelector('currentPassword', '')
export const newPassword = viewSelector('newPassword', '')
export const newPassword2 = viewSelector('newPassword2', '')
export const isLoading = viewSelector('isLoading', false)

export const selectors = {
  id,
  cell,
  name,
  commDevice,
  commMobile,
  commEmail,
  location,
  email,
  tasks,
  currentPassword,
  newPassword,
  newPassword2,
  isLoading
}
