// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { View } from 'react-native'
import { Map, List } from 'immutable'
import { LoaderScreen } from 'components/Loader'
import StyleSheet from 'react-native-extended-stylesheet'
import ResourceList from 'components/ResourceList'
import AudioUpload from './components/AudioUpload'

const styles = StyleSheet.create({
  wrapper: {
    flex: 1,
    backgroundColor: '$White'
  }
})

ProjectAudio.navigationOptions = {
  title: 'Audio'
}

ProjectAudio.propTypes = {
  audio: PropTypes.instanceOf(Map).isRequired,
  audioList: PropTypes.instanceOf(List).isRequired,
  uploadAudio: PropTypes.func.isRequired,
  deleteAudio: PropTypes.func.isRequired,
  isUploading: PropTypes.bool.isRequired,
  hasLoaded: PropTypes.bool.isRequired
}

export default function ProjectAudio ({
  audio,
  audioList,
  deleteAudio,
  hasLoaded,
  ...props
}) {
  if (!hasLoaded) {
    return <LoaderScreen />
  }
  return (
    <View style={styles.wrapper}>
      <AudioUpload {...props} />
      <ResourceList
        resource={audio}
        resourceList={audioList}
        canDelete
        onDelete={deleteAudio}
        field='filename'
        emptyIcon='ios-microphone-outline'
        emptyLabel='This project has no records yet'
      />
    </View>
  )
}
