// @flow
import { Record } from 'immutable'
import createReducer from 'utils/createreducer'
import createConstants from 'utils/createconstants'
import createViewSelector from 'utils/createviewselector'
import {
  ProjectAudioActions,
  ProjectAudioSelectors
} from 'resources/projectaudio'
import fileChooser from 'utils/filechooser'
import { last } from 'lodash'

export const CONSTANTS = createConstants('SCREEN_PROJECTAUDIO', {
  SET_PROJECT: null,
  SET_UPLOADING: null
})

export const actions = {
  initialize ({ projectId }) {
    return async dispatch => {
      dispatch(actions.setProject({ projectId }))
      dispatch(ProjectAudioActions.fetchList({ projectId }))
    }
  },
  setProject ({ projectId }) {
    return {
      type: CONSTANTS.SET_PROJECT,
      payload: projectId
    }
  },
  setIsUploading (isUploading) {
    return {
      type: CONSTANTS.SET_UPLOADING,
      payload: isUploading
    }
  },
  uploadAudio () {
    return async (dispatch, getState) => {
      try {
        const projectId = selectors.projectId(getState())
        const audio = await fileChooser({ audio: true })
        dispatch(actions.setIsUploading(true))
        await Promise.all(
          audio.map(audio => {
            dispatch(
              ProjectAudioActions.uploadAudio({
                projectId,
                filename: last(audio.split('/')),
                filepath: audio
              })
            )
          })
        )
      } catch (err) {
        console.log(err)
      } finally {
        dispatch(actions.setIsUploading(false))
      }
    }
  },
  deleteAudio (fileId) {
    return async (dispatch, getState) => {
      const projectId = selectors.projectId(getState())
      dispatch(ProjectAudioActions.destroyAudio({ fileId, projectId }))
    }
  }
}

export const ProjectAudioState = Record({
  projectId: null,
  isUploading: false
})

export const reducer = createReducer(new ProjectAudioState(), {
  [CONSTANTS.SET_PROJECT]: (state, { payload }) => {
    return state.set('projectId', payload)
  },
  [CONSTANTS.SET_UPLOADING]: (state, { payload }) => {
    return state.set('isUploading', payload)
  }
})

export const viewState = state => state.screens.projectaudio
export const viewSelector = createViewSelector(viewState)
export const projectId = viewSelector('projectId')
export const isUploading = viewSelector('isUploading')

export const selectors = {
  projectId,
  isUploading,
  audio: ProjectAudioSelectors.projectAudio,
  audioList: ProjectAudioSelectors.projectAudioList(projectId),
  hasLoaded: ProjectAudioSelectors.hasProjectAudioLoaded(projectId)
}
