// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { View } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import { TextInput } from 'components/FormControls'
import NavbarButton from 'components/NavbarButton'
import { SolidButton } from 'components/Button'
import { LoaderScreen } from 'components/Loader'
import AddressLabel from './components/AddressLabel'

const styles = StyleSheet.create({
  wrapper: {
    flex: 1,
    padding: 20,
    backgroundColor: '$White'
  },
  button: {
    height: 35,
    marginTop: 25,
    borderRadius: 5
  }
})

ProjectCreate.navigationOptions = ({ navigation, ...other }) => ({
  title: 'New Project',
  headerRight: (
    <NavbarButton onPress={() => navigation.state.params.createProject()}>
      CREATE
    </NavbarButton>
  )
})

ProjectCreate.propTypes = {
  name: PropTypes.string.isRequired,
  setName: PropTypes.func.isRequired,
  address: PropTypes.string.isRequired,
  selectLocation: PropTypes.func.isRequired
}

export default function ProjectCreate ({
  address,
  createProject,
  setName,
  selectLocation,
  name,
  isLoading
}) {
  if (isLoading) {
    return <LoaderScreen />
  }
  return (
    <View style={styles.wrapper}>
      <TextInput label='Name' onChangeText={setName} value={name} />
      <AddressLabel
        label='Address'
        onPress={selectLocation}
        address={address}
      />
      <SolidButton style={styles.button} onPress={createProject}>
        CREATE
      </SolidButton>
    </View>
  )
}
