// @flow
import { Record } from 'immutable'
import { Alert } from 'react-native'
import RNGooglePlacePicker from 'react-native-google-place-picker'
import createReducer from 'utils/createreducer'
import createConstants from 'utils/createconstants'
import createViewSelector from 'utils/createviewselector'
import Geocoder from 'react-native-geocoder'
import * as RouteActions from 'routes/actions'
import { ProjectActions } from 'resources/project'
import { GOOGLE_API_KEY } from '../../config'

Geocoder.fallbackToGoogle(GOOGLE_API_KEY)

export const CONSTANTS = createConstants('SCREEN_PROJECT_CREATE', {
  SET_NAME: null,
  RESET: null,
  SET_LOCATION: null,
  SET_LOADING: null
})

export const actions = {
  initialize () {
    return dispatch => {
      dispatch(actions.reset())
      dispatch(
        RouteActions.setParams({
          createProject: () => dispatch(actions.createProject())
        })
      )
    }
  },
  reset () {
    return {
      type: CONSTANTS.RESET
    }
  },
  setLoading (loading) {
    return {
      type: CONSTANTS.SET_LOADING,
      payload: loading
    }
  },
  setName (name) {
    return {
      type: CONSTANTS.SET_NAME,
      payload: name
    }
  },
  setLocation ({ latitude, longitude, address }) {
    return {
      type: CONSTANTS.SET_LOCATION,
      payload: {
        latitude,
        longitude,
        address
      }
    }
  },
  selectLocation () {
    return dispatch => {
      RNGooglePlacePicker.show(async response => {
        if (response.didCancel || response.error) {
          return
        }
        dispatch(actions.setLoading(true))
        const geocode = await Geocoder.geocodePosition({
          lat: response.latitude,
          lng: response.longitude
        })
        dispatch(
          actions.setLocation({
            latitude: response.latitude,
            longitude: response.longitude,
            address: geocode.length ? response.address : 'Unknown Address'
          })
        )
        dispatch(actions.setLoading(false))
      })
    }
  },
  createProject () {
    return async (dispatch, getState) => {
      const state = getState()
      const name = selectors.name(state)
      const address = selectors.address(state)
      const lat = selectors.lat(state)
      const long = selectors.long(state)
      if (!address || !name) {
        Alert.alert('Nailit!', 'Fill in the details')
        return
      }
      try {
        dispatch(actions.setLoading(true))
        await dispatch(
          ProjectActions.createProject({
            name,
            address,
            lat,
            long
          })
        )
        await dispatch(ProjectActions.fetchList())
        dispatch(RouteActions.back())
      } catch (error) {
        console.log('creating project error', error)
        Alert.alert('Nailit!', 'Could not create project')
      } finally {
        dispatch(actions.setLoading(false))
      }
    }
  }
}

export const ProjectCreateState = Record({
  name: '',
  lat: 0,
  isLoading: false,
  long: 0,
  address: ''
})

export const reducer = createReducer(new ProjectCreateState(), {
  [CONSTANTS.RESET]: () => new ProjectCreateState(),
  [CONSTANTS.SET_NAME]: (state, { payload }) => state.set('name', payload),
  [CONSTANTS.SET_LOADING]: (state, { payload }) =>
    state.set('isLoading', payload),
  [CONSTANTS.SET_LOCATION]: (state, { payload }) => {
    const { latitude, longitude, address } = payload
    return state
      .set('lat', latitude)
      .set('long', longitude)
      .set('address', address)
  }
})

export const viewState = state => state.screens.projectcreate
export const viewSelector = createViewSelector(viewState)
export const name = viewSelector('name')
export const long = viewSelector('long')
export const lat = viewSelector('lat')
export const address = viewSelector('address')
export const isLoading = viewSelector('isLoading')

export const selectors = {
  name,
  address,
  long,
  lat,
  isLoading
}
