// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { View } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import { TextInput } from 'components/FormControls'
import NavbarButton from 'components/NavbarButton'
import { SolidButton } from 'components/Button'
import { LoaderScreen } from 'components/Loader'
import AddressLabel from './components/AddressLabel'

const styles = StyleSheet.create({
  wrapper: {
    flex: 1,
    padding: 20,
    backgroundColor: '$White'
  },
  button: {
    height: 35,
    marginTop: 25,
    borderRadius: 5
  }
})

ProjectEdit.navigationOptions = ({ navigation, ...other }) => ({
  title: 'Project Edit',
  headerRight: (
    <NavbarButton onPress={() => navigation.state.params.saveProject()}>
      SAVE
    </NavbarButton>
  )
})

ProjectEdit.propTypes = {
  name: PropTypes.string.isRequired,
  setName: PropTypes.func.isRequired,
  address: PropTypes.string.isRequired,
  selectLocation: PropTypes.func.isRequired
}

export default function ProjectEdit ({
  address,
  saveProject,
  setName,
  selectLocation,
  name,
  projectNumber,
  setProjectNumber,
  setContactNumber,
  setContactName,
  contacts,
  isLoading
}) {
  if (isLoading) {
    return <LoaderScreen />
  }
  return (
    <View style={styles.wrapper}>
      <TextInput label='Project Name' onChangeText={setName} value={name} />
      <AddressLabel
        label='Project Address'
        onPress={selectLocation}
        address={address}
      />
      <TextInput
        label='Project Phone Number'
        onChangeText={setProjectNumber}
        value={projectNumber}
      />
      <TextInput
        label='Project Contact Name'
        onChangeText={value => setContactName(0, value)}
        value={contacts.getIn([0, 'name'])}
      />
      <TextInput
        label='Project Contact Phone Number'
        onChangeText={value => setContactNumber(0, value)}
        value={contacts.getIn([0, 'phone'])}
      />
      <SolidButton style={styles.button} onPress={saveProject}>
        SAVE
      </SolidButton>
    </View>
  )
}
