// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { View } from 'react-native'
import { Map, List } from 'immutable'
import { LoaderScreen } from 'components/Loader'
import StyleSheet from 'react-native-extended-stylesheet'
import ResourceList from 'components/ResourceList'
import FileUpload from './components/FileUpload'

const styles = StyleSheet.create({
  wrapper: {
    flex: 1,
    backgroundColor: '$White'
  }
})

ProjectFile.navigationOptions = {
  title: 'Files'
}

ProjectFile.propTypes = {
  files: PropTypes.instanceOf(Map).isRequired,
  fileList: PropTypes.instanceOf(List).isRequired,
  uploadFile: PropTypes.func.isRequired,
  isUploading: PropTypes.bool.isRequired,
  deleteFile: PropTypes.func.isRequired,
  hasLoaded: PropTypes.bool.isRequired,
  viewFile: PropTypes.func.isRequired
}

export default function ProjectFile ({
  files,
  fileList,
  deleteFile,
  hasLoaded,
  isUploading,
  viewFile,
  ...props
}) {
  if (!hasLoaded || isUploading) {
    return <LoaderScreen />
  }
  return (
    <View style={styles.wrapper}>
      <FileUpload {...props} isUploading={isUploading} />
      <ResourceList
        resource={files}
        resourceList={fileList}
        canDelete
        onDelete={deleteFile}
        field='filename'
        onPress={viewFile}
        emptyIcon='ios-folder-outline'
        emptyLabel='This project has no files yet'
      />
    </View>
  )
}
