// @flow
import { Record } from 'immutable'
import { Linking } from 'react-native'
import createReducer from 'utils/createreducer'
import createConstants from 'utils/createconstants'
import createViewSelector from 'utils/createviewselector'
import { ProjectFileActions, ProjectFileSelectors } from 'resources/projectfile'
import fileChooser from 'utils/filechooser'
import { last } from 'lodash'
import sleep from 'utils/sleep'

export const CONSTANTS = createConstants('SCREEN_PROJECTFILE', {
  SET_PROJECT: null,
  SET_UPLOADING: null
})

export const actions = {
  initialize ({ projectId }) {
    return async dispatch => {
      dispatch(actions.setProject({ projectId }))
      dispatch(ProjectFileActions.fetchList({ projectId }))
    }
  },
  setProject ({ projectId }) {
    return {
      type: CONSTANTS.SET_PROJECT,
      payload: projectId
    }
  },
  setIsUploading (isUploading) {
    return {
      type: CONSTANTS.SET_UPLOADING,
      payload: isUploading
    }
  },
  viewFile ({ id }) {
    return (_, getState) => {
      const files = ProjectFileSelectors.projectFile(getState())
      const file = files.get(id)
      Linking.openURL(file.get('url'))
    }
  },
  uploadFile () {
    return async (dispatch, getState) => {
      try {
        const projectId = selectors.projectId(getState())
        const images = await fileChooser({
          images: true,
          audio: true,
          video: true,
          pdf: true
        })
        dispatch(actions.setIsUploading(true))
        await Promise.all(
          images.map(image =>
            dispatch(
              ProjectFileActions.uploadFile({
                projectId,
                filename: last(image.split('/')),
                filepath: image
              })
            )
          )
        )
        await sleep(300)
        await dispatch(ProjectFileActions.fetchList({ projectId }))
        dispatch(actions.setIsUploading(false))
      } catch (err) {
        console.log(err)
      } finally {
        dispatch(actions.setIsUploading(false))
      }
    }
  },
  deleteFile (imageId) {
    return async (dispatch, getState) => {
      const projectId = selectors.projectId(getState())
      await dispatch(ProjectFileActions.destroyFile({ imageId, projectId }))
      await dispatch(ProjectFileActions.fetchList({ projectId }))
    }
  }
}

export const ProjectFileState = Record({
  projectId: null,
  isUploading: false
})

export const reducer = createReducer(new ProjectFileState(), {
  [CONSTANTS.SET_PROJECT]: (state, { payload }) => {
    return state.set('projectId', payload)
  },
  [CONSTANTS.SET_UPLOADING]: (state, { payload }) => {
    return state.set('isUploading', payload)
  }
})

export const viewState = state => state.screens.projectfile
export const viewSelector = createViewSelector(viewState)
export const projectId = viewSelector('projectId')
export const isUploading = viewSelector('isUploading')

export const selectors = {
  projectId,
  isUploading,
  files: ProjectFileSelectors.projectFile,
  fileList: ProjectFileSelectors.projectFileList(projectId),
  hasLoaded: ProjectFileSelectors.hasProjectFileLoaded(projectId)
}
