// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { View } from 'react-native'
import { Map, List } from 'immutable'
import { LoaderScreen } from 'components/Loader'
import StyleSheet from 'react-native-extended-stylesheet'
import ResourceList from 'components/ResourceList'
import ImageUpload from './components/ImageUpload'

const styles = StyleSheet.create({
  wrapper: {
    flex: 1,
    backgroundColor: '$White'
  }
})

ProjectImage.navigationOptions = {
  title: 'Camera'
}

ProjectImage.propTypes = {
  images: PropTypes.instanceOf(Map).isRequired,
  imageList: PropTypes.instanceOf(List).isRequired,
  uploadImage: PropTypes.func.isRequired,
  deleteImage: PropTypes.func.isRequired,
  hasLoaded: PropTypes.bool.isRequired
}

export default function ProjectImage ({
  images,
  imageList,
  deleteImage,
  isUploading,
  hasLoaded,
  ...props
}) {
  if (!hasLoaded || isUploading) {
    return <LoaderScreen />
  }
  return (
    <View style={styles.wrapper}>
      <ImageUpload {...props} />
      <ResourceList
        resource={images}
        resourceList={imageList}
        canDelete
        onDelete={deleteImage}
        field='filename'
        emptyIcon='ios-images-outline'
        emptyLabel='This project has no images yet'
      />
    </View>
  )
}
