// @flow
import ActionSheet from '@yfuks/react-native-action-sheet'
import { Record } from 'immutable'
import createReducer from 'utils/createreducer'
import createConstants from 'utils/createconstants'
import createViewSelector from 'utils/createviewselector'
import {
  ProjectImageActions,
  ProjectImageSelectors
} from 'resources/projectimage'
import fileChooser from 'utils/filechooser'
import { last } from 'lodash'

export const CONSTANTS = createConstants('SCREEN_PROJECTIMAGE', {
  SET_PROJECT: null,
  SET_UPLOADING: null
})

export const actions = {
  initialize ({ projectId }) {
    return async dispatch => {
      dispatch(actions.setProject({ projectId }))
      dispatch(ProjectImageActions.fetchList({ projectId }))
    }
  },
  setProject ({ projectId }) {
    return {
      type: CONSTANTS.SET_PROJECT,
      payload: projectId
    }
  },
  setIsUploading (isUploading) {
    return {
      type: CONSTANTS.SET_UPLOADING,
      payload: isUploading
    }
  },
  sendPhoto (chooseParams) {
    return async (dispatch, getState) => {
      try {
        const projectId = selectors.projectId(getState())
        const images = await fileChooser(chooseParams)
        dispatch(actions.setIsUploading(true))
        await Promise.all(
          images.map(image =>
            dispatch(
              ProjectImageActions.uploadImage({
                projectId,
                filename: last(image.split('/')),
                filepath: image
              })
            )
          )
        )
      } catch (err) {
        console.log(err)
      } finally {
        // api takes a while to process our uploads
        setTimeout(() => {
          const projectId = selectors.projectId(getState())
          dispatch(ProjectImageActions.fetchList({ projectId }))
          dispatch(actions.setIsUploading(false))
        }, 2000)
      }
    }
  },
  deleteImage (imageId) {
    return async (dispatch, getState) => {
      const projectId = selectors.projectId(getState())
      dispatch(ProjectImageActions.destroyImage({ imageId, projectId }))
    }
  },
  uploadImage () {
    return (dispatch, getState) => {
      const options = [
        'Send Photo from Camera',
        'Send Photo from Library',
        'Send Photo from Dropbox',
        'Cancel'
      ].filter(value => value)
      ActionSheet.showActionSheetWithOptions(
        {
          options,
          cancelButtonIndex: options.length - 1
        },
        buttonIndex => {
          if (buttonIndex === options.length - 1) {
            return
          }
          switch (buttonIndex) {
            case 0:
              dispatch(actions.sendPhoto({ camera: true }))
              break
            case 1:
              dispatch(actions.sendPhoto({ library: true }))
              break
            case 2:
              dispatch(actions.sendPhoto({ images: true }))
              break
          }
        }
      )
    }
  }
}

export const ProjectImageState = Record({
  projectId: null,
  isUploading: false
})

export const reducer = createReducer(new ProjectImageState(), {
  [CONSTANTS.SET_PROJECT]: (state, { payload }) => {
    return state.set('projectId', payload)
  },
  [CONSTANTS.SET_UPLOADING]: (state, { payload }) => {
    return state.set('isUploading', payload)
  }
})

export const viewState = state => state.screens.projectimage
export const viewSelector = createViewSelector(viewState)
export const projectId = viewSelector('projectId')
export const isUploading = viewSelector('isUploading')

export const selectors = {
  projectId,
  isUploading,
  images: ProjectImageSelectors.projectImage,
  imageList: ProjectImageSelectors.projectImageList(projectId),
  hasLoaded: ProjectImageSelectors.hasProjectImageLoaded(projectId)
}
