// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { Record } from 'immutable'
import StyleSheet from 'react-native-extended-stylesheet'
import { View, ScrollView } from 'react-native'
import NavbarButton from 'components/NavbarButton'
import { SolidButton } from 'components/Button'
import ProjectMap from './components/ProjectMap'
import ButtonBar from './components/ButtonBar'
import SubsView from './components/SubsView'
import ProjectTabBar from './components/ProjectTabBar'
import ProjectInfoLoader from './components/ProjectInfoLoader'
import Modal from 'components/Modal'
import { SCREEN_WIDTH } from 'utils/device'

const styles = StyleSheet.create({
  wrapper: {
    backgroundColor: '$White',
    flex: 1
  },
  row: {
    flexDirection: 'row',
    marginTop: 20,
    marginLeft: 10,
    marginRight: 10
  },
  announceButton: {
    marginRight: 10,
    flex: 1,
    borderRadius: 5,
    paddingTop: 10,
    paddingBottom: 10,
    width: SCREEN_WIDTH / 2 - 15
  },
  addSubButton: {
    flex: 1,
    borderRadius: 5,
    paddingTop: 10,
    paddingBottom: 10,
    width: SCREEN_WIDTH / 2 - 15
  }
})

ProjectInfo.navigationOptions = ({ navigation }) => ({
  title: navigation.state.params.title || 'Project Info',
  headerRight: !navigation.state.params.isSub && (
    <NavbarButton
      onPress={() => navigation.state.params.editProject()}
      name='md-create'
      size={25}
    />
  )
})

ProjectInfo.propTypes = {
  addSub: PropTypes.func.isRequired,
  announce: PropTypes.func.isRequired,
  project: PropTypes.instanceOf(Record),
  hasLoaded: PropTypes.bool.isRequired,
  isLoading: PropTypes.bool.isRequired,
  toCaptureImages: PropTypes.func.isRequired,
  toRecord: PropTypes.func.isRequired,
  toInbox: PropTypes.func.isRequired,
  toAttachFiles: PropTypes.func.isRequired,
  onDelete: PropTypes.func.isRequired
}

export default function ProjectInfo ({
  addSub,
  announce,
  hasLoaded,
  isLoading,
  project,
  toCaptureImages,
  toRecord,
  toAttachFiles,
  toInbox,
  isSub,
  ...props
}) {
  const tabs = [
    {
      name: 'INBOX',
      image: 'ios-mail-outline',
      onPress: toInbox
    },
    {
      name: 'CAMERA',
      image: 'ios-camera-outline',
      onPress: toCaptureImages
    } /*,    {      name: 'RECORD',      image: 'ios-microphone-outline',      onPress: toRecord    } */,
    {
      name: 'FILES',
      image: 'ios-attach-outline',
      onPress: toAttachFiles
    }
  ]
  if (!hasLoaded || isLoading) {
    return <ProjectInfoLoader />
  }
  return (
    <View style={styles.wrapper}>
      <ButtonBar isSub={false} {...props} />
      <ProjectMap project={project} {...props} />
      <ScrollView style={styles.wrapper}>
        {!isSub && (
          <View style={styles.row}>
            <SolidButton style={styles.announceButton} onPress={announce}>
              ANNOUNCE TO TEAM
            </SolidButton>
            <SolidButton style={styles.addSubButton} onPress={addSub}>
              ADD TO TEAM
            </SolidButton>
          </View>
        )}
        <SubsView {...props} isSub={isSub} />
      </ScrollView>
      <ProjectTabBar tabs={tabs} />
      <Modal />
    </View>
  )
}
