import React from 'react'
import { shallow } from 'enzyme'
import ButtonBar from '../components/ButtonBar'
import { OpacityButton } from 'components/Button'

function renderHelper ({ ...props }) {
  const noop = () => {}
  return shallow(
    <ButtonBar
      hasPhoneNumber
      toMessage={noop}
      toCall={noop}
      toDirections={noop}
      {...props}
    />
  )
}

describe('Project Info ButtonBar', () => {
  it.skip('should not change by accident', () => {
    expect(renderHelper()).toMatchSnapshot()
  })
  it('should render 3 buttons', () => {
    const node = renderHelper()
    expect(node.find(OpacityButton)).toHaveLength(3)
  })
  it('should map the callbacks as expected', () => {
    const toMessage = jest.fn()
    const toCall = jest.fn()
    const toDirections = jest.fn()
    const node = renderHelper({
      toMessage,
      toCall,
      toDirections
    })
    const messageButton = node
      .find(OpacityButton)
      .findWhere(node => node.prop('leftIcon') === 'ios-chatbubbles-outline')
    expect(messageButton.prop('onPress')).toBe(toMessage)
    const callButton = node
      .find(OpacityButton)
      .findWhere(node => node.prop('leftIcon') === 'ios-call-outline')
    expect(callButton.prop('onPress')).toBe(toCall)
    const directionButton = node
      .find(OpacityButton)
      .findWhere(node => node.prop('leftIcon') === 'ios-car-outline')
    expect(directionButton.prop('onPress')).toBe(toDirections)
  })
  it('should not let you message if the project owner does not have a phone number', () => {
    const toMessage = jest.fn()
    const node = renderHelper({
      toMessage,
      hasPhoneNumber: false
    })
    const messageButton = node
      .find(OpacityButton)
      .findWhere(node => node.prop('leftIcon') === 'ios-chatbubbles-outline')
    expect(messageButton.prop('onPress')).not.toBe(toMessage)
  })
})
