import React from 'react'
import { ProjectSchema } from 'resources/project'
import { shallow } from 'enzyme'
import { Text } from 'react-native'
import MapView from 'react-native-maps'
import ProjectMap from '../components/ProjectMap'
import MapMarker from '../components/MapMarker'
import { LATITUDE_DEFAULT, LONGITUDE_DEFAULT } from 'utils/mapdefaults'

function renderHelper ({ ...projectDetails }) {
  const project = new ProjectSchema({
    lat: 25,
    long: 66,
    address: 'Route 88',
    ...projectDetails
  })
  return shallow(<ProjectMap project={project} />)
}

describe('Project Info ProjectMap', () => {
  it('should render a MapView centered on the project coordinates', () => {
    const node = renderHelper()
    expect(node.find(MapView).exists()).toBeTruthy()
    expect(node.find(MapView).prop('region').latitude).toBe(25)
    expect(node.find(MapView).prop('region').longitude).toBe(66)
  })
  it('should render a marker in the project coordinates', () => {
    const node = renderHelper()
    expect(node.find(MapView.Marker).exists()).toBeTruthy()
    expect(node.find(MapMarker).exists()).toBeTruthy()
    expect(node.find(MapView.Marker).prop('coordinate').latitude).toBe(25)
    expect(node.find(MapView.Marker).prop('coordinate').longitude).toBe(66)
  })
  it('should default coordinates if not available', () => {
    const node = renderHelper({
      lat: undefined,
      long: undefined
    })
    expect(node.find(MapView).prop('region').latitude).toBe(LATITUDE_DEFAULT)
    expect(node.find(MapView).prop('region').longitude).toBe(LONGITUDE_DEFAULT)
  })
  it('should render the project address', () => {
    const node = renderHelper({
      location: 'Route 66'
    })
    expect(node.find(Text).prop('children')).toBe('Route 66')
  })
  it('should default project address if unavilable', () => {
    const node = renderHelper({ address: '' })
    expect(node.find(Text).prop('children')).toBe('No address set yet')
  })
})
