import React from 'react'
import { shallow } from 'enzyme'
import ProjectTabBar from '../components/ProjectTabBar'
import ProjectTabButton from '../components/ProjectTabButton'

function renderHelper ({ tabs, toCaptureImages, toRecord, toAttachFiles } = {}) {
  const propToCaptureImages = toCaptureImages || jest.fn()
  const propToRecord = toRecord || jest.fn()
  const propToAttachFiles = toAttachFiles || jest.fn()
  const renderTabs = tabs || [
    {
      name: 'CAMERA',
      image: 'ios-camera-outline',
      onPress: propToCaptureImages
    },
    {
      name: 'RECORD',
      image: 'ios-microphone-outline',
      onPress: propToRecord
    },
    {
      name: 'FILES',
      image: 'ios-attach-outline',
      onPress: propToAttachFiles
    }
  ]
  return shallow(<ProjectTabBar tabs={renderTabs} />)
}

describe('Project Info ProjectTabBar', () => {
  it('should render a list of ProjectTabButton', () => {
    const node = renderHelper()
    expect(node.find(ProjectTabButton)).toHaveLength(3)
  })
  it('should pass the expected props', () => {
    const toCaptureImages = jest.fn()
    const toRecord = jest.fn()
    const toAttachFiles = jest.fn()
    const node = renderHelper({
      toCaptureImages,
      toRecord,
      toAttachFiles
    })
    const cameraTab = node.find(ProjectTabButton).at(0)
    expect(cameraTab.prop('onPress')).toBe(toCaptureImages)
    expect(cameraTab.prop('name')).toBe('CAMERA')
    expect(cameraTab.prop('image')).toBe('ios-camera-outline')

    const recordTab = node.find(ProjectTabButton).at(1)
    expect(recordTab.prop('onPress')).toBe(toRecord)
    expect(recordTab.prop('name')).toBe('RECORD')
    expect(recordTab.prop('image')).toBe('ios-microphone-outline')

    const filesTab = node.find(ProjectTabButton).at(2)
    expect(filesTab.prop('onPress')).toBe(toAttachFiles)
    expect(filesTab.prop('name')).toBe('FILES')
    expect(filesTab.prop('image')).toBe('ios-attach-outline')
  })
})
