import React from 'react'
import { shallow } from 'enzyme'
import { fromJS } from 'immutable'
import { SwipeableFlatList } from 'react-native-swipeable-flat-list'
import SubsList from '../components/SubsList'
import SubRow from '../components/SubRow'

function renderHelper ({ ...props }) {
  const toConversation = jest.fn()
  const users = fromJS({
    '1': {
      name: 'someone'
    }
  })
  const tasks = fromJS({
    '3': {
      taskName: 'windows',
      taskSub: [
        {
          id: '1',
          conversationId: '33',
          roomId: '55'
        }
      ]
    }
  })

  return shallow(
    <SubsList
      toConversation={toConversation}
      users={users}
      tasks={tasks}
      userId='1'
      taskId='3'
      onDelete={jest.fn()}
      tasksSubList={fromJS([{ user: '1', task: '3' }])}
      {...props}
    />
  )
}

describe('Project Info SubList', () => {
  it('should render a flat list of SubRow', () => {
    const node = renderHelper()
    const list = node.find(SwipeableFlatList)
    expect(list.exists()).toBe(true)
    expect(list.prop('data')).toEqual([{ userId: '1', taskId: '3' }])
  })
  it('should pass down tasks subs toConversation and item props', () => {
    const users = fromJS({
      '1': {
        name: 'someone'
      }
    })
    const tasks = fromJS({
      '3': {
        taskName: 'windows',
        taskSub: [
          {
            id: '1',
            conversationId: '33',
            roomId: '55'
          }
        ]
      }
    })
    const toConversation = jest.fn()
    const node = renderHelper({ users, tasks, toConversation })
    const list = node.find(SwipeableFlatList)
    const RowRenderer = list.prop('renderItem')
    const rowNode = shallow(
      <RowRenderer item={{ userId: '34', taskId: '25' }} />
    )
    const subrow = rowNode.find(SubRow)
    expect(subrow.exists()).toBe(true)
    expect(subrow.prop('userId')).toBe('34')
    expect(subrow.prop('taskId')).toBe('25')
    expect(subrow.prop('users')).toBe(users)
    expect(subrow.prop('tasks')).toBe(tasks)
    expect(subrow.prop('toConversation')).toBe(toConversation)
  })
})
