import React from 'react'
import { shallow } from 'enzyme'
import { fromJS } from 'immutable'
import { Text, TouchableOpacity } from 'react-native'
import SubRow from '../components/SubRow'
import Icon from 'components/Icon'

function renderHelper ({ ...props }) {
  const toConversation = jest.fn()
  const users = fromJS({
    '1': {
      name: 'someone'
    }
  })
  const tasks = fromJS({
    '3': {
      name: 'windows',
      taskSub: [
        {
          id: '1',
          conversationId: '33',
          roomId: '55'
        }
      ]
    }
  })
  const userId = '1'
  const taskId = '3'

  return shallow(
    <SubRow
      toConversation={toConversation}
      users={users}
      tasks={tasks}
      userId={userId}
      taskId={taskId}
      {...props}
    />
  )
}

describe('Project Info SubRow', () => {
  it('should not change by accident', () => {
    expect(renderHelper()).toMatchSnapshot()
  })
  it('should render the sub name', () => {
    const node = renderHelper({
      users: fromJS({
        '2': {
          name: 'Daniele'
        }
      }),
      userId: '2'
    })
    expect(
      node
        .find(Text)
        .at(0)
        .children()
        .text()
    ).toBe('Daniele')
  })
  it('should render the sub task', () => {
    const node = renderHelper({
      tasks: fromJS({
        '2': {
          name: 'doors',
          taskSub: [
            {
              id: '1',
              conversationId: '33',
              roomId: '55'
            }
          ]
        }
      }),
      taskId: '2'
    })
    expect(
      node
        .find(Text)
        .at(1)
        .children()
        .text()
    ).toBe('doors')
  })
  it('should render the icon forward', () => {
    const node = renderHelper()
    expect(node.find(Icon).prop('name')).toBe('ios-arrow-forward')
  })
  it('should call the callback when touched', () => {
    const toConversation = jest.fn()
    const node = renderHelper({ toConversation, userId: '1', taskId: '3' })
    node.find(TouchableOpacity).prop('onPress')()
    expect(toConversation).toHaveBeenCalledWith({
      conversationId: '33',
      roomId: '55',
      userId: '1'
    })
  })
  it('should default to unassigned if task does not exist', () => {
    const node = renderHelper({ taskId: '66' })
    expect(
      node
        .find(Text)
        .at(1)
        .children()
        .text()
    ).toBe('Unassigned')
  })
})
