import createStoreForTesting from 'test/createstore'
import projectInfoRecord from 'test/records/projectinfo.json'
import { UserActions } from 'resources/user'
import { actions, selectors } from '../module'
import { API_URL } from '../../../config'
import projectTasksRecord from 'test/records/projecttasks.json'
import projectTaskSubRecord from 'test/records/projecttasksub.json'

describe('Project Info Screen', () => {
  describe('module', () => {
    it('initialize should load the expected project and trades', async () => {
      const store = createStoreForTesting()
      const projectId = '768'
      const userId = '45'
      store.dispatch(UserActions.setCurrentUser(userId))
      store.addResponse(projectInfoRecord)
      store.addResponse(projectTaskSubRecord)
      store.addResponse(projectTasksRecord)
      await store.dispatch(actions.initialize({ projectId }))
      expect(selectors.projectId(store.getState())).toBe(projectId)
      expect(selectors.project(store.getState()).toJS().id).toBe(projectId)
      expect(fetch).toHaveBeenCalledWith(
        `${API_URL}/get/project/${projectId}/${userId}`,
        {
          headers: {
            Accept: 'application/json',
            'Content-Type': 'application/json'
          },
          method: 'GET'
        }
      )
    })
    it('sets the project id', () => {
      const store = createStoreForTesting()
      store.dispatch(actions.setProjectId('44'))
      expect(selectors.projectId(store.getState())).toBe('44')
    })
  })
})
