// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { View } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import { OpacityButton } from 'components/Button'
import { SCREEN_WIDTH } from 'utils/device'

const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    width: SCREEN_WIDTH,
    height: 40,
    alignItems: 'center',
    shadowColor: 'rgba(0,0,0,.1)',
    shadowOffset: { width: 0, height: 0 },
    shadowOpacity: 1,
    shadowRadius: 3,
    zIndex: 3
  },
  button: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center'
  },
  separator: {
    height: 34,
    backgroundColor: '$DarkDivider',
    width: 1,
    marginLeft: 5,
    marginRight: 5
  },
  icon: {
    marginRight: 10
  },
  text: {
    fontWeight: 'normal',
    fontSize: 15
  }
})

ButtonBar.propTypes = {
  hasPhoneNumber: PropTypes.bool.isRequired,
  toMessage: PropTypes.func.isRequired,
  toCall: PropTypes.func.isRequired,
  toDirections: PropTypes.func.isRequired
}

export default function ButtonBar ({
  hasPhoneNumber,
  toMessage,
  toCall,
  toDirections,
  isSub
}) {
  const safeToMessage = hasPhoneNumber ? toMessage : () => {}
  return (
    <View style={styles.container}>
      <OpacityButton
        leftIcon='ios-chatbubbles-outline'
        buttonStyle={styles.button}
        iconStyle={[styles.icon, !hasPhoneNumber ? styles.iconDisabled : {}]}
        textStyle={styles.text}
        disabled={!hasPhoneNumber || isSub}
        onPress={safeToMessage}
      >
        Message
      </OpacityButton>
      <View style={styles.separator} />
      <OpacityButton
        leftIcon='ios-call-outline'
        buttonStyle={styles.button}
        iconStyle={styles.icon}
        textStyle={styles.text}
        disabled={isSub}
        onPress={toCall}
      >
        Call
      </OpacityButton>
      <View style={styles.separator} />
      <OpacityButton
        leftIcon='ios-car-outline'
        buttonStyle={styles.button}
        iconStyle={styles.icon}
        textStyle={styles.text}
        onPress={toDirections}
      >
        Directions
      </OpacityButton>
    </View>
  )
}
