// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { Record, Map } from 'immutable'
import StyleSheet from 'react-native-extended-stylesheet'
import { View, Text } from 'react-native'
import font from 'utils/font'

const styles = StyleSheet.create({
  textContainer: {
    position: 'absolute',
    top: 5,
    left: 5,
    right: 5,
    height: 20,
    backgroundColor: '$White',
    borderRadius: 5,
    shadowColor: 'rgba(0,0,0,.1)',
    shadowOffset: { width: 0, height: 0 },
    shadowOpacity: 1,
    shadowRadius: 3,
    zIndex: 3,
    padding: 5,
    alignItems: 'center',
    justifyContent: 'center',
    flexDirection: 'row'
  },
  subs: {
    ...font({ weight: 'bold' }),
    fontSize: 16,
    marginTop: 10,
    alignSelf: 'center'
  },
  leftForm: {
    fontSize: 14
  },
  rightForm: {
    ...font({ weight: 'bold' }),
    marginLeft: 5,
    fontSize: 13
  }
})

ProjectDetails.propTypes = {
  project: PropTypes.instanceOf(Record).isRequired,
  contacts: PropTypes.instanceOf(Map)
}

export default function ProjectDetails ({ project, contacts }) {
  const contact = contacts.get(project.getIn(['contacts', 0]))
  if (!contact) {
    return null
  }
  return (
    <View style={styles.textContainer}>
      <Text style={styles.leftForm}>Contact:</Text>
      <Text numberOfLines={1} style={styles.rightForm}>
        {contact.name}
      </Text>
    </View>
  )
}
