// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { Record } from 'immutable'
import StyleSheet from 'react-native-extended-stylesheet'
import { View, Text } from 'react-native'
import MapView from 'react-native-maps'
import {
  LATITUDE_DELTA,
  LONGITUDE_DELTA,
  LATITUDE_DEFAULT,
  LONGITUDE_DEFAULT
} from 'utils/mapdefaults'
import { SCREEN_WIDTH } from 'utils/device'
import sanitizeLocation from 'utils/sanitizelocation'
import MapMarker from './MapMarker'
import ProjectDetails from './ProjectDetails'

const styles = StyleSheet.create({
  container: {
    height: 200,
    position: 'relative'
  },
  textContainer: {
    position: 'absolute',
    bottom: 5,
    left: 5,
    right: 5,
    height: 30,
    backgroundColor: '$White',
    borderRadius: 5,
    shadowColor: 'rgba(0,0,0,.1)',
    shadowOffset: { width: 0, height: 0 },
    shadowOpacity: 1,
    shadowRadius: 3,
    zIndex: 3,
    padding: 5,
    alignItems: 'center',
    justifyContent: 'center'
  },
  text: {
    color: '$Primary',
    fontSize: 12
  },
  map: {
    width: SCREEN_WIDTH,
    height: 199
  },
  border: {
    height: 1,
    width: SCREEN_WIDTH,
    backgroundColor: '$LightText'
  }
})

ProjectMap.propTypes = {
  project: PropTypes.instanceOf(Record).isRequired
}

export default function ProjectMap ({ project, contacts }) {
  const coordinates = {
    latitude: project.get('lat') || LATITUDE_DEFAULT,
    longitude: project.get('long') || LONGITUDE_DEFAULT
  }
  return (
    <View style={styles.container}>
      <MapView
        style={styles.map}
        region={{
          ...coordinates,
          latitudeDelta: LATITUDE_DELTA,
          longitudeDelta: LONGITUDE_DELTA
        }}
        showsMyLocationButton={false}
        showsPointsOfInterest={false}
        showsCompass={false}
        showsScale={false}
        showsBuildings={false}
        showsTraffic={false}
        zoomEnabled={false}
        rotateEnabled={false}
        scrollEnabled={false}
        pitchEnabled={false}
        toolbarEnabled={false}
      >
        <MapView.Marker coordinate={coordinates}>
          <MapMarker />
        </MapView.Marker>
      </MapView>
      <ProjectDetails project={project} contacts={contacts} />
      <View style={styles.textContainer}>
        <Text numberOfLines={1} ellipsizeMode='middle' style={styles.text}>
          {sanitizeLocation(project.get('location')) || 'No address set yet'}
        </Text>
      </View>
      <View style={styles.border} />
    </View>
  )
}
