// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { Map } from 'immutable'
import { TouchableOpacity, View, Text } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import font from 'utils/font'
import Icon from 'components/Icon'
import COLORS from '../../../colors'

const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    height: 60,
    paddingLeft: 15,
    paddingRight: 15,
    borderColor: '$LightDivider',
    borderBottomWidth: 1,
    alignItems: 'center',
    justifyContent: 'space-between'
  },
  name: {
    ...font({ weight: 'bold' }),
    color: '$Primary',
    textAlign: 'left',
    fontSize: 15
  },
  address: {
    color: '$DarkText',
    fontSize: 13,
    marginTop: 5,
    textAlign: 'left'
  }
})

SubRow.propTypes = {
  toConversation: PropTypes.func.isRequired,
  users: PropTypes.instanceOf(Map).isRequired,
  tasks: PropTypes.instanceOf(Map).isRequired,
  userId: PropTypes.string.isRequired,
  taskId: PropTypes.string.isRequired
}

export default function SubRow ({
  toConversation,
  users,
  tasks,
  userId,
  isSub,
  taskId
}) {
  const task = tasks.get(taskId)
  const user = users.get(userId)
  const taskSub =
    task && task.get('taskSub').find(taskSub => taskSub.get('id') === userId)
  const onPress = () =>
    !isSub &&
    toConversation({
      conversationId: taskSub.get('conversationId'),
      roomId: taskSub.get('roomId'),
      userId: taskSub.get('id')
    })
  return (
    <TouchableOpacity onPress={taskSub && onPress}>
      <View style={styles.container}>
        <View style={styles.inputText}>
          <Text style={styles.name}>{user.get('name')}</Text>
          <Text style={styles.address}>
            {(task && task.get('name')) || 'Unassigned'}
          </Text>
        </View>
        {!isSub && (
          <Icon name='ios-arrow-forward' size={20} color={COLORS.Primary} />
        )}
      </View>
    </TouchableOpacity>
  )
}
