// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { List, Map } from 'immutable'
import StyleSheet from 'react-native-extended-stylesheet'
import { SwipeableFlatList } from 'react-native-swipeable-flat-list'
import SubRow from './SubRow'
import SubDelete from './SubDelete'
import COLORS from '../../../colors'

const styles = StyleSheet.create({
  wrapper: {
    backgroundColor: '$White',
    flex: 1
  },
  container: {
    flex: 1
  }
})

SubsList.propTypes = {
  toConversation: PropTypes.func.isRequired,
  tasksSubList: PropTypes.instanceOf(List),
  onDelete: PropTypes.func.isRequired,
  users: PropTypes.instanceOf(Map),
  tasks: PropTypes.instanceOf(Map)
}

export default function SubsList ({
  toConversation,
  onDelete,
  tasks,
  users,
  isSub,
  tasksSubList
}) {
  const flattenedList = tasksSubList
    .toJS()
    .map(({ user, task }) => ({ userId: user, taskId: task }))
  const rowRenderer = ({ item }) => (
    <SubRow
      {...item}
      tasks={tasks}
      users={users}
      style={{ height: 60 }}
      isSub={false}
      toConversation={toConversation}
    />
  )
  const rowRightRenderer = ({ item }) => (
    <SubDelete
      key={item.id}
      {...item}
      tasks={tasks}
      style={{ height: 75, width: 75 }}
      onDelete={onDelete}
    />
  )
  if (isSub) {
    return (
      <SwipeableFlatList
        data={flattenedList}
        keyExtractor={(item, index) => `${index}-${item.userId}-${item.taskId}`}
        renderItem={rowRenderer}
        style={styles.container}
      />
    )
  }
  return (
    <SwipeableFlatList
      data={flattenedList}
      keyExtractor={(item, index) => `${index}-${item.userId}-${item.taskId}`}
      renderItem={rowRenderer}
      style={styles.container}
      renderRight={rowRightRenderer}
      backgroundColor={COLORS.White}
    />
  )
}
