// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { List, Map } from 'immutable'
import StyleSheet from 'react-native-extended-stylesheet'
import { View, FlatList } from 'react-native'
import NavbarButton from 'components/NavbarButton'
import Search from 'components/Search'
import EmptyResources from 'components/EmptyResource'
import Loader from './components/Loader'
import ProjectRow from './components/ProjectRow'

const styles = StyleSheet.create({
  wrapper: {
    backgroundColor: '$White',
    flex: 1
  },
  container: {
    flex: 1
  }
})

ProjectList.navigationOptions = ({ navigation }) => ({
  title: 'Projects',
  headerLeft: (
    <NavbarButton onPress={() => navigation.navigate('DrawerOpen')} />
  ),
  headerRight: (
    <NavbarButton
      name='ios-add-outline'
      onPress={() => navigation.state.params.createProject()}
    />
  )
})

ProjectList.propTypes = {
  hasLoaded: PropTypes.bool.isRequired,
  toCreateProject: PropTypes.func.isRequired,
  toProjectInfo: PropTypes.func.isRequired,
  projects: PropTypes.instanceOf(Map).isRequired,
  projectList: PropTypes.instanceOf(List).isRequired,
  searchNeedle: PropTypes.string.isRequired,
  setSearchNeedle: PropTypes.func.isRequired
}

export default function ProjectList ({
  createProject,
  hasLoaded,
  toCreateProject,
  toProjectInfo,
  projects,
  projectList,
  searchNeedle,
  setSearchNeedle
}) {
  if (!hasLoaded) {
    return <Loader />
  }
  const flattenedList = projectList.toJS().map(id => ({ id }))
  const rowRenderer = ({ item }) => (
    <ProjectRow {...item} toProjectInfo={toProjectInfo} projects={projects} />
  )
  // empty list or no search results
  if (!flattenedList.length && !searchNeedle) {
    return (
      <EmptyResources
        onCreate={toCreateProject}
        icon='ios-copy-outline'
        buttonLabel='Create a Project'
        label='You have no projects yet'
      />
    )
  }
  return (
    <View style={styles.wrapper}>
      <Search
        keyword={searchNeedle}
        onCancel={() => setSearchNeedle('')}
        onDelete={() => setSearchNeedle('')}
        onChangeText={setSearchNeedle}
      />
      {!flattenedList.length ? (
        <EmptyResources
          onCreate={toCreateProject}
          icon='ios-copy-outline'
          label='No projects that match'
        />
      ) : (
        <FlatList
          data={flattenedList}
          keyExtractor={(_, index) => index.toString()}
          renderItem={rowRenderer}
          style={styles.container}
        />
      )}
    </View>
  )
}
