import React from 'react'
import { Text, TouchableOpacity } from 'react-native'
import { shallow } from 'enzyme'
import { fromJS } from 'immutable'
import ProjectRow from '../components/ProjectRow'

const mockProjects = fromJS({
  '2': {
    name: 'Project name',
    location: 'Project location'
  }
})

function renderHelper ({ ...props }) {
  const noop = () => {}
  return shallow(
    <ProjectRow
      id='2'
      projects={mockProjects}
      toProjectInfo={noop}
      {...props}
    />
  )
}

describe('ProjectRow', () => {
  it('should render project name', () => {
    const node = renderHelper()
    const text = node.find(Text).map(node => node.children().text())
    expect(text.includes('Project name')).toBe(true)
  })
  it('should render project location', () => {
    const node = renderHelper()
    const text = node.find(Text).map(node => node.children().text())
    expect(text.includes('Project location')).toBe(true)
  })
  it('should be touchable and have onPress mapped', () => {
    const toProjectInfo = jest.fn()
    const node = renderHelper({ toProjectInfo })
    node.find(TouchableOpacity).prop('onPress')()
    expect(toProjectInfo).toHaveBeenCalledWith('2')
  })
})
