import React from 'react'
import { FlatList } from 'react-native'
import { shallow } from 'enzyme'
import { fromJS } from 'immutable'
import Search from 'components/Search'
import EmptyResource from 'components/EmptyResource'
import Container from '../Container'
import Loader from '../components/Loader'
import ProjectList from '../ProjectList'
import ProjectRow from '../components/ProjectRow'
import { actions } from '../module'

const projects = fromJS({ '1': { name: 'test', location: 'test location' } })

function renderHelper ({ ...props }) {
  const noop = () => {}
  return shallow(
    <ProjectList
      hasLoaded
      toCreateProject={noop}
      toProjectInfo={noop}
      projects={projects}
      projectList={fromJS(['1'])}
      searchNeedle=''
      setSearchNeedle={noop}
      {...props}
    />
  )
}

describe('Project List Screen', () => {
  describe('container', () => {
    it('should include in  navigateActions initialize', () => {
      expect(Container.navigateActions.includes(actions.initialize)).toBe(true)
    })
  })
  describe('view', () => {
    it('should render sidebar menu in title not back button', () => {
      const header = ProjectList.navigationOptions({ navigation: {} })
      const node = shallow(header.headerLeft)
      expect(node.props().children.props.name).toBe('ios-menu')
    })
    it('should render plus icon in title', () => {
      const header = ProjectList.navigationOptions({ navigation: {} })
      const node = shallow(header.headerRight)
      expect(node.props().children.props.name).toBe('ios-add-outline')
    })
    it('should render search box and search icon', () => {
      const setSearchNeedle = jest.fn()
      const node = renderHelper({ setSearchNeedle, searchNeedle: 'foo' })
      const search = node.find(Search)
      expect(search).toHaveLength(1)
    })
    it('should render message to create a project if no projects', () => {
      const toCreateProject = jest.fn()
      const node = renderHelper({ projectList: fromJS([]), toCreateProject })
      const emptyResource = node.find(EmptyResource)
      expect(emptyResource).toHaveLength(1)
      expect(emptyResource.props().buttonLabel).toBe('Create a Project')
      expect(emptyResource.props().label).toBe('You have no projects yet')
      expect(emptyResource.props().onCreate).toBe(toCreateProject)
    })
    it('should render projects if projects', () => {
      const toProjectInfo = jest.fn()
      const node = renderHelper({ toProjectInfo })
      const list = node.find(FlatList)
      expect(list).toHaveLength(1)
      const rowRenderer = list.prop('renderItem')
      const renderedRow = shallow(
        <div>{rowRenderer({ item: { id: '1' } })}</div>
      )
      const rowNode = renderedRow.find(ProjectRow)
      expect(rowNode).toHaveLength(1)
      expect(rowNode.prop('projects')).toBe(projects)
      expect(rowNode.prop('toProjectInfo')).toBe(toProjectInfo)
    })
    describe('hasLoaded', () => {
      it('should render a loader if loading', () => {
        const node = renderHelper({ hasLoaded: false })
        expect(node.find(Loader)).toHaveLength(1)
      })
      it('should not render a loader if loading', () => {
        const node = renderHelper({ hasLoaded: true })
        expect(node.find(Loader)).toHaveLength(0)
      })
    })
  })
})
