import createStoreForTesting from 'test/createstore'
import { API_URL } from '../../../config'
import { UserActions } from 'resources/user'
import { NavigationActions } from 'react-navigation'
import SCREENS from 'routes/screens'
import projectListRecord from 'test/records/projectlist.json'
import { actions, selectors } from '../module'

describe('Project List Screen', () => {
  describe('module', () => {
    it('initialize should retrieve a list of all projects', async () => {
      const store = createStoreForTesting()
      const userId = '45'
      store.dispatch(UserActions.setCurrentUser(userId))
      store.addResponse(projectListRecord)
      await store.dispatch(actions.initialize())
      expect(fetch).toHaveBeenCalledWith(`${API_URL}/projects/${userId}`, {
        headers: {
          Accept: 'application/json',
          'Content-Type': 'application/json'
        },
        method: 'GET'
      })
    })
    describe('searchProjects', () => {
      it('should set the search needle', () => {})
      it(' should apply the search needle filter', async () => {
        const store = createStoreForTesting()
        store.addResponse(projectListRecord)
        await store.dispatch(actions.initialize())
        store.dispatch(actions.setSearchNeedle(''))
        expect(selectors.projectList(store.getState()).toJS()).toEqual([
          '593',
          '592',
          '591',
          '590'
        ])
        store.dispatch(actions.setSearchNeedle('Stubbs'))
        expect(selectors.projectList(store.getState()).toJS()).toEqual(['593'])
      })
    })
    it.skip('toCreateProject should navigate to create project screen', () => {})
    it('toProjectInfo should navigate to project details for each project not inbox', () => {
      const store = createStoreForTesting()
      store.dispatch(actions.toProjectInfo('66'))
      const action = store.spyActions.findAction(NavigationActions.NAVIGATE)
      expect(action.routeName).toBe(SCREENS.PROJECT_INFO)
      expect(action.params).toEqual({ projectId: '66' })
    })
  })
})
