// @flow
import { Record } from 'immutable'
import createReducer from 'utils/createreducer'
import createConstants from 'utils/createconstants'
import createViewSelector from 'utils/createviewselector'
import SCREENS from 'routes/screens'
import * as RouteActions from 'routes/actions'
import { ProjectActions, ProjectSelectors } from 'resources/project'
import createFilter from 'utils/createfilter'

export const CONSTANTS = createConstants('SCREEN_PROJECT_LIST', {
  SET_SEARCH_NEEDLE: null
})

export const actions = {
  initialize () {
    return async dispatch => {
      await dispatch(ProjectActions.fetchList())
      dispatch(
        RouteActions.setParams({
          createProject: () =>
            dispatch(RouteActions.navigate(SCREENS.PROJECT_CREATE))
        })
      )
    }
  },
  toProjectInfo (projectId) {
    return RouteActions.navigate(SCREENS.PROJECT_INFO, { projectId })
  },
  toCreateProject () {
    return dispatch => {}
  },
  setSearchNeedle (needle) {
    return {
      type: CONSTANTS.SET_SEARCH_NEEDLE,
      payload: needle
    }
  }
}

export const ProjectListState = Record({
  searchNeedle: ''
})

export const reducer = createReducer(new ProjectListState(), {
  [CONSTANTS.SET_SEARCH_NEEDLE]: (state, { payload }) =>
    state.set('searchNeedle', payload)
})

export const viewState = state => state.screens.projectlist
export const viewSelector = createViewSelector(viewState)
export const searchNeedle = viewSelector('searchNeedle')

export const projectList = createFilter(
  searchNeedle,
  ProjectSelectors.projects,
  ProjectSelectors.projectsList,
  ['name', 'location']
)

export const selectors = {
  searchNeedle,
  projectList
}
