// @flow
import React from 'react'
import PropTypes from 'prop-types'
import StyleSheet from 'react-native-extended-stylesheet'
import { View, Text } from 'react-native'
import font from 'utils/font'
import Button, { IconButton } from 'components/Button'
import NavbarButton from 'components/NavbarButton'
import COLORS from '../../colors'

const styles = StyleSheet.create({
  wrapper: {
    backgroundColor: '$White',
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center'
  },
  separator: {
    height: 1,
    width: 200,
    marginTop: 20,
    backgroundColor: '$DarkBackground'
  },
  title: {
    fontSize: 22,
    ...font({ weight: 'bold' })
  },
  button: {
    marginTop: 20
  },
  linkButton: {
    justifyContent: 'center',
    alignItems: 'center'
  },
  linkButtonText: {
    fontSize: 16,
    color: '$DarkText'
  },
  linkButtonLink: {
    fontSize: 18,
    color: '$Secondary',
    textDecorationLine: 'underline'
  },
  buttonbar: {
    marginTop: 20,
    flexDirection: 'row'
  },
  shareButton: {
    marginLeft: 20
  }
})

ReferFriend.navigationOptions = ({ navigation }) => ({
  title: 'Refer a friend',
  headerLeft: <NavbarButton onPress={() => navigation.navigate('DrawerOpen')} />
})

ReferFriend.propTypes = {
  shareLink: PropTypes.func.isRequired,
  shareMail: PropTypes.func.isRequired,
  shareFacebook: PropTypes.func.isRequired,
  shareTwitter: PropTypes.func.isRequired
}

export default function ReferFriend ({
  shareLink,
  shareMail,
  shareFacebook,
  shareTwitter
}) {
  return (
    <View style={styles.wrapper}>
      <Text style={styles.title}>Share it!</Text>
      <View style={styles.separator} />
      <Button style={styles.button} onPress={shareLink}>
        <View style={styles.linkButton}>
          <Text style={styles.linkButtonText}>COPY LINK</Text>
          <Text style={styles.linkButtonLink}>http://www.thenailitapp.com</Text>
        </View>
      </Button>
      <View style={styles.separator} />
      <View style={styles.buttonbar}>
        <IconButton
          name='ios-mail-open-outline'
          color={COLORS.Primary}
          size={36}
          onPress={shareMail}
        />
        <IconButton
          name='logo-facebook'
          style={styles.shareButton}
          color={COLORS.Primary}
          size={36}
          onPress={shareFacebook}
        />
        <IconButton
          name='logo-twitter'
          style={styles.shareButton}
          color={COLORS.Primary}
          size={36}
          onPress={shareTwitter}
        />
      </View>
    </View>
  )
}
