// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { View, FlatList } from 'react-native'
import { List, Map } from 'immutable'
import StyleSheet from 'react-native-extended-stylesheet'
import NavbarButton from 'components/NavbarButton'
import { LoaderScreen } from 'components/Loader'
import SearchBar from 'components/Search'
import ProjectRow from './components/ProjectRow'
import COLORS from '../../colors'

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '$White'
  },
  searchBar: {
    backgroundColor: '$LightBackground',
    borderBottomWidth: 1,
    borderBottomColor: '$LightText'
  },
  seachBox: {
    borderBottomColor: '$LightDivider'
  }
})

SelectProject.navigationOptions = ({ navigation }) => ({
  title: 'Select Project',
  headerRight: (
    <NavbarButton onPress={() => navigation.state.params.save()}>
      SAVE
    </NavbarButton>
  )
})

SelectProject.propTypes = {
  hasLoaded: PropTypes.bool.isRequired,
  searchText: PropTypes.string.isRequired,
  setSearch: PropTypes.func.isRequired,
  projects: PropTypes.instanceOf(Map).isRequired,
  projectList: PropTypes.instanceOf(List).isRequired,
  selectProject: PropTypes.func.isRequired,
  selection: PropTypes.instanceOf(List).isRequired
}

export default function SelectProject ({
  hasLoaded,
  displayAll,
  searchText,
  setSearch,
  projects,
  projectList,
  selectProject,
  selection
}) {
  if (!hasLoaded) {
    return <LoaderScreen />
  }
  const flattenedList = projectList.toJS().map(id => ({ id }))
  if (displayAll) {
    flattenedList.unshift({ id: '0' })
  }
  const rowRenderer = ({ item }) => (
    <ProjectRow
      {...item}
      selectProject={selectProject}
      selection={selection}
      projects={projects}
    />
  )
  return (
    <View style={styles.container}>
      <View style={styles.searchBar}>
        <SearchBar
          placeholder='Search'
          onChangeText={setSearch}
          useClearButton={false}
          onCancel={() => setSearch('')}
          style={styles.seachBox}
          textFieldBackgroundColor={COLORS.DarkBackground}
        />
      </View>
      <FlatList
        data={flattenedList}
        keyExtractor={(_, index) => index.toString()}
        renderItem={rowRenderer}
        style={styles.container}
      />
    </View>
  )
}
