// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { Map, fromJS } from 'immutable'
import { TouchableOpacity, View, Text } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'
import sanitizeLocation from 'utils/sanitizelocation'
import font from 'utils/font'
import { SCREEN_WIDTH } from 'utils/device'
import COLORS from '../../../colors'
import Icon from 'components/Icon'

const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    height: 75,
    paddingLeft: 15,
    paddingRight: 15,
    borderColor: '$LightDivider',
    borderBottomWidth: 1,
    alignItems: 'center',
    justifyContent: 'space-between'
  },
  name: {
    ...font({ weight: 'bold' }),
    color: '$Primary',
    textAlign: 'left',
    fontSize: 15,
    width: SCREEN_WIDTH - 45
  },
  address: {
    color: '$DarkText',
    fontSize: 13,
    marginTop: 5,
    paddingRight: 10,
    textAlign: 'left'
  },
  selection: {
    position: 'absolute',
    right: 10,
    top: 35,
    borderRadius: 15,
    borderWidth: 1,
    borderColor: '$Secondary',
    width: 17,
    height: 17,
    justifyContent: 'center',
    alignItems: 'center'
  }
})

ProjectRow.propTypes = {
  projects: PropTypes.instanceOf(Map).isRequired,
  selectProject: PropTypes.func.isRequired,
  id: PropTypes.string.isRequired
}

export default function ProjectRow ({ selectProject, projects, id, selection }) {
  const project = projects.get(id, fromJS({ id: '0', name: 'All' }))
  const onPress = () => selectProject(id)
  const selected = selection.includes(id)
  return (
    <TouchableOpacity onPress={onPress}>
      <View style={styles.container}>
        <View style={styles.inputText}>
          <Text style={styles.name} numberOfLines={1}>
            {project.get('name')}
          </Text>
          {project.get('id') !== '0' && (
            <Text style={styles.address} numberOfLines={1}>
              {sanitizeLocation(project.get('location')) ||
                'No address set yet'}
            </Text>
          )}
        </View>
        <View style={styles.selection}>
          {selected && (
            <Icon name='ios-checkmark-circle' size={15} color={COLORS.Orange} />
          )}
        </View>
      </View>
    </TouchableOpacity>
  )
}
