// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { View } from 'react-native'
import { List, Map } from 'immutable'
import StyleSheet from 'react-native-extended-stylesheet'
import NavbarButton from 'components/NavbarButton'
import { LoaderScreen } from 'components/Loader'
import SearchBar from 'components/Search'
import TaskGrid from './components/TaskGrid'
import COLORS from '../../colors'

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '$White'
  },
  searchBar: {
    backgroundColor: '$LightBackground',
    borderBottomWidth: 1,
    borderBottomColor: '$LightText'
  },
  seachBox: {
    borderBottomColor: '$LightDivider'
  }
})

SelectTrade.navigationOptions = ({ navigation }) => ({
  title: 'Select Trade',
  headerRight: (
    <NavbarButton onPress={() => navigation.state.params.save()}>
      SAVE
    </NavbarButton>
  )
})

SelectTrade.propTypes = {
  hasLoaded: PropTypes.bool.isRequired,
  searchText: PropTypes.string.isRequired,
  setSearch: PropTypes.func.isRequired,
  tasks: PropTypes.instanceOf(Map).isRequired,
  taskList: PropTypes.instanceOf(List).isRequired,
  selectTask: PropTypes.func.isRequired,
  selection: PropTypes.instanceOf(List).isRequired
}

export default function SelectTrade ({
  hasLoaded,
  searchText,
  setSearch,
  tasks,
  taskList,
  selectTask,
  selection
}) {
  if (!hasLoaded) {
    return <LoaderScreen />
  }
  return (
    <View style={styles.container}>
      <View style={styles.searchBar}>
        <SearchBar
          placeholder='Search'
          onChangeText={setSearch}
          useClearButton={false}
          onCancel={() => setSearch('')}
          style={styles.seachBox}
          textFieldBackgroundColor={COLORS.DarkBackground}
        />
      </View>
      <TaskGrid
        tasks={tasks}
        taskList={taskList}
        selection={selection}
        selectTask={selectTask}
      />
    </View>
  )
}
