// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { Map } from 'immutable'
import FastImage from 'react-native-fast-image'
import { TouchableOpacity, Text, View } from 'react-native'
import StyleSheet from 'react-native-extended-stylesheet'

const styles = StyleSheet.create({
  container: {
    flex: 1,
    alignSelf: 'center',
    backgroundColor: '$White',
    flexDirection: 'column',
    justifyContent: 'center',
    alignItems: 'center',
    borderWidth: 1,
    borderColor: '$Primary',
    borderRadius: 3,
    paddingLeft: 10,
    paddingRight: 10,
    paddingTop: 5,
    paddingBottom: 5,
    width: 90,
    height: 95,
    margin: 5,
    overflow: 'hidden'
  },
  thumb: {
    width: 50,
    height: 65
  },
  text: {
    flex: 1,
    marginTop: 5,
    fontSize: 10,
    color: '$Primary'
  },
  selected: {
    borderColor: '$Secondary'
  },
  textSelected: {
    color: '$Secondary'
  }
})

TaskCell.propTypes = {
  tasks: PropTypes.instanceOf(Map).isRequired,
  id: PropTypes.string.isRequired,
  selectTask: PropTypes.func.isRequired,
  selected: PropTypes.bool.isRequired
}

export default function TaskCell ({ tasks, id, selectTask, selected }) {
  const task = tasks.get(id)
  const imageUrl = (task.get('url') || '').substring(
    0,
    (task.get('url') || '').length - 4
  )
  const url = selected ? `${imageUrl}_selected.png` : `${imageUrl}.png`
  return (
    <TouchableOpacity onPress={selectTask}>
      <View style={[styles.container, selected && styles.selected]}>
        <FastImage
          style={styles.thumb}
          source={{ uri: url }}
          resizeMode='contain'
        />
        <Text style={[styles.text, selected && styles.textSelected]}>
          {task.get('name')}
        </Text>
      </View>
    </TouchableOpacity>
  )
}
