// @flow
import React from 'react'
import { View, FlatList } from 'react-native'
import { Map, List } from 'immutable'
import PropTypes from 'prop-types'
import StyleSheet from 'react-native-extended-stylesheet'
import TaskCell from './TaskCell'

const styles = StyleSheet.create({
  container: {
    flex: 1,
    flexDirection: 'column',
    justifyContent: 'center',
    alignItems: 'center'
  },
  grid: {
    backgroundColor: '$White',
    flex: 1,
    width: 305
  }
})

TaskGrid.propTypes = {
  selection: PropTypes.instanceOf(List).isRequired,
  tasks: PropTypes.instanceOf(Map).isRequired,
  taskList: PropTypes.instanceOf(List).isRequired,
  selectTask: PropTypes.func.isRequired
}

export default function TaskGrid ({ selection, tasks, taskList, selectTask }) {
  const flattenedList = taskList.toJS().map(id => ({ id }))
  const rowRenderer = ({ item }) => (
    <TaskCell
      {...item}
      selected={selection.includes(item.id)}
      selectTask={() => selectTask(item.id)}
      tasks={tasks}
    />
  )

  return (
    <View style={styles.container}>
      <FlatList
        data={flattenedList}
        numColumns={3}
        keyExtractor={(_, index) => index.toString()}
        renderItem={rowRenderer}
        style={styles.grid}
      />
    </View>
  )
}
