// @flow
import { List, Record, fromJS } from 'immutable'
import createReducer from 'utils/createreducer'
import createConstants from 'utils/createconstants'
import { createSelector } from 'reselect'
import { TaskSelectors, TaskActions } from 'resources/task'
import createViewSelector from 'utils/createviewselector'
import { RouteActions } from 'routes'

export const CONSTANTS = createConstants('SCREEN_SELECT_TRADE', {
  TOGGLE_TRADE: null,
  SET_SEARCH: null,
  RESET: null,
  SET_SINGLE_SELECTION: null
})

export const actions = {
  initialize ({ save, singleSelection, selected = [] }) {
    return async (dispatch, getState) => {
      dispatch(actions.reset())
      dispatch(actions.setSingleSelection(singleSelection))
      selected.forEach(selected => dispatch(actions.selectTask(selected)))
      dispatch(TaskActions.fetchList())
      dispatch(
        RouteActions.setParams({
          save: () => dispatch(actions.saveTrades({ save }))
        })
      )
    }
  },

  reset (projectId) {
    return {
      type: CONSTANTS.RESET
    }
  },

  saveTrades ({ save }) {
    return (dispatch, getState) => {
      const state = getState()
      const selection = selectors.selection(state)
      if (save) {
        dispatch(save(selection))
      }
      dispatch(RouteActions.back())
    }
  },

  setSearch (needle) {
    return {
      type: CONSTANTS.SET_SEARCH,
      payload: needle
    }
  },

  selectTask (taskId) {
    return {
      type: CONSTANTS.TOGGLE_TRADE,
      payload: taskId
    }
  },

  setSingleSelection (singleSelection) {
    return {
      type: CONSTANTS.SET_SINGLE_SELECTION,
      payload: singleSelection
    }
  }
}

export const SelectTradeState = Record({
  selection: List(),
  save: null,
  search: '',
  singleSelection: false
})

export const reducer = createReducer(new SelectTradeState(), {
  [CONSTANTS.RESET]: state => new SelectTradeState(),
  [CONSTANTS.SET_SEARCH]: (state, { payload }) => state.set('search', payload),
  [CONSTANTS.SET_SINGLE_SELECTION]: (state, { payload }) =>
    state.set('singleSelection', payload),
  [CONSTANTS.TOGGLE_TRADE]: (state, { payload }) => {
    const singleSelection = state.get('singleSelection')
    if (singleSelection) {
      return state.set('selection', fromJS([payload]))
    }
    const selection = state.get('selection')
    if (selection.includes(payload)) {
      const newSelection = selection.filter(id => id !== payload)
      return state.set('selection', newSelection)
    }
    const newSelection = selection.push(payload)
    return state.set('selection', newSelection)
  }
})

export const viewState = state => state.screens.selectTrade
export const viewSelector = createViewSelector(viewState)
export const selection = viewSelector('selection')
export const searchText = viewSelector('search', '')
export const taskList = createSelector(
  [TaskSelectors.tasks, TaskSelectors.taskList, searchText],
  (tasks, taskList, search) =>
    taskList.filter(taskId => {
      const taskName = tasks.getIn([taskId, 'name'], '').toLowerCase()
      const categories = tasks
        .getIn([taskId, 'categories'], List())
        .toJS()
        .join('')
        .toLowerCase()
      const matchTaskName = taskName.indexOf(search.toLowerCase()) !== -1
      const matchCategory = categories.indexOf(search.toLowerCase()) !== -1
      return matchTaskName || matchCategory
    })
)

export const selectors = {
  selection,
  searchText,
  hasLoaded: TaskSelectors.hasListLoaded,
  tasks: TaskSelectors.tasks,
  taskList
}
