// @flow
import React from 'react'
import { Record } from 'immutable'
import PropTypes from 'prop-types'
import LinearGradient from 'react-native-linear-gradient'
import StyleSheet from 'react-native-extended-stylesheet'
import { View, Text } from 'react-native'
import SidemenuUser from './components/SidemenuUser'
import SidemenuItem from './components/SidemenuItem'
import COLORS from '../../colors'

const styles = StyleSheet.create({
  container: {
    flex: 1,
    flexDirection: 'column'
  },
  separator: {
    marginTop: 10,
    height: 1,
    backgroundColor: '$White',
    opacity: 0.3,
    marginLeft: 20,
    marginRight: 20
  },
  spacer: {
    height: 10
  },
  sideBorder: {
    position: 'absolute',
    top: 0,
    right: 0,
    width: 1,
    bottom: 0,
    backgroundColor: '$White',
    opacity: 0.3
  },
  version: {
    position: 'absolute',
    right: 5,
    bottom: 5,
    fontSize: 10,
    color: 'rgba(255, 255, 255, 0.4)'
  }
})

Sidemenu.propTypes = {
  currentUser: PropTypes.instanceOf(Record),
  toProjects: PropTypes.func.isRequired,
  toLogout: PropTypes.func.isRequired,
  toAccountInfo: PropTypes.func.isRequired,
  toInbox: PropTypes.func.isRequired,
  toReferFriend: PropTypes.func.isRequired,
  toSupport: PropTypes.func.isRequired
}

export default function Sidemenu ({
  currentUser,
  toProjects,
  toLogout,
  toAccountInfo,
  toInbox,
  toReferFriend,
  toSupport
}) {
  if (!currentUser) {
    return null // still loading?
  }
  return (
    <LinearGradient
      colors={[COLORS.LightPrimary, COLORS.Primary]}
      start={{ x: 0.5, y: 0.3 }}
      end={{ x: 0.8, y: 0.7 }}
      style={styles.container}
    >
      <SidemenuUser user={currentUser} />
      <View style={styles.spacer} />
      <SidemenuItem
        label='My Account'
        icon='ios-contact-outline'
        onPress={toAccountInfo}
      />
      <SidemenuItem label='Inbox' icon='ios-mail-outline' onPress={toInbox} />
      <SidemenuItem
        label='Projects'
        icon='ios-clipboard-outline'
        onPress={toProjects}
      />
      <View style={styles.separator} />
      <View style={styles.spacer} />
      <SidemenuItem
        label='Refer a Friend'
        icon='ios-share-outline'
        onPress={toReferFriend}
      />
      <SidemenuItem
        label='Support'
        icon='ios-help-buoy-outline'
        onPress={toSupport}
      />
      <View style={styles.separator} />
      <View style={styles.spacer} />
      <SidemenuItem label='Logout' icon='ios-log-out' onPress={toLogout} />
      <View style={styles.sideBorder} />

      <Text style={styles.version}>v2.6</Text>
    </LinearGradient>
  )
}
