// @flow
import { createStructuredSelector } from 'reselect'
import { AsyncStorage } from 'react-native'
import { UserSelectors } from 'resources/user'
import SCREENS from 'routes/screens'
import * as RouteActions from 'routes/actions'
import * as PushNotification from 'utils/pushnotification'
import { USERID_KEY } from '../../config'

export const selector = createStructuredSelector({
  currentUser: UserSelectors.currentUser
})

export const actions = {
  toProjects () {
    return RouteActions.reset('SignedIn', SCREENS.PROJECT_LIST)
  },
  toLogout () {
    return async dispatch => {
      await AsyncStorage.removeItem(USERID_KEY)
      dispatch({ type: 'RESOURCE_RESET' })
      dispatch(PushNotification.unregister())
      dispatch(RouteActions.navigate(SCREENS.LOGIN))
    }
  },
  toAccountInfo () {
    return RouteActions.navigate(SCREENS.ACCOUNT)
  },
  toInbox () {
    return dispatch => {
      dispatch(
        RouteActions.reset('SignedIn', SCREENS.INBOX, { projectId: '0' })
      )
      dispatch(RouteActions.setParams({ projectId: '0' }))
    }
  },
  toReferFriend () {
    return RouteActions.reset('SignedIn', SCREENS.REFER_FRIEND)
  },
  toSupport () {
    return RouteActions.reset('SignedIn', SCREENS.SUPPORT)
  }
}
