// @flow
import React from 'react'
import PropTypes from 'prop-types'
import StyleSheet from 'react-native-extended-stylesheet'
import { View, Keyboard, TouchableWithoutFeedback } from 'react-native'
import { TextInput } from 'components/FormControls'
import NavbarButton from 'components/NavbarButton'
import { LoaderScreen } from 'components/Loader'

const styles = StyleSheet.create({
  wrapper: {
    backgroundColor: '$White',
    flex: 1,
    width: '100%',
    padding: 10
  },
  email: {
    flex: 1
  }
})

Support.navigationOptions = ({ navigation, ...other }) => ({
  title: 'Help/Support',
  headerLeft: (
    <NavbarButton onPress={() => navigation.navigate('DrawerOpen')} />
  ),
  headerRight: (
    <NavbarButton onPress={() => navigation.state.params.sendEmail()}>
      SEND
    </NavbarButton>
  )
})

Support.propTypes = {
  setEmail: PropTypes.func.isRequired,
  setSubject: PropTypes.func.isRequired,
  setBody: PropTypes.func.isRequired,
  email: PropTypes.string.isRequired,
  subject: PropTypes.string.isRequired,
  body: PropTypes.string.isRequired,
  isLoading: PropTypes.bool
}

export default function Support ({
  setEmail,
  setSubject,
  setBody,
  email,
  subject,
  body,
  isLoading
}) {
  if (isLoading) {
    return <LoaderScreen />
  }
  return (
    <TouchableWithoutFeedback onPress={Keyboard.dismiss}>
      <View style={styles.wrapper}>
        <TextInput label='Email' onChangeText={setEmail} value={email} />
        <TextInput label='Subject' onChangeText={setSubject} value={subject} />
        <TextInput
          label='Body'
          onChangeText={setBody}
          value={body}
          multiline
          style={styles.email}
          containerStyle={styles.email}
        />
      </View>
    </TouchableWithoutFeedback>
  )
}
