// @flow
import { Alert, Keyboard } from 'react-native'
import { UserSelectors } from 'resources/user'
import SCREENS from 'routes/screens'
import * as RouteActions from 'routes/actions'
import { post } from 'utils/http'
import { Record } from 'immutable'
import createReducer from 'utils/createreducer'
import createConstants from 'utils/createconstants'
import createViewSelector from 'utils/createviewselector'

export const CONSTANTS = createConstants('SCREEN_LOGIN', {
  RESET: null,
  SET_EMAIL: null,
  SET_BODY: null,
  SET_SUBJECT: null,
  SET_LOADING: null
})

export const actions = {
  setEmail (email) {
    return {
      type: CONSTANTS.SET_EMAIL,
      payload: email
    }
  },

  setBody (body) {
    return {
      type: CONSTANTS.SET_BODY,
      payload: body
    }
  },

  setSubject (subject) {
    return {
      type: CONSTANTS.SET_SUBJECT,
      payload: subject
    }
  },

  setLoading (loading) {
    return {
      type: CONSTANTS.SET_LOADING,
      payload: loading
    }
  },

  reset () {
    return {
      type: CONSTANTS.RESET
    }
  },

  sendEmail () {
    return async (dispatch, getState) => {
      try {
        const state = getState()
        const userId = UserSelectors.currentUserId(state)
        const email = selectors.email(state)
        const message = selectors.body(state)
        const subject = selectors.subject(state)
        if (!email.trim() || !message.trim() || !subject.trim()) {
          Alert.alert('Sorry', 'You must fill in all fields')
          return
        }
        dispatch(actions.setLoading(true))
        await post('/support', { userId, email, message, subject })
        Keyboard.dismiss()
        dispatch(actions.reset())
        dispatch(actions.initialize())
        Alert.alert(
          'NailIt!',
          "We've received your request, we'll answer as soon as possible"
        )
        dispatch(RouteActions.reset('SignedIn', SCREENS.PROJECT_LIST))
      } catch (error) {
        console.log('Email error', error)
      } finally {
        dispatch(actions.setLoading(false))
      }
    }
  },

  initialize () {
    return (dispatch, getState) => {
      const currentUser = UserSelectors.currentUser(getState())
      const userEmail = currentUser.get('email')
      dispatch(actions.setEmail(userEmail))
      dispatch(
        RouteActions.setParams({
          sendEmail: () => dispatch(actions.sendEmail())
        })
      )
    }
  }
}

export const SupportState = Record({
  email: '',
  subject: '',
  body: '',
  isLoading: false
})

export const reducer = createReducer(new SupportState(), {
  [CONSTANTS.RESET]: () => new SupportState(),
  [CONSTANTS.SET_EMAIL]: (state, { payload }) => state.set('email', payload),
  [CONSTANTS.SET_BODY]: (state, { payload }) => state.set('body', payload),
  [CONSTANTS.SET_SUBJECT]: (state, { payload }) =>
    state.set('subject', payload),
  [CONSTANTS.SET_LOADING]: (state, { payload }) =>
    state.set('isLoading', payload)
})

export const viewState = state => state.screens.support
export const viewSelector = createViewSelector(viewState)

export const selectors = {
  email: viewSelector('email', ''),
  body: viewSelector('body', ''),
  subject: viewSelector('subject', ''),
  isLoading: viewSelector('isLoading', false)
}
