// @flow
import React from 'react'
import PropTypes from 'prop-types'
import StyleSheet from 'react-native-extended-stylesheet'
import {
  KeyboardAvoidingView,
  TouchableWithoutFeedback,
  Keyboard
} from 'react-native'
import LinearGradient from 'react-native-linear-gradient'
import Logo from 'components/Logo'
import { SolidButton } from 'components/Button'
import ErrorMessage from 'components/ErrorMessage'
import { LoaderView } from 'components/Loader'
import RoundTextInput from 'components/RoundTextInput'
import COLORS from '../../colors'
import Instructions from './components/Instructions'
import { KEYBOARD_BEHAVIOUR } from 'utils/device'

const styles = StyleSheet.create({
  wrapper: {
    flex: 1
  },
  container: {
    flex: 1,
    backgroundColor: '$Primary',
    alignItems: 'center',
    justifyContent: 'center'
  },
  pinButton: {
    marginTop: 20,
    width: '80%',
    height: 40,
    borderRadius: 20,
    paddingLeft: 20,
    paddingRight: 20
  },
  error: {
    marginTop: 20
  },
  loading: {
    marginTop: 30,
    backgroundColor: 'transparent'
  }
})

Verifypin.navigationOptions = {
  title: 'Verify Pin',
  header: () => null
}

Verifypin.propTypes = {
  errorMessage: PropTypes.string,
  isSubmitting: PropTypes.bool.isRequired,
  phoneNumber: PropTypes.string.isRequired,
  pin: PropTypes.string.isRequired,
  setPin: PropTypes.func.isRequired,
  verifyPin: PropTypes.func.isRequired
}

export default function Verifypin ({
  errorMessage,
  isSubmitting,
  phoneNumber,
  pin,
  setPin,
  verifyPin
}) {
  return (
    <KeyboardAvoidingView behavior={KEYBOARD_BEHAVIOUR} style={styles.wrapper}>
      <TouchableWithoutFeedback
        style={styles.wrapper}
        onPress={Keyboard.dismiss}
      >
        <LinearGradient
          colors={[COLORS.LightPrimary, COLORS.Primary]}
          start={{ x: 0.5, y: 0.3 }}
          end={{ x: 0.8, y: 0.7 }}
          style={styles.container}
        >
          <Logo width={200} />
          <Instructions />
          <LoaderView isLoading={isSubmitting} style={styles.loading}>
            <ErrorMessage style={styles.error} message={errorMessage} />
            <RoundTextInput
              value={pin}
              onChangeText={setPin}
              placeHolder='Validation pin'
            />
            <SolidButton
              style={styles.pinButton}
              secondary
              onPress={() => verifyPin(phoneNumber)}
            >
              VERIFY PIN
            </SolidButton>
          </LoaderView>
        </LinearGradient>
      </TouchableWithoutFeedback>
    </KeyboardAvoidingView>
  )
}
