import { AsyncStorage } from 'react-native'
import { NavigationActions } from 'react-navigation'
import createStoreForTesting from 'test/createstore'
import { API_URL, USERID_KEY } from '../../../config'
import verifypinRecord from 'test/records/verifypin.json'
import userInfoRecord from 'test/records/userinfo.json'
import SCREENS from 'routes/screens'
import {
  CONSTANTS,
  actions,
  selectors,
  viewState,
  VerifyPinState
} from '../module'

describe('Verifypin module', () => {
  describe('initialize', () => {
    it('should reset state', () => {
      const store = createStoreForTesting()
      store.dispatch(actions.initialize())
      expect(store.spyActions.types().includes(CONSTANTS.RESET)).toBe(true)
    })
  })

  describe('setPin', () => {
    it('should set the pin', () => {
      const store = createStoreForTesting()
      expect(selectors.pin(store.getState())).toBe('')
      store.dispatch(actions.setPin('34'))
      expect(selectors.pin(store.getState())).toBe('34')
    })
    it('should reset the errors', () => {
      const store = createStoreForTesting()
      expect(selectors.errorMessage(store.getState())).toBe(null)
      store.dispatch(actions.setErrorMessage('error message'))
      expect(selectors.errorMessage(store.getState())).toBe('error message')
      store.dispatch(actions.setPin('34'))
      expect(selectors.errorMessage(store.getState())).toBe(null)
    })
  })

  describe('resetState', () => {
    it('should reset state', () => {
      const store = createStoreForTesting()
      expect(viewState(store.getState())).toEqual(new VerifyPinState())
      store.dispatch(actions.setErrorMessage('error'))
      expect(viewState(store.getState())).not.toEqual(new VerifyPinState())
      store.dispatch(actions.resetState())
      expect(viewState(store.getState())).toEqual(new VerifyPinState())
    })
  })

  describe('setSubmitting', () => {
    it('should set submit state', () => {
      const store = createStoreForTesting()
      expect(selectors.isSubmitting(store.getState())).toBe(false)
      store.dispatch(actions.setSubmitting(true))
      expect(selectors.isSubmitting(store.getState())).toBe(true)
    })
  })

  describe('setErrorMessage', () => {
    it('should set the error message', () => {
      const store = createStoreForTesting()
      expect(selectors.errorMessage(store.getState())).toBe(null)
      store.dispatch(actions.setErrorMessage('error message'))
      expect(selectors.errorMessage(store.getState())).toBe('error message')
    })
  })

  describe('verifyPin', () => {
    it('should call the api to verify the pin and set userId', async () => {
      const store = createStoreForTesting()
      store.dispatch(actions.setPin('1234'))
      store.addResponse(verifypinRecord)
      store.addResponse(userInfoRecord)
      await store.dispatch(actions.verifyPin('1234567890'))
      expect(fetch).toHaveBeenCalledWith(`${API_URL}/authentic`, {
        body: JSON.stringify({ email: '1234567890', password: '1234' }),
        headers: {
          Accept: 'application/json',
          'Content-Type': 'application/json'
        },
        method: 'POST'
      })
      expect(await AsyncStorage.getItem(USERID_KEY)).toBe('771')
    })
    // TODO: FIX ME
    // no time to fix this now
    it.skip('should push to project list screen if success', async () => {
      const store = createStoreForTesting()
      store.dispatch(actions.setPin('1234'))
      store.addResponse(verifypinRecord)
      store.addResponse(userInfoRecord)
      await store.dispatch(actions.verifyPin('1234567890'))
      const action = store.spyActions.findAction(NavigationActions.NAVIGATE)
      expect(action.action.actions[0].routeName).toBe(SCREENS.PROJECT_LIST)
    })
    it('should set the error if failure', async () => {
      const store = createStoreForTesting()
      store.dispatch(actions.setPin('1234'))
      store.addReject()
      await store.dispatch(actions.verifyPin('1234567890'))
      expect(selectors.errorMessage(store.getState())).toBe(
        "There's been an error validating the PIN"
      )
    })
  })
})
