// @flow
import { Record } from 'immutable'
import { AsyncStorage, Keyboard } from 'react-native'
import createReducer from 'utils/createreducer'
import createConstants from 'utils/createconstants'
import { DEVELOPMENT_ENV, USERID_KEY } from '../../config'
import { UserActions } from 'resources/user'
import createViewSelector from 'utils/createviewselector'
import * as PushNotifications from 'utils/pushnotification'
import * as API from 'utils/api'
import SCREENS from 'routes/screens'
import * as RouteActions from 'routes/actions'

export const CONSTANTS = createConstants('SCREEN_VERIFYPIN', {
  RESET: null,
  SET_PIN: null,
  SET_SUBMITTING: null,
  SET_ERRORMESSAGE: null
})

export const actions = {
  initialize () {
    return dispatch => {
      dispatch(actions.resetState())
    }
  },
  setPin (pin) {
    return dispatch => {
      dispatch(actions.setErrorMessage(null))
      dispatch({
        type: CONSTANTS.SET_PIN,
        payload: pin
      })
    }
  },
  resetState () {
    return {
      type: CONSTANTS.RESET
    }
  },
  setSubmitting (isSubmitting) {
    return {
      type: CONSTANTS.SET_SUBMITTING,
      payload: isSubmitting
    }
  },
  setErrorMessage (errorMessage) {
    return {
      type: CONSTANTS.SET_ERRORMESSAGE,
      payload: errorMessage
    }
  },
  verifyPin (phoneNumber) {
    return async (dispatch, getState) => {
      Keyboard.dismiss()
      const pin = selectors.pin(getState())

      try {
        dispatch(actions.setSubmitting(true))
        const response = await API.verifyPin({ phoneNumber, pin })
        if (response.responseCode !== 200) {
          throw new Error('HTTP Error')
        }
        const { userId } = response
        await AsyncStorage.setItem(USERID_KEY, userId.toString())
        dispatch(UserActions.setCurrentUser(userId.toString()))
        await dispatch(UserActions.fetchInfo(userId.toString()))
        dispatch(PushNotifications.register())
        dispatch(RouteActions.reset('SignedIn', SCREENS.PROJECT_LIST))
      } catch (error) {
        if (DEVELOPMENT_ENV) {
          console.log('verifyPin failed', error)
        }
        dispatch(actions.setSubmitting(false))
        dispatch(
          actions.setErrorMessage("There's been an error validating the PIN")
        )
      }
    }
  }
}

export const VerifyPinState = Record({
  pin: '',
  isSubmitting: false,
  errorMessage: null
})

export const reducer = createReducer(new VerifyPinState(), {
  [CONSTANTS.RESET]: () => new VerifyPinState(),
  [CONSTANTS.SET_PIN]: (state, { payload }) => state.set('pin', payload),
  [CONSTANTS.SET_SUBMITTING]: (state, { payload }) =>
    state.set('isSubmitting', payload),
  [CONSTANTS.SET_ERRORMESSAGE]: (state, { payload }) =>
    state.set('errorMessage', payload)
})

export const viewState = state => state.screens.verifypin
export const viewSelector = createViewSelector(viewState)

export const selectors = {
  pin: viewSelector('pin', ''),
  isSubmitting: viewSelector('isSubmitting'),
  errorMessage: viewSelector('errorMessage')
}
