import React from 'react'
import { shallow } from 'enzyme'
import createLoader from '../createloader'
import { LoaderScreen } from 'components/Loader'

class DummyComponent extends React.Component {
  render () {
    return <div />
  }
}

describe('createLoader', () => {
  it('returns a react element', () => {
    const Component = createLoader(DummyComponent)
    expect(() => shallow(<Component />)).not.toThrow()
  })

  it('renders the loader if the key is true', () => {
    const Component = createLoader(DummyComponent)
    const node = shallow(<Component isLoading />)
    expect(node.find(LoaderScreen).exists()).toBeTruthy()
    expect(node.find(DummyComponent).exists()).toBeFalsy()
  })

  it('renders the component if the loading key is false', () => {
    const Component = createLoader(DummyComponent)
    const node = shallow(<Component isLoading={false} />)
    expect(node.find(LoaderScreen).exists()).toBeFalsy()
    expect(node.find(DummyComponent).exists()).toBeTruthy()
  })

  it('passes statics if flag is set', () => {
    DummyComponent.navigationOptions = 'foobar'
    const Component = createLoader(DummyComponent, LoaderScreen, {
      passStatic: true
    })
    expect(Component.navigationOptions).toBe('foobar')
  })
})
