import { destroy } from '../http'
import { API_URL } from '../../config'

describe('http', () => {
  beforeEach(() => {
    fetch.resetMocks()
    fetch.mockResponse('{}')
  })
  describe('destroy', () => {
    it('should call with the api url', async () => {
      await destroy('/foo')
      expect(fetch.mock.calls[0][0]).toBe(`${API_URL}/foo`)
    })
    it('should add default json headers', async () => {
      await destroy('/foo')
      expect(fetch.mock.calls[0][1].headers).toEqual({
        Accept: 'application/json',
        'Content-Type': 'application/json'
      })
    })
    it('should call with the expected headers', async () => {
      await destroy('/foo', {
        headers: { some: 'header' },
        option: 'config'
      })
      expect(fetch.mock.calls[0][1].headers.some).toBe('header')
      expect(fetch.mock.calls[0][1].option).toBe('config')
    })
    it('should convert response to camel case', async () => {
      fetch.mockResponse(JSON.stringify({ access_token: '12345' }))
      const response = await destroy('/foo')
      expect(response).toEqual({ accessToken: '12345' })
    })
  })
})
