import { get } from '../http'
import { API_URL } from '../../config'

describe('http', () => {
  beforeEach(() => {
    fetch.resetMocks()
    fetch.mockResponse('{}')
  })
  describe('get', () => {
    it('should call with the api url', async () => {
      await get('/foo')
      expect(fetch.mock.calls[0][0]).toBe(`${API_URL}/foo`)
    })
    it('should call with the expected query string', async () => {
      const params = { bar: 'baz', params: [1, 2, 3] }
      await get('/foo', params)
      expect(fetch.mock.calls[0][0]).toBe(
        `${API_URL}/foo?bar=baz&params=1%2C2%2C3`
      )
    })
    it('should add default json headers', async () => {
      await get('/foo')
      expect(fetch.mock.calls[0][1].headers).toEqual({
        Accept: 'application/json',
        'Content-Type': 'application/json'
      })
    })
    it('should call with the expected headers', async () => {
      await get('/foo', null, { headers: { some: 'header' }, option: 'config' })
      expect(fetch.mock.calls[0][1].headers.some).toBe('header')
      expect(fetch.mock.calls[0][1].option).toBe('config')
    })
    it('should convert params to snake case', async () => {
      const params = { fooBar: 'baz' }
      await get('/foo', params)
      expect(fetch.mock.calls[0][0]).toBe(`${API_URL}/foo?foo_bar=baz`)
    })
    it('should convert response to camel case', async () => {
      fetch.mockResponse(JSON.stringify({ access_token: '12345' }))
      const response = await get('/foo')
      expect(response).toEqual({ accessToken: '12345' })
    })
  })
})
