import { patch } from '../http'
import { API_URL } from '../../config'

describe('http', () => {
  beforeEach(() => {
    fetch.resetMocks()
    fetch.mockResponse('{}')
  })
  describe('patch', () => {
    it('should call with the api url', async () => {
      await patch('/foo')
      expect(fetch.mock.calls[0][0]).toBe(`${API_URL}/foo`)
    })
    it('should call with the expected body', async () => {
      const params = { bar: 'baz', params: [1, 2, 3] }
      await patch('/foo', params)
      expect(fetch.mock.calls[0][1].body).toBe(JSON.stringify(params))
    })
    it('should add default json headers', async () => {
      await patch('/foo')
      expect(fetch.mock.calls[0][1].headers).toEqual({
        Accept: 'application/json',
        'Content-Type': 'application/json'
      })
    })
    it('should call with the expected headers', async () => {
      await patch('/foo', null, {
        headers: { some: 'header' },
        option: 'config'
      })
      expect(fetch.mock.calls[0][1].headers.some).toBe('header')
      expect(fetch.mock.calls[0][1].option).toBe('config')
    })
    it('should convert payload to snake case', async () => {
      const params = { fooBar: 'baz' }
      await patch('/foo', params)
      expect(fetch.mock.calls[0][1].body).toBe('{"foo_bar":"baz"}')
    })
    it('should convert response to camel case', async () => {
      fetch.mockResponse(JSON.stringify({ access_token: '12345' }))
      const response = await patch('/foo')
      expect(response).toEqual({ accessToken: '12345' })
    })
  })
})
