// @flow
import React from 'react'
import PropTypes from 'prop-types'
import { connect } from 'react-redux'
import { createStructuredSelector } from 'reselect'

export default function (
  Component,
  selector = createStructuredSelector({}),
  actions
) {
  class ReduxContainer extends React.Component {
    static propTypes = {
      navigation: PropTypes.object
    }
    static contextTypes = {
      store: PropTypes.object.isRequired
    }

    navigationParams () {
      const { navigation } = this.props
      return (navigation && navigation.state.params) || {}
    }

    componentDidMount () {
      if (Component.navigateActions) {
        const { store } = this.context
        Component.navigateActions.forEach(action =>
          store.dispatch(action({ ...this.props, ...this.navigationParams() }))
        )
      }
    }

    componentWillUnmount () {
      if (Component.navigateAwayActions) {
        const { store } = this.context
        Component.navigateAwayActions.forEach(action =>
          store.dispatch(action({ ...this.props, ...this.navigationParams() }))
        )
      }
    }

    render () {
      return <Component {...this.navigationParams()} {...this.props} />
    }
  }
  const connectedComponent = connect(selector, { ...actions })(ReduxContainer)
  connectedComponent.navigationOptions = Component.navigationOptions
  connectedComponent.navigateActions = Component.navigateActions
  connectedComponent.navigateAwayActions = Component.navigateAwayActions
  return connectedComponent
}
