// @flow
import Immutable from 'immutable'
import { PRODUCTION_ENV } from '../config'

export default function createReducer (initialState, handlers) {
  if (!PRODUCTION_ENV && 'undefined' in handlers) {
    console.warn('Found key "undefined" in reducer handlers', handlers)
  }

  const StateConstructor = initialState.constructor
  return function reducer (state = initialState, action) {
    if (!PRODUCTION_ENV && !(state instanceof StateConstructor)) {
      const nextState = new StateConstructor(state)
      if (Immutable.is(state, nextState)) {
        state = nextState
      } else {
        console.warn('State is not an instance of StateConstructor')
      }
    }

    const handler = handlers[action.type]
    if (!handler) {
      return state
    }

    state = handler(state, action)
    if (!(state instanceof StateConstructor)) {
      throw new TypeError(
        'Reducers must return an instance of StateConstructor'
      )
    }

    return state
  }
}
