// @flow
import { Iterable } from 'immutable'
import { createStore, applyMiddleware, compose } from 'redux'
import { createLogger } from 'redux-logger'
import thunk from 'redux-thunk'
import { batchedSubscribe } from 'redux-batched-subscribe'
import { debounce } from 'lodash'
import { DEVELOPMENT_ENV } from '../config'
import createReducer from '../reducers'

export function logger () {
  const stateTransformer = state => {
    const transformer = value =>
      value && typeof value === 'object' ? stateTransformer(value) : value
    return Object.entries(state).reduce((vals, [key, value]) => {
      vals[key] = Iterable.isIterable(value) ? value.toJS() : transformer(value)
      return vals
    }, {})
  }
  return createLogger({
    collapsed: true,
    stateTransformer,
    predicate () {
      return DEVELOPMENT_ENV
    }
  })
}

const debounceNotify = debounce(notify => notify())

export default function configureStore (navReducer, middlewares = []) {
  const enhancer = compose(
    applyMiddleware(thunk, /* logger(), */ ...middlewares),
    batchedSubscribe(debounceNotify)
  )
  const store = createStore(createReducer(navReducer), enhancer)
  global.store = store
  if (module.hot) {
    module.hot.accept(() => {
      const nextRootReducer = require('../reducers').default
      store.replaceReducer(nextRootReducer(navReducer))
    })
  }

  return store
}
