// @flow
import { merge } from 'lodash'
import humps from 'humps'
import { DEVELOPMENT_ENV } from '../config'

function getQuery (queryParams) {
  const params = Object.keys(queryParams).map(key =>
    [humps.decamelize(key), encodeURIComponent(queryParams[key])].join('=')
  )
  return '?' + params.join('&')
}

const defaultOptions = {
  headers: {
    'Content-Type': 'application/json',
    Accept: 'application/json'
  },
  method: 'GET'
}

async function _fetch (method, url, opts = {}, data, queryParams = '') {
  const options = {}
  merge(options, defaultOptions, { ...opts, method })
  if (DEVELOPMENT_ENV) {
    console.log('fetching', url, queryParams, data)
  }
  const urlWithQuery = `${url}${queryParams}`
  if (data) {
    options.body = JSON.stringify(humps.decamelizeKeys(data))
  }
  const response = await fetch(urlWithQuery, options)
  if (response.status >= 200 && response.status < 300) {
    const json = await response.json()
    const camelizedResponse = humps.camelizeKeys(json)
    if (opts.dontCamelize) {
      return json.response || json
    }
    return camelizedResponse.response || camelizedResponse
  }
  try {
    const responseText = (await response.text()) || response.statusText
    throw new Error(responseText)
  } catch (e) {
    throw new Error(e)
  }
}

export function get (url, options, queryParams) {
  return _fetch(
    'GET',
    url,
    options,
    null,
    queryParams ? getQuery(queryParams) : ''
  )
}

export function post (url, options, body) {
  return _fetch('POST', url, options, body)
}

export function put (url, options, body) {
  return _fetch('PUT', url, options, body)
}
export function patch (url, options, body) {
  return _fetch('PATCH', url, options, body)
}
export function destroy (url, options) {
  return _fetch('DELETE', url, options)
}
