// @flow
import ImagePicker from 'react-native-image-picker'
import DocumentPicker from 'react-native-document-picker'
import { Alert, Platform } from 'react-native'

export default function fileChooser ({
  audio,
  video,
  images,
  pdf,
  library,
  camera
}) {
  if (library) {
    return fileChooserLibrary()
  } else if (camera) {
    return fileChooserCamera()
  }
  return new Promise(async (resolve, reject) => {
    try {
      let selectedImages
      const result = await DocumentPicker.pickMultiple({
        type: [
          audio && DocumentPicker.types.audio,
          video && 'public.video',
          images && DocumentPicker.types.images,
          pdf && DocumentPicker.types.pdf
        ].filter(value => value)
      })
      selectedImages = result.map(({ uri }) => uri)
      resolve(selectedImages)
    } catch (error) {
      reject(error)
      if (DocumentPicker.isCancel(error)) {
        return
      }
      // TODO - APP
      Alert.alert('DKBLCC', 'Sorry the file failed to upload, please try again')
    }
  })
}

export function fileChooserCamera () {
  const options = {
    maxWidth: 1000,
    maxHeight: 1000,
    returnBase64Image: false,
    returnIsVertical: false,
    quality: 0.6,
    allowsEditing: false
  }
  return new Promise((resolve, reject) => {
    ImagePicker.launchCamera(options, async response => {
      if (response.didCancel && Platform.OS !== 'android') {
        reject(new Error('cancel'))
        return
      }
      if (response.error) {
        Alert.alert('An error occurred', response.error, [{ text: 'OK' }])
        reject(new Error('response error'))
        return
      }
      try {
        let selectedImages = [response.uri]
        resolve(selectedImages)
      } catch (error) {
        // TODO - APP
        Alert.alert(
          'DKBLCC',
          'Sorry the file failed to upload, please try again'
        )
        reject(error)
      }
    })
  })
}

export function fileChooserLibrary () {
  const options = {
    maxWidth: 1000,
    maxHeight: 1000,
    returnBase64Image: false,
    returnIsVertical: false,
    quality: 0.6,
    allowsEditing: false
  }
  return new Promise((resolve, reject) => {
    ImagePicker.launchImageLibrary(options, async response => {
      if (response.didCancel && Platform.OS !== 'android') {
        reject(new Error('cancel'))
        return
      }
      if (response.error) {
        Alert.alert('An error occurred', response.error, [{ text: 'OK' }])
        reject(new Error('response error'))
        return
      }
      try {
        let selectedImages = [response.uri]
        resolve(selectedImages)
      } catch (error) {
        // TODO - APP
        Alert.alert(
          'DKBLCC',
          'Sorry the file failed to upload, please try again'
        )
        reject(error)
      }
    })
  })
}
