// @flow
import { Platform } from 'react-native'

const font = {
  OpenSans: {
    weights: {
      extraBold: '800',
      bold: '700',
      semiBold: '600',
      light: '300',
      normal: '400'
    },
    styles: {
      italic: 'italic'
    }
  }
}

export default function fontMaker (options = {}) {
  let { weight, style, family } = Object.assign(
    {
      weight: null,
      style: null,
      family: 'OpenSans'
    },
    options
  )

  const { weights, styles } = font[family]

  if (Platform.OS === 'android') {
    weight = weights[weight] ? weight : ''
    style = styles[style] ? style : ''

    const suffix = weight + style

    return {
      fontFamily: family + (suffix.length ? `-${suffix}` : '')
    }
  } else {
    weight = weights[weight] || weights.normal
    style = styles[style] || 'normal'

    return {
      fontFamily: family,
      fontWeight: weight,
      fontStyle: style
    }
  }
}
