// @flow
import { AppState, Platform, PushNotificationIOS } from 'react-native'
import humps from 'humps'
import { UserSelectors, UserActions } from 'resources/user'
import PushNotification from 'react-native-push-notification'
import { RouteActions } from 'routes'
import SCREENS from 'routes/screens'

export function register () {
  return async (dispatch, getState) => {
    const userId = UserSelectors.currentUserId(getState())
    if (Platform.OS === 'ios') {
      PushNotificationIOS.addEventListener('register', token => {
        dispatch(
          UserActions.registerToken({
            deviceType: Platform.OS,
            userId,
            deviceToken: token
          })
        )
      })
      PushNotificationIOS.addEventListener('notification', notification => {
        const data = humps.camelizeKeys(notification.getData())
        if (AppState.currentState === 'active') {
          return
        }
        if (Platform.OS === 'ios') {
          notification.finish(PushNotificationIOS.FetchResult.NoData)
        }

        dispatch(
          RouteActions.reset('SignedIn', SCREENS.INBOX, { projectId: '0' })
        )
        dispatch(RouteActions.setParams({ projectId: '0' }))
        setTimeout(() => {
          dispatch(RouteActions.navigate(SCREENS.CONVERSATION, data))
        }, 300)
      })
      PushNotificationIOS.requestPermissions()
    } else {
      const FCM = require('react-native-fcm').default
      FCM.requestPermissions()
      FCM.getFCMToken().then(token => {
        UserActions.registerToken({
          deviceType: Platform.OS,
          userId,
          deviceToken: token
        })
      })
      FCM.getInitialNotification()
      FCM.on('FCMNotificationReceived', notif => {
        FCM.presentLocalNotification({
          title: notif.title,
          body: notif.body,
          priority: 'high',
          click_action: notif.click_action,
          show_in_foreground: true,
          local: true
        })
      })

      PushNotification.configure({
        onRegister: function ({ token }) {
          dispatch(
            UserActions.registerToken({
              deviceType: Platform.OS,
              userId,
              deviceToken: token
            })
          )
        },

        onNotification: async function (notification) {
          const data = humps.camelizeKeys(notification.getData())
          if (Platform.OS === 'ios') {
            notification.finish(PushNotificationIOS.FetchResult.NoData)
          }
          if (AppState.currentState === 'active') {
            return
          }
          dispatch(
            RouteActions.reset('SignedIn', SCREENS.INBOX, { projectId: '0' })
          )
          dispatch(RouteActions.setParams({ projectId: '0' }))
          setTimeout(() => {
            dispatch(RouteActions.navigate(SCREENS.CONVERSATION, data))
          }, 300)
        },
        permissions: {
          alert: true,
          badge: true,
          sound: true
        },
        requestPermissions: true,
        senderID: '1027779752377'
      })
    }
  }
}

export function unregister () {
  return (dispatch, getState) => {
    const userId = UserSelectors.currentUserId(getState())
    const deviceToken = UserSelectors.deviceToken(getState())
    dispatch(UserActions.unregisterToken({ userId, deviceToken }))
  }
}
