// @flow
import { Platform, NativeModules } from 'react-native'
import RNGRP from 'react-native-get-real-path'
import humps from 'humps'

const { FileUpload } = NativeModules

async function parseFiles (files) {
  return Promise.all(
    files.map(file => {
      if (Platform.OS === 'ios') {
        return Promise.resolve(file)
      }
      return new Promise(async (resolve, reject) => {
        try {
          const androidPath = await RNGRP.getRealPathFromURI(file.filepath)
          resolve({
            ...file,
            filepath: androidPath
          })
        } catch (e) {
          console.log('nope', e)
        }
      })
    })
  )
}

export function upload (uploadUrl, fields, files, androidParsePath = true) {
  return new Promise(async (resolve, reject) => {
    try {
      const parsedFiles = androidParsePath ? await parseFiles(files) : files
      FileUpload.upload(
        {
          uploadUrl,
          method: 'POST',
          headers: {
            Accept: 'application/json'
          },
          fields,
          files: parsedFiles
        },
        (err, result) => {
          if (result && result.status === 200) {
            return resolve(humps.camelizeKeys(JSON.parse(result.data)))
          }
          reject(err || result)
        }
      )
    } catch (err) {
      reject(err)
    }
  })
}
